(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    610176,      16754]
NotebookOptionsPosition[    522677,      15786]
NotebookOutlinePosition[    523221,      15805]
CellTagsIndexPosition[    523178,      15802]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Creating and solving list of exercises with Mathematica.  Local extrema of a \
function in two variables. \
\>", "Title",
 CellChangeTimes->{{3.8371594606850915`*^9, 3.837159517472588*^9}, {
   3.837177285695553*^9, 3.8371773147060623`*^9}, {3.837177347896946*^9, 
   3.8371773881120567`*^9}, 3.8375274535830555`*^9, 3.83752748458865*^9, {
   3.8436497804312572`*^9, 
   3.8436497932810383`*^9}},ExpressionUUID->"f4127fb0-ac83-4259-9c97-\
79c6d9b0af56"],

Cell["Stanis\[LSlash]aw Ewert-Krzemieniewski", "Author",
 CellChangeTimes->{{3.837527500527007*^9, 
  3.837527534112398*^9}},ExpressionUUID->"0db49f07-b9fc-4864-a9fa-\
f996f9d84a68"],

Cell["\<\
School of Mathematics, West Pomeranian University of Technology in Szczecin, \
Al. Piast\[OAcute]w 17, 70-310 Szczecin, Poland
\
\>", "Department",
 CellChangeTimes->{{3.8375275575079184`*^9, 3.8375276699924183`*^9}, {
   3.8390738610482016`*^9, 3.83907389145926*^9}, {3.8390739306646423`*^9, 
   3.8390739334864225`*^9}, {3.8393338484282475`*^9, 3.8393338506643343`*^9}, 
   3.8436491969683437`*^9},ExpressionUUID->"2aff5f34-50b2-4074-8929-\
33b372bae672"],

Cell["e - mail: ewert@zut.edu.pl", "Text",
 CellChangeTimes->{{3.8393338550996923`*^9, 
  3.8393338766129107`*^9}},ExpressionUUID->"61c4b771-eeb0-496e-8c1f-\
617a24f1858e"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.8390739422544327`*^9, 
  3.8390739481311197`*^9}},ExpressionUUID->"0680e803-e07a-4bb2-ad68-\
869854d4e99d"],

Cell["\<\

\tWe present a program in Mathematica that allows to create a long list of \
different exercises of similar types for students and the second one of \
answers.
\tThe presentation is based on two examples. We want to investigate the local \
extrema of a function f[a, b, c][x, y] in real variables x, y, depending on \
real parameters a, b, c. In both examples students have to solve by \
factorizing the system of two equation of the second degree. The choice of \
parameters should makes the numerical computations as easy as possible. \
Therefore, in the first example the parameters are chosen in such a way that \
the components of all stationary points are integers, while in the second one \
are integers or square roots of integers. Moreover, the resulting functions \
depend only on two parameters b, c.
\tFor each example we create the set of about 30 exercises. This number can \
varies depending on needs. Thus the sets are suitable for on-line exams or \
home-works.
\tFor better understanding, in Example 1 we explain, step by step, the result \
of each code we have created. In the Example 2 we present necessary codes in \
a compact form. We do not explain how Mathematica works! For that we refer to \
help menu in Mathematica.
\tThe user can create her or his own list of parameters in the form \
listofparameters = { {b1, c1}, {b2, \
c2},\[Ellipsis]\[Ellipsis]\[Ellipsis].{bm, cm} } or try to replace the \
function f with her or his own one.
\tEach part runs independently from other.
\tFor those not familiar with Mathematica the .pdf and .tex files are attached.
\tFinally we remark that problems no.  3261 and no. 3259, respectively 2986 \
and 2984 for the Polish edition, from the well- known problems book by G. N. \
Berman are the special cases of discussed functions.
\
\>", "Text",
 CellChangeTimes->{{3.8371774379273415`*^9, 3.8371776381927896`*^9}, {
   3.837177677577891*^9, 3.8371777230063543`*^9}, 3.83717795131623*^9, {
   3.83752885892773*^9, 3.8375289744254513`*^9}, 3.8375291692152157`*^9, {
   3.839073786498478*^9, 3.8390738474548793`*^9}, {3.839333885617404*^9, 
   3.839333906879714*^9}, 3.8393339663917103`*^9, {3.8393340231384315`*^9, 
   3.839334067514058*^9}, {3.839335206745652*^9, 3.839335257089258*^9}, {
   3.8393917368759694`*^9, 3.8393917438802414`*^9}, {3.839560732651309*^9, 
   3.839560736307272*^9}, {3.839643286505189*^9, 3.839643346377103*^9}, {
   3.8396434159127035`*^9, 3.8396434467232137`*^9}, {3.8396434972010183`*^9, 
   3.839643498761573*^9}},ExpressionUUID->"b992263d-f6ce-47b3-8120-\
5042758196fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 1", "Section",
 CellChangeTimes->{{3.832149173139254*^9, 3.83214917697956*^9}, {
  3.837159535131672*^9, 
  3.837159538145645*^9}},ExpressionUUID->"c2987a83-db69-4ea4-ba5c-\
075404df2f4c"],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsubsection",
 CellChangeTimes->{{3.8321615245710125`*^9, 3.832161526814526*^9}, {
  3.8326816862592583`*^9, 3.8326816908880634`*^9}, {3.8371595445475483`*^9, 
  3.837159549713807*^9}, {3.8371615719997454`*^9, 3.83716157637359*^9}, {
  3.837527564461606*^9, 
  3.8375275802534947`*^9}},ExpressionUUID->"987c660c-f517-493b-9035-\
6cd391f3f3c0"],

Cell["\<\
There is given a family of functions f[x,y]  :=  x y (a + b x + c y), that \
depends on three real parameters a, b, c. The components of stationary points \
are easily expressed by parameters a, b, c.\
\>", "Text",
 CellChangeTimes->{{3.837159589467532*^9, 3.8371595913345466`*^9}, {
   3.837159624283513*^9, 3.8371597501440773`*^9}, 3.8371598942848363`*^9, {
   3.837161971101631*^9, 
   3.8371619737527633`*^9}},ExpressionUUID->"8cb91a9c-0369-4943-8b11-\
1d5bfa9ea0b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "  ", ":=", "  ", 
  RowBox[{"x", " ", "y", " ", 
   RowBox[{"(", 
    RowBox[{"a", " ", "+", " ", 
     RowBox[{"b", " ", "x"}], " ", "+", " ", 
     RowBox[{"c", " ", "y"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.8371611814934497`*^9, 3.8371611878901095`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"de82af97-faee-42c2-91f4-b00663a85aa7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"x", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", 
          RowBox[{"b", " ", "x"}], "+", 
          RowBox[{"c", " ", "y"}]}], ")"}]}], ",", " ", "x"}], "]"}], " ", 
     "\[Equal]", " ", "0"}], " ", "&&", "   ", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"x", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", 
          RowBox[{"b", " ", "x"}], "+", 
          RowBox[{"c", " ", "y"}]}], ")"}]}], ",", " ", "y"}], "]"}], " ", 
     "\[Equal]", "0"}], " ", "&&", " ", 
    RowBox[{"a", " ", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"b", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"c", " ", "=!=", "0"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8321466572685537`*^9, 3.832146828540494*^9}, {
  3.8371597852012415`*^9, 3.83715983303854*^9}, {3.837159898042926*^9, 
  3.8371599014484034`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"fabee59f-9882-4040-89b0-d874c20faa23"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["a", "c"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["a", 
        RowBox[{"3", " ", "b"}]]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["a", 
        RowBox[{"3", " ", "c"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["a", "b"]}]}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.832146830106033*^9, 3.832161833326397*^9, 
  3.8321620026545253`*^9, 3.8322331266185064`*^9, 3.83224476740758*^9, 
  3.83224694839933*^9, 3.8322476880367575`*^9, 3.832249305892005*^9, 
  3.8323076356233644`*^9, 3.832319340509174*^9, 3.832647070635405*^9, 
  3.8329086552535686`*^9, 3.832923967836557*^9, 3.833343614612917*^9, 
  3.8333468744243164`*^9, 3.837159880511885*^9, 3.8371599132143164`*^9, 
  3.837163304313885*^9, 3.8371635199405184`*^9, 3.839335327401348*^9, 
  3.839335537613031*^9, 3.839335655768936*^9, 3.83939239366687*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"eab655cb-1643-459d-9961-4cc694ae4ba0"]
}, Open  ]],

Cell["\<\
It is clear that the problem \[OpenCurlyDoubleQuote]test the existence and \
type of local extrema of the given function f relative to the parameters a, \
b,c\[CloseCurlyDoubleQuote] can be easily solved in general.   Our goal is to \
provide a large number of numerically uncomplicated  examples.\
\>", "Text",
 CellChangeTimes->{{3.83715997384079*^9, 3.8371600363128705`*^9}, {
  3.837160139335153*^9, 3.8371601402204237`*^9}, {3.837160266213666*^9, 
  3.8371603668370266`*^9}, {3.8371604030504975`*^9, 3.837160423624129*^9}, {
  3.837160460326455*^9, 3.8371604722635117`*^9}, {3.8371605141368127`*^9, 
  3.8371605930424256`*^9}, {3.8371608626718893`*^9, 3.8371609051040897`*^9}, {
  3.8371609774648156`*^9, 3.837160984225155*^9}, {3.837177143327776*^9, 
  3.8371771689483404`*^9}},ExpressionUUID->"4a330fc1-6502-439b-a15b-\
93ecdf34f923"],

Cell["\<\
Suppose 3b|a and 3c|a and put f[x,y] := x y (3 b c + b x + c y).\
\>", "Text",
 CellChangeTimes->{{3.8326821129664364`*^9, 3.8326821408927345`*^9}, {
   3.8326823306447306`*^9, 3.832682358799261*^9}, {3.833942793830263*^9, 
   3.833942802616544*^9}, {3.8371610564496098`*^9, 3.8371610864887724`*^9}, {
   3.8371615926653137`*^9, 3.8371616477242346`*^9}, 
   3.837162081142433*^9},ExpressionUUID->"b9e61f88-0b02-4d11-9c05-\
91a0c089d22a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";", "  ", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"x", " ", "y", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "b", " ", "c"}], "+", 
      RowBox[{"b", " ", "x"}], "+", 
      RowBox[{"c", " ", "y"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8371616526840315`*^9, 3.837161681383579*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"c47b159b-a6bc-40a6-8aa3-1c450d9cb56a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parametricsolution", " ", "=", 
  RowBox[{"Solve", "[", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "b", " ", "c"}], "  ", "+", 
         RowBox[{"2", "b", " ", "x"}], " ", "+", " ", 
         RowBox[{"c", " ", "y"}]}], ")"}]}], " ", "\[Equal]", " ", "0"}], " ",
      "&&", "  ", 
     RowBox[{
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "b", " ", "c"}], " ", "+", " ", 
         RowBox[{"b", " ", "x"}], " ", "+", " ", 
         RowBox[{"2", " ", "c", " ", "y"}]}], ")"}]}], " ", "\[Equal]", "0"}],
      " ", "&&", " ", 
     RowBox[{"a", " ", "=!=", "0"}], " ", "&&", " ", 
     RowBox[{"b", "=!=", "0"}], " ", "&&", " ", 
     RowBox[{"c", " ", "=!=", "0"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8321466572685537`*^9, 3.832146828540494*^9}, {
  3.832146952266513*^9, 3.832146969221568*^9}, {3.8323192800606956`*^9, 
  3.8323192931692705`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"8717ecca-984d-4cdf-9a0f-570c9cb19696"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "b"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", "c"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", "b"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "c"}]}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8321491527516966`*^9, 3.8321618333638945`*^9, 
  3.8321620028743725`*^9, 3.832233126776061*^9, 3.832244767526972*^9, 
  3.8322469485076227`*^9, 3.8322476881629715`*^9, 3.8322493060272727`*^9, 
  3.832307635751343*^9, 3.8323193406242304`*^9, 3.832647070742139*^9, 
  3.8329086553660955`*^9, 3.8329239678846626`*^9, 3.8333436147403464`*^9, 
  3.833346874542227*^9, 3.837161797149416*^9, 3.837163304335975*^9, 
  3.837163519956315*^9, 3.839335327419691*^9, 3.8393355376293173`*^9, 
  3.839335655790099*^9, 3.839392393682618*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"57b1027c-b52f-4a6f-a926-376b7c1c36b4"]
}, Open  ]],

Cell["\<\
If b, c are integers, so do the coordinates of stationary points!\
\>", "Text",
 CellChangeTimes->{{3.8371769802960854`*^9, 3.8371770532092896`*^9}, 
   3.83933550467875*^9},ExpressionUUID->"333e7dfb-3911-46f1-8d22-\
978cb0dd3475"],

Cell[BoxData[
 RowBox[{"Clear", "[", "f", "]"}]], "Input",
 CellChangeTimes->{{3.8371634037175217`*^9, 3.837163407343089*^9}, {
   3.839334756639347*^9, 3.8393347634844894`*^9}, 3.8393354773275685`*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"9e86f152-ae81-47a8-85f2-6f34ceca452d"]
}, Closed]],

Cell[CellGroupData[{

Cell["For studens", "Subsubsection",
 CellChangeTimes->{{3.837166468373644*^9, 
  3.8371664734277706`*^9}},ExpressionUUID->"3d175d12-43da-4432-ae00-\
a201f9b8c64f"],

Cell["\<\
Investigate the existence and type of local extrema of the function  \
f[b,c][x,y] in real variables x, y that depends on two real parameters b, c \
given by listofparameters. THe list listofparameters can be of arbitrary \
length.\
\>", "Text",
 CellChangeTimes->{{3.8371621241604776`*^9, 
  3.8371623433303876`*^9}},ExpressionUUID->"bc6cf451-a4b7-478c-8955-\
b641a85db6d4"],

Cell["\<\
REMARK! The definition of function and listofparameters are the only \
quantities entered by the user.\
\>", "Text",
 CellChangeTimes->{{3.8371623603618727`*^9, 3.8371624431207066`*^9}, {
  3.837162523152525*^9, 
  3.837162533502813*^9}},ExpressionUUID->"618d4a37-9c5e-4ba3-9177-\
c279b0653c70"],

Cell["Define the function.", "Text",
 CellChangeTimes->{{3.8326828819553223`*^9, 3.8326828929228024`*^9}, {
  3.83716254629744*^9, 
  3.837162556534298*^9}},ExpressionUUID->"001f9eb1-efc8-4010-a95a-\
92fa348f42d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"b_", ",", "c_"}], "]"}], "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"3", " ", "b", " ", "c", " ", "x", " ", "y"}], "+", 
   RowBox[{"b", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"c", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.8321580297572684`*^9, 3.832158095332217*^9}, {
   3.8321589251796246`*^9, 3.8321589269848022`*^9}, 3.8371623691872964`*^9, {
   3.837163338739891*^9, 3.8371633478256364`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"ee7114a0-8255-484a-a702-f63a8f5827c2"],

Cell["\<\
For integers b, c the components of stationary points of the given function f \
are also integers. We define  listofparameters, i.e. the set of pairs {b, c}.\
\>", "Text",
 CellChangeTimes->{{3.8371627876775084`*^9, 3.8371629026152725`*^9}, {
  3.837162948175088*^9, 
  3.837162976249958*^9}},ExpressionUUID->"edf20948-7d49-425c-b539-\
a12af9a63f23"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"listofparameters", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2"}], ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2"}], ",", " ", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", " ", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", " ", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", " ", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", " ", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", " ", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2"}], ",", " ", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", " ", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", " ", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "4"}], ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", " ", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", " ", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", " ", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", " ", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", " ", 
      RowBox[{"-", "4"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", " ", 
      RowBox[{"-", "4"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2"}], ",", " ", 
      RowBox[{"-", "4"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", " ", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", " ", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", " ", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "4"}], ",", " ", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "5"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"5", ",", " ", "1"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.832161616032201*^9, 3.832161640189154*^9}, {
   3.8333434764360666`*^9, 3.833343559653691*^9}, {3.8333467202980194`*^9, 
   3.8333468598463078`*^9}, 3.8371623691885557`*^9, {3.83716353713148*^9, 
   3.83716353713148*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"a27d5900-7ea0-414e-8467-1cec849c6434"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8371635461941833`*^9, 3.8393353274354997`*^9, 
  3.8393355557142353`*^9, 3.8393356704748383`*^9, 3.8393923937140193`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"59357941-783d-4c3b-9fff-00081d1126b3"]
}, Open  ]],

Cell["We define the right hand sides of  f[b,c][x,y].", "Text",
 CellChangeTimes->{{3.832683415818554*^9, 3.832683472927697*^9}, {
  3.837163181945115*^9, 
  3.8371632095831127`*^9}},ExpressionUUID->"76a20d94-92d3-40ec-8ba7-\
5df665adb89d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"listofrighthandside", " ", "=", " ", 
  RowBox[{"Apply", "[", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"#1", ",", " ", "#2"}], "]"}], "[", 
      RowBox[{"x", ",", " ", "y"}], "]"}], " ", "&"}], ",", " ", 
    "listofparameters", "  ", ",", " ", 
    RowBox[{"{", "1", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.832157856969433*^9, 3.8321579238787494`*^9}, 
   3.8321579643387485`*^9, {3.8321581282753854`*^9, 3.832158326019701*^9}, {
   3.8321583893454895`*^9, 3.832158446767804*^9}, {3.83215854988686*^9, 
   3.832158571183409*^9}, {3.8321588323854227`*^9, 3.832158871814169*^9}, {
   3.8321589779823284`*^9, 3.832159044350474*^9}, {3.832159076848095*^9, 
   3.8321591829726505`*^9}, 3.83216161302649*^9, 3.832161652967498*^9, {
   3.8321616847269034`*^9, 3.832161700284647*^9}, 3.837162369189995*^9, {
   3.8371635971887703`*^9, 3.8371635971887703`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"b43fe6ed-9361-4a5f-add1-df96027b0c3e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"2", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"6", " ", "x", " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"2", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"6", " ", "x", " ", "y"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"12", " ", "x", " ", "y"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"2", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"9", " ", "x", " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "9"}], " ", "x", " ", "y"}], "-", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "9"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"9", " ", "x", " ", "y"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"18", " ", "x", " ", "y"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"18", " ", "x", " ", "y"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"2", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "18"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"2", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "18"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "27"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"27", " ", "x", " ", "y"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"12", " ", "x", " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"12", " ", "x", " ", "y"}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"36", " ", "x", " ", "y"}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"3", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"36", " ", "x", " ", "y"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "36"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "36"}], " ", "x", " ", "y"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "-", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"36", " ", "x", " ", "y"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "-", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"24", " ", "x", " ", "y"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "-", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"24", " ", "x", " ", "y"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"24", " ", "x", " ", "y"}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"2", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"48", " ", "x", " ", "y"}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "48"}], " ", "x", " ", "y"}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"4", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"15", " ", "x", " ", "y"}], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"5", " ", "x", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"15", " ", "x", " ", "y"}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["x", "2"], " ", "y"}], "+", 
    RowBox[{"x", " ", 
     SuperscriptBox["y", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8371636022924194`*^9, 3.839335327451397*^9, 
  3.839335555729859*^9, 3.8393356704944873`*^9, 3.8393923937140193`*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"07bf9951-dda9-406c-942b-3fce5e1cd1e4"]
}, Open  ]],

Cell["\<\
The next two inputs make possible to write the left hand side of a function \
in the form f[b,c][x,y].\
\>", "Text",
 CellChangeTimes->{{3.8371640835393596`*^9, 
  3.8371641606962185`*^9}},ExpressionUUID->"4c9e2792-fd1c-40f0-bf0c-\
f762ec98d52d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"listofheads", " ", "=", " ", 
  RowBox[{"Apply", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"#1", ",", " ", "#2"}], "]"}], " ", "&"}], ",", " ", 
    "listofparameters", " ", ",", " ", 
    RowBox[{"{", "1", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.832159452728803*^9, 3.8321594750401897`*^9}, 
   3.8321616683343105`*^9, {3.832161722723113*^9, 3.83216173206402*^9}, 
   3.837162369194786*^9, {3.837163713330058*^9, 3.837163713330058*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"adae21dc-2c9e-45f8-97d4-b6abe61b5b01"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "1"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "2"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"1", ",", "2"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"2", ",", "1"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"2", ",", "2"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"1", ",", "3"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "3"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "1"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"3", ",", "1"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"2", ",", "3"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"3", ",", "2"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "2"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "3"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"3", ",", "3"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"1", ",", "4"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "1"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"4", ",", "1"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"4", ",", "3"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"3", ",", "4"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "4"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"3", ",", 
     RowBox[{"-", "4"}]}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}]}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"2", ",", "4"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"4", ",", "2"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"4", ",", "4"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "4"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"1", ",", "5"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"5", ",", "1"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8371637222287207`*^9, 3.8393353274671288`*^9, 
  3.839335555729859*^9, 3.8393356705221033`*^9, 3.8393923937299075`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"90925cc7-0dc7-4258-a9bc-282aebc57e39"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"listoflefthandside", " ", "=", " ", 
  RowBox[{"Map", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"HoldForm", "[", 
      RowBox[{"#", " ", "[", 
       RowBox[{"x", ",", " ", "y"}], "]"}], "]"}], " ", "&"}], ",", " ", 
    "listofheads"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.832160476283702*^9, 3.832160538060707*^9}, {
   3.8321617453952103`*^9, 3.8321617937312136`*^9}, 3.837162369199933*^9, {
   3.83716375853294*^9, 3.83716375853294*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"76556e3e-c569-4862-8d1f-bb400ed69ab6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "1"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "2"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "3"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"3", ",", "3"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"1", ",", "4"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "1"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"4", ",", "1"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"4", ",", "3"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"3", ",", "4"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "4"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}]}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}]}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"2", ",", "4"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"4", ",", "2"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"4", ",", "4"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"1", ",", "5"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"5", ",", "1"}], "]"}], "[", 
     RowBox[{"x", ",", "y"}], "]"}],
    HoldForm]}], "}"}]], "Output",
 CellChangeTimes->{3.837163811600856*^9, 3.8393353274829655`*^9, 
  3.839335555749996*^9, 3.8393356705370555`*^9, 3.839392393751215*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"8aa8b8b4-1adb-4056-b87c-fcdd1a3bf44d"]
}, Open  ]],

Cell["We obtain a numbered list of functions.", "Text",
 CellChangeTimes->{{3.832683515925913*^9, 3.8326835286439695`*^9}, 
   3.8326835675892944`*^9, {3.837164181007382*^9, 
   3.8371642238543396`*^9}},ExpressionUUID->"c27872c8-9c72-40d9-b846-\
cc6b62ec7bf5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"r", ",", "Bold"}], "]"}], "]"}], ",", " ", 
     RowBox[{"Print", "[", " ", 
      RowBox[{
       RowBox[{"listoflefthandside", "[", 
        RowBox[{"[", "r", "]"}], "]"}], " ", "==", " ", 
       RowBox[{"ReleaseHold", "[", " ", 
        RowBox[{"listoflefthandside", "[", 
         RowBox[{"[", "r", "]"}], "]"}], " ", "]"}]}], " ", "]"}]}], " ", 
    "}"}], " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"r", ",", " ", "1", " ", ",", " ", 
     RowBox[{"Length", "[", "listoflefthandside", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8321592319010873`*^9, 3.8321592367436657`*^9}, {
   3.832160582205969*^9, 3.8321606552311077`*^9}, {3.832160751392248*^9, 
   3.832160756627226*^9}, {3.8321611162048006`*^9, 3.832161124291768*^9}, {
   3.8321611904989777`*^9, 3.832161195110818*^9}, 3.8321614219053144`*^9, {
   3.8321620416642714`*^9, 3.8321620500142317`*^9}, {3.8323077477836027`*^9, 
   3.832307758673258*^9}, 3.8371623692089043`*^9, {3.837163878960434*^9, 
   3.837163878960434*^9}, {3.8371642334067535`*^9, 3.837164308222353*^9}, {
   3.8371643391330824`*^9, 3.8371643421439915`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"ad5d462e-72c1-439c-8bf9-821b1d9ee3d3"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["1",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393751215*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"96d54837-ce2e-473a-b2e3-9de2d6906ea4"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393766901*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"1b71e4f0-29b5-491c-b23a-780943acefab"],

Cell[BoxData[
 StyleBox["2",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393766901*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"d071b536-f5a0-42d2-9ded-812f7b3e363e"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393766901*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"187ebc6e-93d7-4f57-b4d2-627bb0f59c8e"],

Cell[BoxData[
 StyleBox["3",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393766901*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"377e0593-7342-4f6b-b747-455c63f15d28"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393766901*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"4d0a95ed-3f6f-4f7f-b9ce-39a31c329c18"],

Cell[BoxData[
 StyleBox["4",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393766901*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"96b70ed6-1227-4f87-8dee-5ac24f74a4ac"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393766901*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"cd95dec2-522b-4572-b929-fea7e6bbfc94"],

Cell[BoxData[
 StyleBox["5",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"d1dc2b03-a37e-4bb2-9fc7-a0e6cbfbbb01"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"9270b975-1d93-4dae-b659-42d59c173596"],

Cell[BoxData[
 StyleBox["6",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"27c9c505-d5b9-49e2-8c80-1b05c054dd5e"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"8c1d0d9b-c54c-428c-9377-4f096936e3c7"],

Cell[BoxData[
 StyleBox["7",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"bac1178c-fae8-4812-8c5f-e6782bee620a"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "9"}], " ", "x", " ", "y"}], "-", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"0fca224b-ee4a-412d-b2b9-aa76b9064ee4"],

Cell[BoxData[
 StyleBox["8",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"7e93ecb7-e958-4a34-8e70-447623e5e96b"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "9"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"6cc712e1-fb15-4925-810c-807ac74f8539"],

Cell[BoxData[
 StyleBox["9",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"b248e8cb-da2a-4301-a1fb-947f9ddecb7e"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393782521*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"b0f5ed76-b700-42f4-8737-c3e858a8232a"],

Cell[BoxData[
 StyleBox["10",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"ebe0bade-f9c4-4f43-9ff5-705f52c70c4e"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"18", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"3771b725-cc78-4c3e-b4d8-d0c52b0e36bc"],

Cell[BoxData[
 StyleBox["11",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"aaf91e00-edb6-4f2d-8831-3f51f5c77f34"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"18", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"d97a1704-d564-42e9-a84e-02bb69f10fdf"],

Cell[BoxData[
 StyleBox["12",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"ffbef9b1-f4ff-464a-85ad-a117ac7dff1b"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "18"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"729934cf-2df7-4551-af39-260a34c7cb82"],

Cell[BoxData[
 StyleBox["13",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"267d59b1-7ea4-4945-b1cf-780782f6e25c"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "18"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"0d530900-329a-4b3c-8d8a-e26bdc213fb8"],

Cell[BoxData[
 StyleBox["14",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"49c85e98-32e5-4d4a-86c1-3561510596d2"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "27"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.839392393798089*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"452a9398-62a3-48bd-9918-c78327d7bc6c"],

Cell[BoxData[
 StyleBox["15",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"24ed5ffa-26f7-41d2-9da9-beb558ea9451"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"27", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"d6b7365d-ecdb-41e7-ac3a-e28635d3bb4a"],

Cell[BoxData[
 StyleBox["16",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"41e1a047-75dd-44c6-ae39-047700b0e26b"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"895e1e4d-34a5-403b-af16-fc9241e555e8"],

Cell[BoxData[
 StyleBox["17",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"fa547995-1bc4-4ff2-b694-02595b9d1708"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "4"}], ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"cac8df2a-0268-4f7c-8498-6045d11f599d"],

Cell[BoxData[
 StyleBox["18",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"eb2c210d-8326-45cc-b385-5559a73934bc"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"e1489a8b-d861-4ac9-99e7-ed8dca3e4c66"],

Cell[BoxData[
 StyleBox["19",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938137183`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"e513d3b0-c801-4559-a349-1c147785aaf9"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"2cc52ffa-a03d-43c9-b75e-1be8f1caac7f"],

Cell[BoxData[
 StyleBox["20",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"c5ce71d0-18c4-459f-bbf4-9db397dc2573"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"183cf73d-d64b-49ac-92e7-d0f058c5b385"],

Cell[BoxData[
 StyleBox["21",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"e3d4c190-de85-4a94-86a2-111ae28d37c9"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "36"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"5b6cd426-000d-48b4-a480-57d376a47d8b"],

Cell[BoxData[
 StyleBox["22",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"232f0476-82d3-4b33-b650-6b9d9c6fc08a"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", 
      RowBox[{"-", "4"}]}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "36"}], " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"dc94efb8-1c4b-4f48-872f-8f78a01a89d6"],

Cell[BoxData[
 StyleBox["23",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"8dcf422e-739b-4289-9445-2f3577448699"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "4"}]}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"ad964e03-4e86-4b53-8d4b-e9ac3b44f6d2"],

Cell[BoxData[
 StyleBox["24",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938293443`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"6b21b644-9a7e-46b3-a9aa-3ac8d71d3a16"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "4"}]}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938449683`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"6d4fb640-209d-4019-8e79-5894fe8c6c7b"],

Cell[BoxData[
 StyleBox["25",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938449683`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"9f28907e-7dce-4db5-8f49-603396dcba39"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938449683`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"6b3e882c-32c3-4727-a8af-8b7bf502debf"],

Cell[BoxData[
 StyleBox["26",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938449683`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"2552925f-ec59-4b92-bfe9-56ee5217034f"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"87fd44a6-badf-4099-bba3-936c4431e49d"],

Cell[BoxData[
 StyleBox["27",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"ea4952d2-bbca-4287-b054-0dd439526721"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"4", ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"48", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"5380c7d1-c396-4333-afee-56833aadef4b"],

Cell[BoxData[
 StyleBox["28",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"660a02fe-9843-4296-9405-a6e5a8c086b2"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "4"}], ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "48"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"bf3bab32-a295-4064-9d68-8cdcdf7b3555"],

Cell[BoxData[
 StyleBox["29",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"18dcfe6d-0e5d-4cd9-a74f-d974ddf2699d"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "5"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"5", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"2cc47eb9-352c-43fc-b5e4-8754fb26f3e2"],

Cell[BoxData[
 StyleBox["30",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"1852b3af-4bec-4497-963d-5cc2974d5db8"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"5", ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", "x", " ", "y"}], "+", 
   RowBox[{"5", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.83716437748973*^9, 3.8393353275313864`*^9, 
  3.8393355557665*^9, 3.8393356705687532`*^9, 3.8393923938515253`*^9},
 CellLabel->
  "During evaluation of \
In[11]:=",ExpressionUUID->"85617552-925b-45c6-a378-cb89fe975ae8"]
}, Open  ]]
}, Open  ]],

Cell["\<\
Finally we get a  list of exercises for students. To simplify the notation in \
what follows we write f[x,y] rather then f[b,c][x,y].  We also attache an \
instruction for students (here in Polish).\
\>", "Text",
 CellChangeTimes->{{3.832683545292714*^9, 3.8326836081718283`*^9}, {
   3.837164667527117*^9, 3.8371648000492*^9}, 3.8371654936368837`*^9, {
   3.837166348592402*^9, 
   3.837166386299082*^9}},ExpressionUUID->"53b329bf-1935-47a2-bb51-\
be32a7efe310"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", " ", 
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"r", ",", "Bold"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "Print", "[", 
      "\"\<Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych funkcji f \
zmiennych rzeczywistych x, y. Oblicz hesjan.\>\"", "]"}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"Print", "[", " ", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", " ", "y"}], "]"}], " ", "==", " ", 
       RowBox[{"ReleaseHold", "[", " ", 
        RowBox[{"listoflefthandside", "[", 
         RowBox[{"[", "r", "]"}], "]"}], "]"}]}], "]"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"r", ",", " ", "1", " ", ",", " ", 
     RowBox[{"Length", "[", "listoflefthandside", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.832308794924383*^9, 3.8323087982804728`*^9}, {
   3.83231978784593*^9, 3.8323197928848844`*^9}, 3.837162369229718*^9, {
   3.8371644271172895`*^9, 3.837164427119419*^9}, {3.8371644643751326`*^9, 
   3.83716446675784*^9}, {3.837164873385379*^9, 3.8371648844508743`*^9}, {
   3.8371650529885674`*^9, 3.837165143771339*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"dcb81d5d-7f5c-46ed-8d42-116363299f6a"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["1",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923938845387`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"0569e59c-54c5-4514-87c5-c7fed5b224b0"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"9cf3ad6f-f08f-423c-86ec-bb5c20327569"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"36cc6a16-8add-4278-a32a-c770f56092fd"],

Cell[BoxData[
 StyleBox["2",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"b84fda4a-052c-41ea-98ae-f00515762be4"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"cb03dd06-5c4c-4ca3-9eeb-0f785a68a6c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"275ccac5-b265-4876-adcc-a19f2a9593c1"],

Cell[BoxData[
 StyleBox["3",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"6801fac7-fdbc-4b75-befb-24fdf75166f9"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"742d7a5e-7ead-461f-a976-d795c3cc290c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"96f73c30-30a1-4963-a11b-6932977ef839"],

Cell[BoxData[
 StyleBox["4",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"8c587b71-9572-4d27-9bf1-072ac6f6bf5f"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393900164*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"f0962a51-5590-40f7-98c7-3003dd979422"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"a505b710-3915-4bc7-97a9-1832bc5011d6"],

Cell[BoxData[
 StyleBox["5",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"69efa7db-fe1c-402e-a5a5-e7f628cfb1a8"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"82707eea-46e4-4521-a3aa-5eb7dcb6b88d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"8ff9731f-cca4-4b9b-a395-4e689fd687df"],

Cell[BoxData[
 StyleBox["6",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"160b6312-30f7-4fce-a782-37c01ce7a1c1"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"adaeed41-499d-47c1-9b98-0029fbf79fe0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"9f23c2ac-06ab-4bd9-9eaf-c8550cecd682"],

Cell[BoxData[
 StyleBox["7",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"0ac61d44-7e35-47b2-b0e5-f021a52fac35"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"93fc7808-f408-4995-91d3-b6105f58fb67"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "9"}], " ", "x", " ", "y"}], "-", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939157877`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"a8802724-3978-413a-bcbf-c1f47abf39e5"],

Cell[BoxData[
 StyleBox["8",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"e8fa05a7-c04e-434d-94c6-be5d92e58309"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"b209fd5c-f3a0-4e8b-b3d0-1debfd8525fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "9"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"d5eed40d-0601-4162-ae83-2d462f6faf02"],

Cell[BoxData[
 StyleBox["9",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"9a85efd6-a30e-4130-80e3-f57ce705a4a9"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"b1bc88db-ab21-49ec-aa70-e1f054d9679f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"0c8cde36-b154-4d10-9b9c-da676e99dfc5"],

Cell[BoxData[
 StyleBox["10",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"dd6661b2-0dd1-4551-aa1b-bb6b0349a495"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"4e237b41-38a2-4416-8817-8299192c02bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"18", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"ae82c241-ad44-4226-b623-97d71dbabba5"],

Cell[BoxData[
 StyleBox["11",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"af203b08-692e-45a7-9498-0f538d8c7132"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939314113`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"cdaa99c4-79fc-4ee7-bf40-75bb78d67b58"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"18", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939473734`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"d4757223-1637-4218-845f-f8474a1ed028"],

Cell[BoxData[
 StyleBox["12",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939473734`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"cb8981f2-7a34-43ac-8623-463ab5fb7a63"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"2d0dc357-c0ac-40c2-bf8a-e619a64b1aa7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "18"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"c6e74c7f-0af9-423c-9905-51dae9b952af"],

Cell[BoxData[
 StyleBox["13",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"008d041c-6367-463d-9248-53ca7e5371b8"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"12435e67-ba43-4c07-a2e4-674a2e568fef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "18"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"8a5fc60d-708c-4cea-b319-fe4ff6f45273"],

Cell[BoxData[
 StyleBox["14",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"20aa9b1c-30eb-4a56-bd55-e6f0abd8aaed"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"bab88d0b-2ebd-410f-9b18-b9f40af02da5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "27"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"e5fed8ab-0bb7-431c-a665-ad97e8a0b05b"],

Cell[BoxData[
 StyleBox["15",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"cccf2255-6344-4b28-bdc8-e10d92d7270b"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"975b632e-d5af-4405-b44a-2ebd8cec10d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"27", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939518957`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"a2d35f17-3844-4a27-a9ae-38dc60181856"],

Cell[BoxData[
 StyleBox["16",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"34d4cae3-fbbf-4d26-91cc-3b3c8f146e8f"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"bd92d5ac-0064-493e-aa26-8ea900be5dd8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"6711332f-54eb-40f8-9042-cb8564cdc803"],

Cell[BoxData[
 StyleBox["17",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"02618358-2079-4433-baa4-f3040bc5d84e"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"432e0a19-5b2c-4c6f-9bda-12296aa0a1ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"30cb550c-901b-4268-8cd1-197073a183b6"],

Cell[BoxData[
 StyleBox["18",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"a628486e-35d6-453b-ac90-ccef72b4ccf0"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"b27478e6-0618-4f63-a66c-daf3572a6bc5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"d9d5e7c1-0c3a-4d95-bc8a-98bd5f21245a"],

Cell[BoxData[
 StyleBox["19",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"ccec920e-dd34-40c9-88d4-87edfa48f4c2"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393967698*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"7d2ea7e3-663e-4808-9c88-5240ec0988e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"61ad9975-bb51-41c2-b69f-c8d24eae9ad8"],

Cell[BoxData[
 StyleBox["20",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"c540f962-1508-4e8f-afce-89f26e216b0a"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"015006e3-6238-44f4-9a9f-da64ece20f2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"08470814-89ea-42fe-8dcc-066f6e0ccb47"],

Cell[BoxData[
 StyleBox["21",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"4d8ccdd2-d8b9-40c4-b916-d22805659cb3"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"62c9c3b8-e24d-45c3-87b8-111e1cea2d49"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "36"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"6261b21d-bc3c-49e2-b19e-849d12b876e1"],

Cell[BoxData[
 StyleBox["22",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"38d61bf6-fefd-4f8b-b156-e9c51fd4162e"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"bd8210ef-c8d4-42e3-a4d0-db63f9cb8acd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "36"}], " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923939833403`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"413994a0-39d6-4a5f-9612-ba037fc1099a"],

Cell[BoxData[
 StyleBox["23",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"8eae8de3-d042-4c72-8df3-cd4f57844ad4"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"420a82a6-5c53-489a-b4a2-8722670a9880"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"b63de9f1-3a26-4973-aa05-0f74737674f4"],

Cell[BoxData[
 StyleBox["24",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"9a7869b8-7b08-47cc-b7ae-a1925ccd69d3"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"b2071a16-bf78-4bce-ac5b-c9fd222e3586"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"0f5ed594-4f8b-4696-a02f-45e5f09c11ac"],

Cell[BoxData[
 StyleBox["25",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"6fa2bb6f-ae44-4b14-80a0-a3c23d7f0c75"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"989cceb2-6b13-4e2e-b170-6b0d9381d19d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"cbcb7226-5ec7-4ae1-a89f-d7b68f356279"],

Cell[BoxData[
 StyleBox["26",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"f73af40d-535a-4e42-b998-c875c8c370aa"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.839392393998964*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"f7fc19ef-ab1c-4f60-b5b7-3272c28ecec8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"397787d0-3637-432b-84c9-efd5a2669497"],

Cell[BoxData[
 StyleBox["27",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"dbfb2ebe-caa7-4bca-8f1b-046608d5ad73"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"d0a7930c-d559-4c12-ba1c-8160818a3efe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"48", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"467ffa7d-07f3-4f34-8c4a-2661498efea0"],

Cell[BoxData[
 StyleBox["28",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"8a959d61-5602-49e3-870b-19fe6ed73c07"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"e7145f6f-7965-45d5-847a-febb68ed4ba0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "48"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"dae6309f-5276-40b0-91c2-2b817edf5aff"],

Cell[BoxData[
 StyleBox["29",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"ce5ff748-ada3-499e-8270-de6b396844a3"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"93d4293f-cef5-4ca4-9a3f-86de0812a1fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"5", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"7695c34b-67bb-4bdc-ba6d-199868e509ef"],

Cell[BoxData[
 StyleBox["30",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.8393923940145864`*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"5f3a795c-4d4f-4a3c-b997-2a015bce7701"],

Cell[BoxData["\<\"Zbadaj istnienie i rodzaj ekstrem\[OAcute]w lokalnych \
funkcji f zmiennych rzeczywistych x, y. Oblicz hesjan.\"\>"], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.83939239403021*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"0a4ce374-79be-4e50-83e1-d79e8acea062"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", "x", " ", "y"}], "+", 
   RowBox[{"5", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837165558572125*^9, 3.839335327674767*^9, 
  3.8393355559124627`*^9, 3.839335670723592*^9, 3.83939239403021*^9},
 CellLabel->
  "During evaluation of \
In[12]:=",ExpressionUUID->"5d1720b6-a7bb-4f91-808c-bf66236f3a0e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["For teachers", "Subsubsection",
 CellChangeTimes->{{3.8371664102043076`*^9, 
  3.837166419358734*^9}},ExpressionUUID->"3133c71c-6fc6-4639-9df9-\
771995106026"],

Cell["\<\
From now on, we create a list of answers suitable for teachers.\
\>", "Text",
 CellChangeTimes->{{3.8371665207915964`*^9, 3.837166539711507*^9}, {
  3.8371666441133747`*^9, 3.8371666883098426`*^9}, {3.837174980295334*^9, 
  3.837174986131089*^9}},ExpressionUUID->"ed468c81-00ea-4f26-9152-\
8243ec63fc7c"],

Cell["\<\
 lisofstationarypoints is a list of stationary points for successive \
functions.\
\>", "Text",
 CellChangeTimes->{{3.8326836507286882`*^9, 3.832683687831009*^9}, {
  3.8371654186138825`*^9, 3.8371654605566254`*^9}, {3.837174995967643*^9, 
  3.8371750298407173`*^9}},ExpressionUUID->"ce2802e6-fd9c-4a83-9f87-\
b0033b0d89b9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lisofstationarypoints", "  ", "=", " ", 
  RowBox[{"Table", "[", " ", 
   RowBox[{
    RowBox[{"parametricsolution", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b", " ", "->", " ", 
        RowBox[{
         RowBox[{"listofparameters", "[", 
          RowBox[{"[", "r", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
       RowBox[{"c", " ", "->", " ", 
        RowBox[{
         RowBox[{"listofparameters", "[", 
          RowBox[{"[", "r", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", "listofparameters", "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.832162952564493*^9, 3.832163106438775*^9}, {
   3.8321632689977236`*^9, 3.83216334348298*^9}, {3.832163418361325*^9, 
   3.8321634397102747`*^9}, 3.832319318059986*^9, 3.837162369289956*^9, {
   3.837165231118454*^9, 3.8371652311292315`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"e5f30780-1f03-4000-ad22-7bc51abce6e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"y", "\[Rule]", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "2"}]}], ",", 
       RowBox[{"y", "\[Rule]", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "6"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "2"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "6"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "6"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "2"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "6"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "2"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "2"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "6"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "9"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "9"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"y", "\[Rule]", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "9"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "6"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "2"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "9"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "9"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "2"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "6"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "2"}]}], ",", 
       RowBox[{"y", "\[Rule]", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "6"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "9"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "9"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "9"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "9"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "4"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "12"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "12"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"y", "\[Rule]", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "12"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "4"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "12"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "4"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "9"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "9"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "4"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "12"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "4"}]}], ",", 
       RowBox[{"y", "\[Rule]", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "12"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "9"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "4"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "12"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "4"}], ",", 
       RowBox[{"y", "\[Rule]", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "12"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "4"}], ",", 
       RowBox[{"y", "\[Rule]", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "12"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "6"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "4"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "2"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "12"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "12"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "2"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "4"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "6"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "12"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "4"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "4"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "12"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "12"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "4"}]}], ",", 
       RowBox[{"y", "\[Rule]", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "12"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "3"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "5"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "15"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "15"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", "5"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8371657056060038`*^9, 3.8393353278278465`*^9, 
  3.8393357085410185`*^9, 3.839392394051839*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"236464bf-9517-4a0d-b1f4-e1c262928054"]
}, Open  ]],

Cell["\<\
 list is the same list in a simplified form, suitable for further \
computations.\
\>", "Text",
 CellChangeTimes->{{3.832683744009405*^9, 3.8326837764212465`*^9}, {
  3.837165715325807*^9, 3.8371657708205657`*^9}, {3.8371662810329843`*^9, 
  3.8371662832384043`*^9}, {3.8371750516594267`*^9, 
  3.837175067976508*^9}},ExpressionUUID->"760432ac-ecb9-451d-bab7-\
164549d3ba2b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"list", " ", "=", " ", 
  RowBox[{"Map", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"MapAt", "[", " ", 
      RowBox[{"Last", ",", " ", "#", " ", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", " ", 
         RowBox[{"{", "2", "}"}]}], "}"}]}], "]"}], " ", "&"}], ",", " ", 
    "lisofstationarypoints", ",", " ", 
    RowBox[{"{", "2", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.832170221493647*^9, 3.8321702272897596`*^9}, {
   3.8321703186815414`*^9, 3.8321703628692665`*^9}, {3.832170552491933*^9, 
   3.832170556521537*^9}, {3.832170607305933*^9, 3.8321706268066196`*^9}, {
   3.8321706949087334`*^9, 3.8321707358707647`*^9}, {3.8321707722338333`*^9, 
   3.832170798427582*^9}, {3.832170831552524*^9, 3.8321709394720683`*^9}, {
   3.8321752434517303`*^9, 3.832175271110202*^9}, {3.832175307294478*^9, 
   3.832175334681157*^9}, 3.8321753772084007`*^9, {3.8321758380737295`*^9, 
   3.8321758623455276`*^9}, {3.832233340177168*^9, 3.8322333406202583`*^9}, {
   3.832307856993826*^9, 3.832307886737651*^9}, 3.837162369289956*^9, {
   3.837165238131713*^9, 3.837165238141976*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"54367331-7965-4f19-b037-ef051ec65307"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "12"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "12"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "9"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "12"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "12"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "15"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "15"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.837165795340887*^9, 3.8393353278441906`*^9, 
  3.8393357174012623`*^9, 3.839392394067691*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"f0630ad8-0ae1-4ed3-bd62-dc14b9e606f7"]
}, Open  ]],

Cell[TextData[{
 "We define the determinant of the Hesse matrix of the r-th function from \
listofrighthandside and ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SuperscriptBox["\[PartialD]", "2"], "f"}], 
    RowBox[{"\[PartialD]", 
     SuperscriptBox["x", "2"]}]], TraditionalForm]],ExpressionUUID->
  "10a768d8-13b2-491b-85f3-28f344f6d806"],
 " as well."
}], "Text",
 CellChangeTimes->{{3.8371752831868258`*^9, 
  3.8371754406967115`*^9}},ExpressionUUID->"fdd5a3c1-d5e6-4e24-b3e2-\
e31bb4180a89"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hesjan", "[", "r_", "]"}], "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"listofrighthandside", "[", 
       RowBox[{"[", "r", "]"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", "2"}], "}"}]}], "]"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"listofrighthandside", "[", 
       RowBox[{"[", "r", "]"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], "  ", "-", 
   SuperscriptBox[
    RowBox[{"(", " ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"listofrighthandside", "[", 
        RowBox[{"[", "r", "]"}], "]"}], ",", " ", "x", ",", "y"}], "]"}], " ",
      ")"}], "2"]}]}]], "Input",
 CellChangeTimes->{{3.8322335600951014`*^9, 3.832233603245987*^9}, 
   3.832233635084752*^9, {3.8322354183056107`*^9, 3.8322354206654005`*^9}, 
   3.8371623693938365`*^9},
 CellLabel->"In[15]:=",ExpressionUUID->"bc605c97-8131-469b-8263-29f908fc436a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fbisx", "[", "r_", "]"}], "[", 
   RowBox[{"x_", ",", " ", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"listofrighthandside", "[", 
     RowBox[{"[", "r", "]"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "2"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.832233731431588*^9, 3.8322337855507307`*^9}, 
   3.8371623693938365`*^9, {3.837165283518342*^9, 3.837165283518342*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"779f1093-bad4-4d95-a8ba-68ccc7be0533"],

Cell[TextData[{
 "hesjanandfbisx returns ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["detH", "2"], TraditionalForm]],ExpressionUUID->
  "937a50a9-8728-43d8-ae31-2942f325163b"],
 "(f) and ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SuperscriptBox["\[PartialD]", "2"], "f"}], 
    RowBox[{"\[PartialD]", 
     SuperscriptBox["x", "2"]}]], TraditionalForm]],ExpressionUUID->
  "22900efd-f7f6-4894-a005-838cba73d7d5"],
 " for each function from listofrighthandside."
}], "Text",
 CellChangeTimes->{{3.8371754984457464`*^9, 3.8371755005038795`*^9}, {
  3.837175535982584*^9, 3.8371755408546505`*^9}, {3.8371755875792956`*^9, 
  3.8371756990282335`*^9}},ExpressionUUID->"5d413c94-85c9-4040-9ac4-\
536d01251a39"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hesjanandfbisx", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"hesjan", "[", "r", "]"}], "[", 
       RowBox[{"x", ",", " ", "y"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{"fbisx", "[", "r", "]"}], "[", 
       RowBox[{"x", ",", " ", "y"}], "]"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", "listofrighthandside", "]"}]}], "}"}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.83224216539708*^9, 3.8322422269737062`*^9}, {
   3.832308069323956*^9, 3.8323080799883385`*^9}, 3.8371623693938365`*^9, {
   3.837165283518342*^9, 3.837165283518342*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"4fdf202d-559e-4544-90e7-400ef7c034ed"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "6"}], "-", 
         RowBox[{"4", " ", "x"}], "+", 
         RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "16"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "12"}], "-", 
         RowBox[{"4", " ", "x"}], "+", 
         RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"8", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"6", "+", 
         RowBox[{"2", " ", "x"}], "+", 
         RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"8", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"6", "+", 
         RowBox[{"4", " ", "x"}], "+", 
         RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"16", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"12", "+", 
         RowBox[{"4", " ", "x"}], "+", 
         RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"2", " ", "x"}], "+", 
         RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "9"}], "-", 
         RowBox[{"2", " ", "x"}], "+", 
         RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "9"}], "-", 
         RowBox[{"6", " ", "x"}], "+", 
         RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"6", " ", "x"}], "+", 
         RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"6", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"24", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"18", "+", 
         RowBox[{"4", " ", "x"}], "+", 
         RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"24", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"18", "+", 
         RowBox[{"6", " ", "x"}], "+", 
         RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"6", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "18"}], "-", 
         RowBox[{"6", " ", "x"}], "+", 
         RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "18"}], "-", 
         RowBox[{"4", " ", "x"}], "+", 
         RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "36"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "27"}], "-", 
         RowBox[{"6", " ", "x"}], "+", 
         RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"36", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"27", "+", 
         RowBox[{"6", " ", "x"}], "+", 
         RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"6", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"16", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"12", "+", 
         RowBox[{"2", " ", "x"}], "+", 
         RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "16"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "12"}], "-", 
         RowBox[{"8", " ", "x"}], "+", 
         RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"16", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"12", "+", 
         RowBox[{"8", " ", "x"}], "+", 
         RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"8", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"48", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"36", "+", 
         RowBox[{"8", " ", "x"}], "+", 
         RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"8", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"48", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"36", "+", 
         RowBox[{"6", " ", "x"}], "+", 
         RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"6", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "48"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "36"}], "-", 
         RowBox[{"6", " ", "x"}], "+", 
         RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "36"}], "+", 
          RowBox[{"6", " ", "x"}], "-", 
          RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], "-", 
      RowBox[{"48", " ", "x", " ", "y"}]}], ",", 
     RowBox[{"6", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"36", "-", 
          RowBox[{"6", " ", "x"}], "-", 
          RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], "+", 
      RowBox[{"48", " ", "x", " ", "y"}]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"24", "-", 
          RowBox[{"4", " ", "x"}], "-", 
          RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], "+", 
      RowBox[{"32", " ", "x", " ", "y"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"32", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"24", "+", 
         RowBox[{"4", " ", "x"}], "+", 
         RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"32", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"24", "+", 
         RowBox[{"8", " ", "x"}], "+", 
         RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"8", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"64", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"48", "+", 
         RowBox[{"8", " ", "x"}], "+", 
         RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"8", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "64"}], " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "48"}], "-", 
         RowBox[{"8", " ", "x"}], "+", 
         RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"20", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"15", "+", 
         RowBox[{"2", " ", "x"}], "+", 
         RowBox[{"10", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", "y"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"20", " ", "x", " ", "y"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"15", "+", 
         RowBox[{"10", " ", "x"}], "+", 
         RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
     RowBox[{"10", " ", "y"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8371758562233515`*^9, 3.8393353278933377`*^9, 
  3.839335738699069*^9, 3.8393923941156845`*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"bd09eb6a-8a0b-475a-b8f0-3feccc3aa4be"]
}, Open  ]],

Cell[TextData[{
 "Next, we want to calculate the values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["detH", "2"], TraditionalForm]],ExpressionUUID->
  "f3227e86-e9cc-438b-b8ae-6cf39c804e60"],
 "(f) and ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     SuperscriptBox["\[PartialD]", "2"], "f"}], 
    RowBox[{"\[PartialD]", 
     SuperscriptBox["x", "2"]}]], TraditionalForm]],ExpressionUUID->
  "12528151-f9fc-416b-bb00-c24bb0f9dd82"],
 "  for each function at each stationary point.  This is given by values. In \
the example under consideration each function has four stationary points."
}], "Text",
 CellChangeTimes->{{3.8371759021995287`*^9, 3.8371759360900707`*^9}, {
   3.8371759923392577`*^9, 3.837176020504326*^9}, 3.8371760823131557`*^9, {
   3.837176152419188*^9, 3.8371762074975586`*^9}, {3.837176248720398*^9, 
   3.8371762697681503`*^9}},ExpressionUUID->"b54702e7-8bc1-4eb6-a406-\
52c579057bc8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hesjanandfbisxhasz", " ", "=", " ", 
  RowBox[{"(", 
   RowBox[{"hesjanandfbisx", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", " ", "->", " ", "#1"}], ",", " ", 
      RowBox[{"y", " ", "->", " ", "#2"}]}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8322481355647388`*^9, 3.83224816298273*^9}, 
   3.8323081097357388`*^9, {3.832308199204278*^9, 3.832308207842844*^9}, {
   3.8323082530235214`*^9, 3.832308253662253*^9}, 3.8371623693938365`*^9, {
   3.837165291516343*^9, 3.837165291516343*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"932df2bc-3629-47d0-b671-b58d5ffc4fc8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "6"}], "-", 
         RowBox[{"4", " ", "#1"}], "+", 
         RowBox[{"2", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "16"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "12"}], "-", 
         RowBox[{"4", " ", "#1"}], "+", 
         RowBox[{"4", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"8", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"6", "+", 
         RowBox[{"2", " ", "#1"}], "+", 
         RowBox[{"4", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"8", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"6", "+", 
         RowBox[{"4", " ", "#1"}], "+", 
         RowBox[{"2", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"16", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"12", "+", 
         RowBox[{"4", " ", "#1"}], "+", 
         RowBox[{"4", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"2", " ", "#1"}], "+", 
         RowBox[{"6", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "9"}], "-", 
         RowBox[{"2", " ", "#1"}], "+", 
         RowBox[{"6", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "9"}], "-", 
         RowBox[{"6", " ", "#1"}], "+", 
         RowBox[{"2", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"6", " ", "#1"}], "+", 
         RowBox[{"2", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"6", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"24", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"18", "+", 
         RowBox[{"4", " ", "#1"}], "+", 
         RowBox[{"6", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"24", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"18", "+", 
         RowBox[{"6", " ", "#1"}], "+", 
         RowBox[{"4", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"6", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "18"}], "-", 
         RowBox[{"6", " ", "#1"}], "+", 
         RowBox[{"4", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "18"}], "-", 
         RowBox[{"4", " ", "#1"}], "+", 
         RowBox[{"6", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "36"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "27"}], "-", 
         RowBox[{"6", " ", "#1"}], "+", 
         RowBox[{"6", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"36", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"27", "+", 
         RowBox[{"6", " ", "#1"}], "+", 
         RowBox[{"6", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"6", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"16", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"12", "+", 
         RowBox[{"2", " ", "#1"}], "+", 
         RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "16"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "12"}], "-", 
         RowBox[{"8", " ", "#1"}], "+", 
         RowBox[{"2", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"16", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"12", "+", 
         RowBox[{"8", " ", "#1"}], "+", 
         RowBox[{"2", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"8", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"48", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"36", "+", 
         RowBox[{"8", " ", "#1"}], "+", 
         RowBox[{"6", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"8", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"48", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"36", "+", 
         RowBox[{"6", " ", "#1"}], "+", 
         RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"6", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "48"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "36"}], "-", 
         RowBox[{"6", " ", "#1"}], "+", 
         RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "36"}], "+", 
          RowBox[{"6", " ", "#1"}], "-", 
          RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], "-", 
      RowBox[{"48", " ", "#1", " ", "#2"}]}], ",", 
     RowBox[{"6", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"36", "-", 
          RowBox[{"6", " ", "#1"}], "-", 
          RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], "+", 
      RowBox[{"48", " ", "#1", " ", "#2"}]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"24", "-", 
          RowBox[{"4", " ", "#1"}], "-", 
          RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], "+", 
      RowBox[{"32", " ", "#1", " ", "#2"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"32", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"24", "+", 
         RowBox[{"4", " ", "#1"}], "+", 
         RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"32", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"24", "+", 
         RowBox[{"8", " ", "#1"}], "+", 
         RowBox[{"4", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"8", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"64", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"48", "+", 
         RowBox[{"8", " ", "#1"}], "+", 
         RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"8", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "64"}], " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "48"}], "-", 
         RowBox[{"8", " ", "#1"}], "+", 
         RowBox[{"8", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"20", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"15", "+", 
         RowBox[{"2", " ", "#1"}], "+", 
         RowBox[{"10", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", "#2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"20", " ", "#1", " ", "#2"}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"15", "+", 
         RowBox[{"10", " ", "#1"}], "+", 
         RowBox[{"2", " ", "#2"}]}], ")"}], "2"]}], ",", 
     RowBox[{"10", " ", "#2"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.837175880413027*^9, 3.839335327912094*^9, 
  3.8393357468530645`*^9, 3.8393923941473093`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"28df3850-8904-4f9c-a80f-e9a14767a1da"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"values", " ", "=", " ", 
  RowBox[{"Table", "[", " ", 
   RowBox[{
    RowBox[{"Apply", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{"hesjanandfbisxhasz", "[", 
         RowBox[{"[", "r", "]"}], "]"}], "]"}], " ", "&"}], ",", " ", 
      RowBox[{"list", "[", 
       RowBox[{"[", "r", "]"}], "]"}], ",", " ", 
      RowBox[{"{", "1", "}"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"r", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", "listofrighthandside", "]"}]}], "}"}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.832247893842261*^9, 3.8322479293811145`*^9}, {
   3.832247966676382*^9, 3.8322480501704426`*^9}, {3.8322480812629766`*^9, 
   3.832248102279417*^9}, {3.8322481761383615`*^9, 3.8322482163754845`*^9}, {
   3.8322483509048643`*^9, 3.8322483547831054`*^9}, {3.832248598547914*^9, 
   3.8322486322073245`*^9}, {3.8322487624299746`*^9, 3.832248804441973*^9}, 
   3.832249364108182*^9, {3.832308277210947*^9, 3.832308301565076*^9}, {
   3.832308377115389*^9, 3.8323083820633206`*^9}, 3.8371623694081917`*^9, {
   3.837165298290745*^9, 3.837165298292271*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"d64a38ce-31bb-4d06-9d78-b8537f45e1c9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", 
       RowBox[{"-", "24"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", 
       RowBox[{"-", "8"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", 
       RowBox[{"-", "24"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"48", ",", 
       RowBox[{"-", "8"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", 
       RowBox[{"-", "24"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", 
       RowBox[{"-", "8"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "36"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", 
       RowBox[{"-", "24"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"48", ",", 
       RowBox[{"-", "8"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "81"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", 
       RowBox[{"-", "24"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"108", ",", 
       RowBox[{"-", "8"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"108", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"108", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", 
       RowBox[{"-", "24"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"108", ",", 
       RowBox[{"-", "8"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "324"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "729"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"243", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "729"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "729"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "729"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"243", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "729"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "729"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"48", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", 
       RowBox[{"-", "96"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"48", ",", 
       RowBox[{"-", "32"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", 
       RowBox[{"-", "96"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"48", ",", 
       RowBox[{"-", "32"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", 
       RowBox[{"-", "96"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"432", ",", 
       RowBox[{"-", "32"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"432", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"432", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"432", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", 
       RowBox[{"-", "54"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"432", ",", 
       RowBox[{"-", "18"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", 
       RowBox[{"-", "24"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"192", ",", 
       RowBox[{"-", "8"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", 
       RowBox[{"-", "24"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"192", ",", 
       RowBox[{"-", "8"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", 
       RowBox[{"-", "96"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"192", ",", 
       RowBox[{"-", "32"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "576"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2304"}], ",", 
       RowBox[{"-", "96"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"768", ",", 
       RowBox[{"-", "32"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2304"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2304"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2304"}], ",", 
       RowBox[{"-", "96"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"768", ",", 
       RowBox[{"-", "32"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2304"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2304"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "225"}], ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"75", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "225"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "225"}], ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "225"}], ",", 
       RowBox[{"-", "150"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"75", ",", 
       RowBox[{"-", "50"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "225"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "225"}], ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8371760870245934`*^9, 3.8393353279296246`*^9, 
  3.839335754951976*^9, 3.839392394167448*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"3c713df1-bdab-41e6-8c40-c56d89b546d0"]
}, Open  ]],

Cell["Finally, we create a list of answers.", "Text",
 CellChangeTimes->{{3.832683979816354*^9, 3.8326839970884743`*^9}, {
  3.837176350666996*^9, 
  3.837176384236557*^9}},ExpressionUUID->"2ddbfd44-5fe5-4e83-bbbc-\
74f6e6adea5f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Print", " ", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"r", ",", " ", "18", ",", " ", "Red"}], "]"}], "]"}], ",", " ", 
     RowBox[{"Print", "[", "\"\<Function:\>\"", "]"}], ",", "  ", 
     RowBox[{"Print", "[", " ", 
      RowBox[{
       RowBox[{"listoflefthandside", "[", 
        RowBox[{"[", "r", "]"}], "]"}], " ", "==", " ", 
       RowBox[{"ReleaseHold", "[", " ", 
        RowBox[{"listoflefthandside", "[", 
         RowBox[{"[", "r", "]"}], "]"}], "  ", "]"}]}], "  ", "]"}], ",", " ", 
     RowBox[{"Print", "[", "\"\<Stationary points:\>\"", "]"}], ",", "  ", 
     RowBox[{"Print", "[", " ", 
      RowBox[{"list", "[", 
       RowBox[{"[", "r", "]"}], "]"}], " ", "]"}], ",", " ", 
     RowBox[{
     "Print", "[", 
      "\"\<Hesse det and \
\!\(TraditionalForm\`\*FractionBox[\(\*SuperscriptBox[\(\[PartialD]\), \
\(2\)]f\), \(\[PartialD]\*SuperscriptBox[\(x\), \(2\)]\)]\):\>\"", "]"}], ",",
      " ", 
     RowBox[{"Print", "[", 
      RowBox[{"hesjanandfbisx", "[", 
       RowBox[{"[", "r", "]"}], "]"}], " ", "]"}], ",", "  ", 
     RowBox[{"Print", "[", " ", "\"\<Values at stationary points:\>\"", "]"}],
      ",", "  ", 
     RowBox[{"Print", "[", " ", 
      RowBox[{"values", "[", 
       RowBox[{"[", "r", "]"}], "]"}], " ", "]"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"r", ",", " ", "1", " ", ",", " ", 
     RowBox[{"Length", "[", "listoflefthandside", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8322489085144997`*^9, 3.8322489506563206`*^9}, {
   3.832248986897545*^9, 3.8322489939062767`*^9}, {3.832249034918079*^9, 
   3.832249035131237*^9}, {3.832249086650428*^9, 3.8322490972567186`*^9}, 
   3.832249429319709*^9, {3.832308331487316*^9, 3.832308445937607*^9}, {
   3.8323084992155876`*^9, 3.83230851938795*^9}, {3.832308556826152*^9, 
   3.8323085812435193`*^9}, {3.832308666912981*^9, 3.832308671616629*^9}, {
   3.832684611694479*^9, 3.8326846685972886`*^9}, {3.8326847055732083`*^9, 
   3.8326847672849517`*^9}, {3.832923857971098*^9, 3.8329239062028503`*^9}, 
   3.832924052485112*^9, {3.8329293521424417`*^9, 3.832929352789316*^9}, 
   3.837162369420803*^9, {3.8371653101261673`*^9, 3.8371653101261673`*^9}, 
   3.8371764358712125`*^9},
 CellLabel->"In[20]:=",ExpressionUUID->"57562402-5fc0-4056-bdf8-f67fc243e0c4"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["1",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942408795`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7f466922-694a-45ca-9d5a-58da79e5f849"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942408795`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5e3faba9-78ef-40c2-80c2-807d924025cb"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942519283`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1ba1bea8-920c-44ed-9d99-ee50ac2ea525"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942519283`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"2d170b8d-b1f9-45fe-a94f-13152418460f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942519283`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"77d0fafe-c1e6-4fa3-aa91-2470e46c8c0a"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942519283`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"bd5340ed-2aa1-4538-b146-cd043134d738"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "6"}], "-", 
       RowBox[{"4", " ", "x"}], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"66b76ebf-4adb-4f6a-bb14-ddc6ba3262b6"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4e8b3a90-ad35-40a9-9547-d7f236482689"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"eb3f8376-2b9a-4288-90d9-f303a29f8488"],

Cell[BoxData[
 StyleBox["2",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"11d18684-111e-4c32-aab3-091b5e0ab163"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"75f7a4d2-17d2-4252-8c5f-e3d3a4544fe7"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"26587108-eb7d-4c81-9428-8a02c12ed619"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d7ae16ef-3c39-48c7-b906-2acf85c5c5e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7f516ca4-0cbb-4b13-b685-41e993d4be9a"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923942751684`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"486ae76f-5824-4905-8c8b-32abe829bccc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "16"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "12"}], "-", 
       RowBox[{"4", " ", "x"}], "+", 
       RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"b207d285-a4f7-4fae-b91b-884573487f77"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f4ed30b7-43d4-497f-a968-e7d7665fd01c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"8edd4580-a77e-4a4f-a1e4-4db522c36449"],

Cell[BoxData[
 StyleBox["3",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1d1ca40a-e9d1-41d8-80bd-f74a4bd12935"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e19d6409-4ca4-4086-bc83-2e80b4ac29f7"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a53082e4-5172-401d-9513-e8d37cdf6bf1"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5355cc3d-4cc1-4a11-8ce9-268cbbe0ccf2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"15bf6743-7367-43fd-8c29-13578fe01037"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394291483*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ef3f70e7-7d6a-4cda-b078-f59477799e1e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"8", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"6", "+", 
       RowBox[{"2", " ", "x"}], "+", 
       RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"2", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"10beae44-ae6a-40d6-b11a-e7b3d4af0921"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5d5f109a-b512-4343-861b-ea6bdaa96030"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4f2c4868-072f-4aa1-ae05-90086b8544d7"],

Cell[BoxData[
 StyleBox["4",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5af8640d-eeec-44cc-a552-76c5b6e85514"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"17f1fabe-9c77-46de-ad8a-bc7b510f12fd"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1559d472-f47d-49f1-9148-da9961ca641f"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"b8aeb87e-240e-4f4f-9bee-6c12e85f3077"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c232e676-a2e1-4d5c-bc8c-40f475933bec"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394305806*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d1e666bf-b45b-40c9-a65b-f4bb52406ba7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"8", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"6", "+", 
       RowBox[{"4", " ", "x"}], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"4", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ef2e2d2c-846d-4cc8-88dd-e740cfc17fb4"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e8c5e064-0b64-4219-81d2-9526d68cf469"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"2bdd3fe0-5061-40b6-a9fa-4359f12a13bd"],

Cell[BoxData[
 StyleBox["5",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"fa5612e5-a14e-48ef-ae74-02df4866d99b"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"833da214-8e72-4d4a-88f3-53dca150ebb3"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4873892a-236f-4d23-a94e-8e4153562b22"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"16a946e8-fc88-40ec-8ced-8f248d8ca409"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"0f428a8a-24d0-4419-ad38-59ebb3fc0088"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394320463*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1dc86154-d26e-458e-8122-7a58eb4c8f5c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"16", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"4", " ", "x"}], "+", 
       RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"4", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"2450e42f-88df-44c2-a17d-966ec7b5af24"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"840ed12d-8413-4c0a-963a-167a2cd3f3fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"92cc7c1a-5c67-48b9-8b78-9f2a3269de51"],

Cell[BoxData[
 StyleBox["6",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5045476b-9396-431b-8a93-7a34dd8d5561"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"bce34401-6a6d-42b4-b4d8-e74796a0d5aa"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"05709213-a3e4-4fca-8cbe-64bde91e25c1"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c39be98e-ca51-4d35-93e0-8c00e1aa8328"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"0eee461b-be7a-491d-a7c7-d9fbd273f5d7"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943353243`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7d51b46b-6686-4595-a25c-d0f00f2443d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"12", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"9", "+", 
       RowBox[{"2", " ", "x"}], "+", 
       RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"2", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ae1eae79-ccf9-4e57-84f4-448e77414cbe"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"0694dcae-b017-4079-901c-7dc89623204e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d4e83bff-492a-44aa-806c-0673948224f6"],

Cell[BoxData[
 StyleBox["7",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"b4697841-6ca6-4170-9a78-56358b9ae6ce"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"542ab23b-6cf9-44fc-8204-3f47730a4025"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "9"}], " ", "x", " ", "y"}], "-", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4825815d-4fb9-4351-8096-b28d0afd5660"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"37149703-a72c-493c-b3e7-31e431b3d5ba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7ead711a-0b43-4ee3-aed4-671c70a2e59c"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943521523`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d3f255c7-703e-4ba8-be31-eda0029a2bef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "9"}], "-", 
       RowBox[{"2", " ", "x"}], "+", 
       RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1b05eb19-4ec8-48db-a38b-7e4a57d144c1"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1360d72d-898b-441d-92c4-a93037f39eac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c343bf09-1f4c-4f01-9ec6-5049822c31e8"],

Cell[BoxData[
 StyleBox["8",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f100e8c4-ddff-4f02-8f7c-c00d9b5149e4"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"cbca8f7f-b8e7-42ce-96d4-f084177e45f4"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "9"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5bd37406-4a03-4b90-b450-73db1487aa78"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"fc60b278-5f6c-4442-a9f3-89c522dd5d3f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f30b3d2e-b621-4c99-a1dc-c716d0290020"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394365655*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1f41fddf-ddf9-4759-8c3f-18399f780dd1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "9"}], "-", 
       RowBox[{"6", " ", "x"}], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "6"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943803625`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c301c71f-41d6-48b9-9cb5-57ffdd179e6d"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943803625`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"cd55dd47-7601-409c-899b-374f1efe7388"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943803625`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a2aafd1a-7c5a-4063-b48d-b50a93e8983b"],

Cell[BoxData[
 StyleBox["9",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943803625`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"cb2152db-183d-4a67-aa3a-e16df43e30f3"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943867493`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3594b6fd-6ac6-4ba8-8d5a-10f5c75eadaf"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943867493`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3eab02a8-18e7-4bf1-af55-e00dd6c98897"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943867493`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c31727e8-9f02-4b5d-84ee-c2232bacc732"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943867493`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c8cb0751-aae6-4b6f-8e82-4be22a9970e8"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943867493`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"6f892fa9-2e61-4317-a35d-4fd01e94a8a3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"12", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"9", "+", 
       RowBox[{"6", " ", "x"}], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"6", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"277a6496-2d9a-4145-ac03-6280d034ddfb"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"627398a6-74a7-430f-91fb-fa53cf817a59"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "81"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"958a487a-2115-4d45-922b-c13e7eae962b"],

Cell[BoxData[
 StyleBox["10",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"08e20b44-c6ef-46a4-9469-d3069a7fb32b"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a2e13f42-7cca-4ee2-b221-e9245bb35d5a"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"18", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4a6a7535-20b1-4fd2-a203-0f48ab53a862"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"6129223e-52e0-4f51-983e-e7cc449ea543"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e20c1ba3-2807-4a4c-bb1c-97a52ee415f6"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923943943787`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ba3ce28f-f9d1-4c59-ab79-85f1311455e9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"24", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"4", " ", "x"}], "+", 
       RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"4", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"12bc6e11-d969-4d0e-8609-7e3c486df503"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"82e15858-f313-4c4d-bae9-7c5d8dc3adce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"108", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"015039a5-d399-421c-9e5b-32e43f6dcb1e"],

Cell[BoxData[
 StyleBox["11",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"928a7750-07e5-4992-9b0e-cf2c8cf70d2a"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7debdb26-9bba-474a-b1f2-25dbd7cc49a1"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"18", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"65c3312f-5e3d-46bf-8628-0fc9423adc4b"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"edf76857-b43f-4383-a686-93db0700dcfc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3600ac97-e9e8-44ce-9752-63499d5e776f"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394408543*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5ba02b73-8c80-441f-8fe5-9a30a2393c21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"24", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}], "+", 
       RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"6", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5f0b1bc6-9970-44d5-8062-68b9ad1fd105"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5b2c3d00-66f1-4954-bd78-cbc6806236bc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"108", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"24d5d5b6-1668-495c-a065-5d2fdb6b0891"],

Cell[BoxData[
 StyleBox["12",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"01d5a5f5-f52a-4047-8d1c-a1bc811dcb9e"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5a4e9d80-fd36-412e-bc84-32f90fd8f196"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "18"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"515c4054-fb50-4533-afe5-43f608277c57"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d45b6950-04b4-4244-a93a-91f76bbe973f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c35b8672-76af-4df5-9c42-cf25a0d503c6"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394422882*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"6e0875eb-78a0-4625-9288-d59def1653d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "24"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "18"}], "-", 
       RowBox[{"6", " ", "x"}], "+", 
       RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "6"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944376125`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c34ec656-b3cf-4741-92a5-bcd829968140"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944376125`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"830a1c99-66c5-4786-8f6c-ecc1a69ab401"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"108", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944376125`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"57d69829-189d-4883-a531-0a0023e20180"],

Cell[BoxData[
 StyleBox["13",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944376125`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"92d0ff77-22dc-46fd-bd8c-8930bc6af7ee"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944376125`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"bce78e82-5f89-4744-9a57-b476ad1a77c3"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "18"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944376125`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7c9043d0-666f-4fff-82db-6e30a1075dbb"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944376125`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3552846d-37cb-4562-82da-bd9c833012f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944376125`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"53b38449-217d-4afc-9e15-bec092f6a381"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"46a00834-6fce-434e-bc0b-f0fd22dcd516"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "24"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "18"}], "-", 
       RowBox[{"4", " ", "x"}], "+", 
       RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a71e7c6b-5adf-4fee-9e18-d650ce650490"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"9a7691c6-a07d-4bf5-b1c9-c6ca0e54f273"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"108", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"2f2fafed-7f41-4082-b35e-d2dfce5475cd"],

Cell[BoxData[
 StyleBox["14",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e73bb5ab-f0ef-473b-863f-7c4e2e605ea4"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"0bb71c9d-6923-4869-90be-625a8e070313"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "27"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5be74fd1-c6c4-4eb6-9729-83e970dc193f"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ffecac65-b705-445b-8362-b7067b4327e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"356a4eca-f4a3-4e4f-9b9e-de33bcc495f6"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394452133*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"efca83d8-f2dc-44b3-a38f-8ac1fca7802c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "36"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "27"}], "-", 
       RowBox[{"6", " ", "x"}], "+", 
       RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "6"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d38ebb88-3629-4028-bfb9-6fa24c522438"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a35b01d3-239c-4fbe-8b2e-4f9736bb7fbf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "729"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"243", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "729"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "729"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"20cc2f04-4fd0-4646-a60a-445169ab931e"],

Cell[BoxData[
 StyleBox["15",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c0e440cc-2530-421b-a914-741527b8d884"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7325c4e5-1d13-4b01-91de-0bbd8bcf3bc1"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"27", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"2e1aa563-be03-4214-a7dc-b7f755674600"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"af84c029-7624-4b97-868b-34e4be937ade"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"9c65e6bb-68d0-4208-b45a-d9f0c29753b5"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.83939239446929*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4409220e-2a71-430b-85dd-7e24b371f1ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"36", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"27", "+", 
       RowBox[{"6", " ", "x"}], "+", 
       RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"6", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"50786a8a-0bd4-441d-aa4d-ab9bcd18b3fa"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"dc0eec2d-0aa3-497b-8e73-d867ace34fba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "729"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"243", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "729"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "729"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"58b29c61-918e-43b0-be8c-37bc2de6ab9e"],

Cell[BoxData[
 StyleBox["16",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"98842ef1-f26c-42ba-90f0-5e133f8670ed"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e92e2232-9149-47bd-bde3-edb4aa8b5f82"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e5f2152a-36d0-466a-a6f0-3ab0e46f6b66"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7511954d-6900-48f0-8725-0b362639f4d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"308a3eb5-d8fc-487a-91df-51f260f4e2b9"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944826136`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"409224f3-ff35-4801-ac07-f9890c8027d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"16", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"2", " ", "x"}], "+", 
       RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"2", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"08b43553-3a46-4992-832d-f4c8e592d14b"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1c39af48-4ee8-4faf-b0b7-2a588b6f8396"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c2556daf-31c1-4c76-a1cd-c2b02aa4e0db"],

Cell[BoxData[
 StyleBox["17",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"22fba25c-83f7-49d8-90d5-9e93353007e3"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"fa6aae4c-8caf-481a-b25d-10da4510d113"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "4"}], ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a4ddeddb-3ac0-4e6d-809d-2ec5e36d7c9e"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"9ce81771-3db0-4321-94a4-54ab57f22bff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4c6eae83-0b16-40c8-93b3-f01a1059035a"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923944969225`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a122750c-dff5-4d33-b7bd-87486ffab090"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "16"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "12"}], "-", 
       RowBox[{"8", " ", "x"}], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"0055854a-ad76-4929-9c90-ed02d0d967ac"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d7ee8815-65c0-4665-91a9-b49e1dd43374"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", 
     RowBox[{"-", "96"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", 
     RowBox[{"-", "32"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3e520a8c-dabe-48e8-80a0-74cc9c3e2200"],

Cell[BoxData[
 StyleBox["18",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e68a1c4a-203c-46cc-9d72-1b900ec4e7a1"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4be747a2-73cc-4f5e-b1ce-e873da9f7849"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"4", ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"633b463d-2048-44d1-8211-80151b4b3ba9"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"de8473ac-fb19-4882-b38c-223ddb85628b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"9beb7c79-a91e-4c09-bd44-f55ea5141c85"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945111303`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ca75b7b8-1e56-4115-983b-81f23eda6153"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"16", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"8", " ", "x"}], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"8", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ef8ccc60-aacd-471a-912d-474a18249b70"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"8389de44-aa63-4025-95de-dc7091bb41ed"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", 
     RowBox[{"-", "96"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", 
     RowBox[{"-", "32"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "144"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5d6025ec-11b5-42bb-9bf8-cb8e3afc3abd"],

Cell[BoxData[
 StyleBox["19",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"92b7c51d-590e-4c69-a919-fde86ba36ae4"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"dd23fad3-7398-4dcb-8256-8151f7a20075"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"cc68b615-5ec3-4713-acdd-7586a78abe49"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"68d1aeda-5517-4112-9ece-4da157e9ed8c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f4f0479a-af07-4107-86c4-8bb5a030f153"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945263433`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"55c18e98-11e6-4386-80c4-3b8a143466f5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"48", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"36", "+", 
       RowBox[{"8", " ", "x"}], "+", 
       RowBox[{"6", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"8", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394541453*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f9f531b6-da2e-4124-8ffc-b58e5199904e"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394541453*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f5af8791-47b9-40db-9b50-16a53e10c0b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", 
     RowBox[{"-", "96"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"432", ",", 
     RowBox[{"-", "32"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394541453*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4883775b-d7f8-4e01-a39d-d08621b79e5b"],

Cell[BoxData[
 StyleBox["20",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394541453*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"156ea0be-28e7-4c0b-90c2-5cfecded9363"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394541453*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"b0ead1aa-3cb2-4ed3-a809-a5edae580d91"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394541453*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"09862362-1da1-4fc6-bfd2-6eb0cc721864"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7e093450-4175-44b1-9076-4f2923a8d0ad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"df183a7f-2355-44c2-a840-75a40ece35b7"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"bb9ee92c-3b1a-4551-b094-dc8e3fdde6c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"48", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"36", "+", 
       RowBox[{"6", " ", "x"}], "+", 
       RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"6", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"b2f8f225-e9b3-4bca-a774-2dd199900864"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"2ed5ff94-46b8-4a0d-b010-390d7c929bce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"432", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c57a36b8-2232-41c6-82c5-2d758741c584"],

Cell[BoxData[
 StyleBox["21",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"9ca2b2c6-625f-4d95-8609-5180d4631e59"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c14fe1c3-5c91-4f5f-ba73-9727ba087be1"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "36"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f62bf90b-021b-4c9c-89f6-5ab6bd32271c"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945524607`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"977872bb-0419-4297-af17-46761d707ac2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945682745`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3801e71c-1630-4724-938a-ded6f5720aaf"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945682745`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"067178dd-59f2-4602-bcb0-415df5ace681"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "48"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "36"}], "-", 
       RowBox[{"6", " ", "x"}], "+", 
       RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "6"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"8b830054-f9ed-4fb0-8801-1c332fa15c11"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a6d90110-2e59-4427-8d26-e8428216816f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"432", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ce84e981-d85c-40b4-b940-c62f03e280bd"],

Cell[BoxData[
 StyleBox["22",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"97540c7f-febc-4979-911c-36431fd79715"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7cb856fa-078b-457f-9151-338e366de964"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", 
      RowBox[{"-", "4"}]}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "36"}], " ", "x", " ", "y"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"92e0b060-2388-44ef-a07c-408b17cd158a"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d7f8899b-6546-47d0-ae95-666073defb4d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "9"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4774e95a-d1b3-46c0-a170-de6d5db8be87"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923945725393`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ac867c8d-354d-48f3-826f-e6d937e88f7d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "36"}], "+", 
        RowBox[{"6", " ", "x"}], "-", 
        RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], "-", 
    RowBox[{"48", " ", "x", " ", "y"}]}], ",", 
   RowBox[{"6", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"acff7c59-98ed-4c56-a8aa-2b56005fb74e"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a4d716db-5781-48d3-99e5-b4afaa5d58b1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"432", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e2b54c8f-f7e7-42ff-accf-d804beedbc85"],

Cell[BoxData[
 StyleBox["23",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"9235c2e0-aab9-4f21-8874-8a6b1dc97317"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"2c58b34a-3173-4174-852e-274e66a3eb44"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "4"}]}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"36", " ", "x", " ", "y"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c9a39edd-0913-49d0-a2e5-843cdb48bd37"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"902a6264-17de-457a-a2bd-bc320a8bd213"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"cbc4ff0d-91f2-4b0d-a5d9-1af1977d57f6"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394587347*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a79d1944-edb4-44aa-9ef8-ad8c377ecf42"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"36", "-", 
        RowBox[{"6", " ", "x"}], "-", 
        RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], "+", 
    RowBox[{"48", " ", "x", " ", "y"}]}], ",", 
   RowBox[{
    RowBox[{"-", "6"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3c00c56c-9d44-4690-ab3e-fba230dcd562"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"2cfe42cf-d2f2-4e85-ac52-9cdac079af61"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", 
     RowBox[{"-", "54"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"432", ",", 
     RowBox[{"-", "18"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1296"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"bf09ad26-c7b9-4b5c-a0f7-6e6e6a36ea23"],

Cell[BoxData[
 StyleBox["24",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"760db434-63fb-4d0c-b721-e886045c947b"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"9f0b89c0-8e71-451e-a7a0-eaa4888080ef"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "4"}]}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"295691e6-3672-41a5-a50d-da8c3f56337a"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"230c4aa0-0a5e-43d5-ac2b-d033afb0c9b6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3ee2d887-f868-45f0-a7d9-4c0bc4e26f12"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946020985`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"16d075d4-b06b-4999-9f37-87c7ab1f0e58"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"24", "-", 
        RowBox[{"4", " ", "x"}], "-", 
        RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], "+", 
    RowBox[{"32", " ", "x", " ", "y"}]}], ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"ce242588-76bb-499e-979a-f26991c64573"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"efc000e3-b7a4-4b53-b3f9-2853ccc2b10f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3850bb04-1bec-43e2-8e25-bcd67ba37a2d"],

Cell[BoxData[
 StyleBox["25",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"617919b0-06f1-40ea-b3ed-81ad61e6fcfd"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c5e89b2b-7f59-4922-9274-4f051ba9b48a"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7e32afea-ecd0-47d4-beb9-573f44a21532"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"c4903f0f-243f-42ee-acd3-42ff49714e06"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e8186802-9877-4683-8102-4a59d940569c"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946169696`*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"53a4d506-d734-4556-a44e-96c48cb19482"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"32", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"4", " ", "x"}], "+", 
       RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"4", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f932953a-5052-4940-bedb-fdf95287c389"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"43acf8f4-e74d-49a8-a9a2-1ac319951544"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", 
     RowBox[{"-", "24"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192", ",", 
     RowBox[{"-", "8"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"96a6b4a5-aedf-4843-a6f7-587e6044ce4e"],

Cell[BoxData[
 StyleBox["26",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a8d4905e-ae7e-4094-84bb-374ee23d6eaf"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"09b77633-cbc8-4d73-a39f-7b174019b8b0"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"24", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e30e8e30-edae-4de4-811b-a8485b1c057a"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"41bdf649-bfbc-4ecb-a896-cfae50c16b73"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"b91ae83e-61a7-4645-b7f0-a5ae523746b2"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394631738*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3a99f7ed-7883-4cdc-85c2-40ccc6fad1db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"32", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"8", " ", "x"}], "+", 
       RowBox[{"4", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"8", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394646637*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"8ca2c656-fd7b-41bc-94e1-916b20ec19fa"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394646637*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5de03faa-bbe2-4ede-94ee-760ca76a8c9f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", 
     RowBox[{"-", "96"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192", ",", 
     RowBox[{"-", "32"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "576"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394646637*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a7bae9d4-df9a-4bf8-b169-180f13dcd165"],

Cell[BoxData[
 StyleBox["27",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7fde8eb6-437b-46d1-b53e-96d26cefc720"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"93a4fa8c-4139-47f9-a478-c1fc2fe26d6c"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"4", ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"48", " ", "x", " ", "y"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"84a71d21-46a5-4cb2-8d8e-079e20326ef2"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"6dba8a6b-19bc-474e-9615-fd653c6296be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e131f22a-2c75-41b2-84c5-bcba25b66794"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"3207705e-1f7c-4e64-b08e-28a2388a0b70"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"64", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"48", "+", 
       RowBox[{"8", " ", "x"}], "+", 
       RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"8", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"1ea86163-a253-4dc9-b223-60c7aac40b4c"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"19cfabec-62eb-4be9-9969-57d814dca1b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", 
     RowBox[{"-", "96"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"768", ",", 
     RowBox[{"-", "32"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"36de8dd2-1670-4197-9497-cdd115ab6bc1"],

Cell[BoxData[
 StyleBox["28",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.8393923946528*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"d8c361b9-5d59-4e15-9d06-1f56c725e584"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"98d2ccc5-9cc1-4793-886b-c3a2dbe21452"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"-", "4"}], ",", "4"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "48"}], " ", "x", " ", "y"}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"58f4e46d-ef22-42b1-98a8-06ed35c1bc24"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"faf64e4f-e382-402c-9408-34f8184b5a39"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"5071ab02-fe3a-4a5e-b99c-4d7e8f3f0008"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"f829924f-5850-4045-b4e2-9e67b652329e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "64"}], " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "48"}], "-", 
       RowBox[{"8", " ", "x"}], "+", 
       RowBox[{"8", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"21a0ba91-d075-4a47-bba7-db1a5082f510"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"bebb5b5d-790a-4598-b257-9373549bcc15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", 
     RowBox[{"-", "96"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"768", ",", 
     RowBox[{"-", "32"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4f0ffc59-1108-4c5b-9dae-8b1e301f233f"],

Cell[BoxData[
 StyleBox["29",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394669983*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"67fcf738-f31b-4acf-a9cb-9452f65d406d"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394685607*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"a5dfff63-6ab6-4a35-85a4-ab587469d544"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "5"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", "x", " ", "y"}], "+", 
   RowBox[{
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"5", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394685607*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7dc610f2-f254-40b9-aa2a-bac42e145891"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394685607*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"b823992b-dfd5-421a-9ff4-2c30403e1915"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394685607*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e9ca615c-3a8b-49e3-8915-9fdd3afe4b00"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394685607*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"93e85755-8b0b-40ea-ab26-4ff9a589adbe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"20", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"15", "+", 
       RowBox[{"2", " ", "x"}], "+", 
       RowBox[{"10", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"2", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394685607*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"dd09b23e-bd85-46eb-bcf4-d1ede7abb683"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394685607*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"e0f590f4-c541-42aa-864f-0c54d936453b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "225"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"75", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "225"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "225"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394685607*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4460752e-9d74-4d96-b03e-2a150d179ed6"],

Cell[BoxData[
 StyleBox["30",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"8bf9be6a-bfc3-41c7-a297-5566f0419672"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7a616f1e-7572-4b43-a10d-e937a683472a"],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"5", ",", "1"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}],
   HoldForm], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", "x", " ", "y"}], "+", 
   RowBox[{"5", " ", 
    SuperscriptBox["x", "2"], " ", "y"}], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"bf263582-34de-41bf-8716-40007a566c9f"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"073c441b-5ed8-4ab1-9e3e-6687188ee3b0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "15"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7e08d897-0739-4e88-a500-3051dee9349c"],

Cell[BoxData["\<\"Hesse det and \
\\!\\(TraditionalForm\\`\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\),\
 \\(2\\)]f\\), \\(\[PartialD]\\*SuperscriptBox[\\(x\\), \
\\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"7aa729cc-a416-4a58-9a76-376b1747749f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"20", " ", "x", " ", "y"}], "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"15", "+", 
       RowBox[{"10", " ", "x"}], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}], "2"]}], ",", 
   RowBox[{"10", " ", "y"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"bee4f5a4-09a4-4322-8037-a8a487e78679"],

Cell[BoxData["\<\"Values at stationary points:\"\>"], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"6909481a-dede-41ac-9b74-318eb47d53c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "225"}], ",", 
     RowBox[{"-", "150"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"75", ",", 
     RowBox[{"-", "50"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "225"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "225"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.837176529102041*^9, 3.8393353280099955`*^9, 
  3.8393357625835133`*^9, 3.839392394701372*^9},
 CellLabel->
  "During evaluation of \
In[20]:=",ExpressionUUID->"4b99112d-e22e-44be-82b4-9a6cdc1e9e78"]
}, Open  ]]
}, Open  ]],

Cell["Clear all definitions", "Text",
 CellChangeTimes->{{3.8393343637361555`*^9, 
  3.8393343733736205`*^9}},ExpressionUUID->"aaa64169-d3b4-4604-b117-\
bb6607ba1ff3"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "listofparameters", ",", "listofrighthandside", " ", ",", 
   "listofheads", ",", "listoflefthandside", " ", ",", 
   "lisofstationarypoints", " ", ",", "list", ",", "fbisx", ",", " ", 
   "hesjan", ",", "hesjanandfbisx", ",", "hesjanandfbisxhasz", " ", ",", " ", 
   "values"}], "]"}]], "Input",
 CellChangeTimes->{{3.8393343764978204`*^9, 3.839334415772766*^9}, {
  3.8393344461641817`*^9, 3.839334452463455*^9}, {3.83933454579745*^9, 
  3.839334579810978*^9}, {3.839334616393729*^9, 3.839334622438709*^9}, {
  3.8393346573986125`*^9, 3.8393346705445857`*^9}, {3.8393347151743507`*^9, 
  3.8393347235100803`*^9}, {3.8393348062972684`*^9, 3.839334812265832*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"c51b4fe5-8a40-4ff0-b6ab-20e6389f0b09"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 2", "Section",
 CellChangeTimes->{{3.832149173139254*^9, 3.83214917697956*^9}, 
   3.8329088701407237`*^9, {3.837528327877081*^9, 
   3.8375283313013105`*^9}},ExpressionUUID->"885f9177-28f9-4ff7-b1fc-\
8d088038493e"],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsubsection",
 CellChangeTimes->{{3.8323168294764795`*^9, 3.8323168326644735`*^9}, {
  3.837528335736534*^9, 
  3.837528340425815*^9}},ExpressionUUID->"622af1b7-37ab-4ec4-941e-\
fdb70e1a22b7"],

Cell[TextData[{
 "Define the function f[x,y] == a ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "3"], " ", "+", " ", 
    RowBox[{"b", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], " ", "+", " ", 
    RowBox[{"c", " ", 
     SuperscriptBox[
      RowBox[{"x", " "}], "2"]}]}], TraditionalForm]],ExpressionUUID->
  "9becf6e4-422c-4337-8a5e-64ea807c5a88"],
 "+ d ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "2"], TraditionalForm]],ExpressionUUID->
  "493e8436-c582-477b-af78-fdf2a1034198"],
 ", where a, b, c, d, are real parameters. We want to investigate the local \
extrema of f."
}], "Text",
 CellChangeTimes->{{3.835241776184247*^9, 3.8352418773911734`*^9}, {
   3.835242051715314*^9, 3.8352420786100163`*^9}, 3.8371566769806385`*^9, {
   3.837528358771428*^9, 3.83752838486421*^9}, {3.8375284169132223`*^9, 
   3.8375284995689597`*^9}},ExpressionUUID->"e3b38c36-e286-4897-a186-\
3e70f05123b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["x", "3"]}], "+", 
   RowBox[{"b", " ", "x", " ", 
    SuperscriptBox["y", "2"]}], " ", "+", " ", 
   RowBox[{"c", " ", 
    SuperscriptBox["x", "2"]}], " ", "+", " ", 
   RowBox[{"d", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.8352419053070917`*^9, 3.835241920695975*^9}, {
  3.835254982257028*^9, 3.835255007250967*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"d3787089-89d8-458e-89cb-4dee8443e5eb"],

Cell["\<\
For a given values of a, b, c, d  we want to make the numerical computations \
as simply as possible.\
\>", "Text",
 CellChangeTimes->{{3.8352420394079394`*^9, 3.835242041312892*^9}, {
  3.835242090302553*^9, 3.835242122621986*^9}, {3.8352421728560905`*^9, 
  3.8352422030416975`*^9}, {3.8371566962706795`*^9, 
  3.837156697483801*^9}},ExpressionUUID->"0db2660a-5de3-4663-86fe-\
9525b4068d2a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", "x"}], "]"}], "\[Equal]", " ", 
     "0"}], " ", "&&", "  ", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}], "\[Equal]", "0"}], 
    " ", "&&", " ", 
    RowBox[{"a", " ", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"b", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"c", " ", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"d", " ", "=!=", "0"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.832148199112403*^9, 3.8321483076925716`*^9}, {
  3.8352419559656067`*^9, 3.8352419919327536`*^9}, {3.835242234095152*^9, 
  3.835242245485901*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"946e0e6e-e622-4d40-ac00-8a1a0020e4f1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "c"}], 
        RowBox[{"3", " ", "a"}]]}]}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["d", "b"]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         RowBox[{
          RowBox[{"2", " ", "b", " ", "c", " ", "d"}], "-", 
          RowBox[{"3", " ", "a", " ", 
           SuperscriptBox["d", "2"]}]}]], 
        SuperscriptBox["b", 
         RowBox[{"3", "/", "2"}]]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["d", "b"]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", "b", " ", "c", " ", "d"}], "-", 
         RowBox[{"3", " ", "a", " ", 
          SuperscriptBox["d", "2"]}]}]], 
       SuperscriptBox["b", 
        RowBox[{"3", "/", "2"}]]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.832148320769314*^9, 3.8323091139407825`*^9, 3.8323159946312323`*^9, 
   3.8323183288987217`*^9, 3.83231951521558*^9, 3.832647216915476*^9, 
   3.8329088795150785`*^9, 3.832924026925462*^9, 3.8335965095822887`*^9, 
   3.833596603276596*^9, {3.8352422210781093`*^9, 3.8352422484794254`*^9}, 
   3.8352551905244446`*^9, 3.835263914441574*^9, 3.8393358267115235`*^9, 
   3.839336370869193*^9, 3.83939239478529*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"bef50dba-c7d4-4d91-b50e-5f219c40abde"]
}, Open  ]],

Cell["Suppose 3a|c and b|d and put ", "Text",
 CellChangeTimes->{{3.8352423134279876`*^9, 3.8352423278152494`*^9}, {
   3.835242362471619*^9, 3.83524240286347*^9}, 3.8352530327278433`*^9, {
   3.8371588496947503`*^9, 
   3.8371588677400837`*^9}},ExpressionUUID->"18708309-7b01-4115-ae68-\
b5052f5b6ec6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["x", "3"]}], "+", 
   RowBox[{"b", " ", "x", " ", 
    SuperscriptBox["y", "2"]}], " ", "+", " ", 
   RowBox[{"c", " ", "3", " ", "a", " ", 
    SuperscriptBox["x", "2"]}], " ", "+", " ", 
   RowBox[{"d", " ", "b", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.8352424241790757`*^9, 3.8352424405893717`*^9}, {
  3.8352549850615597`*^9, 3.835255004306604*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"01172021-977f-4b70-877e-118a2d9d6fb0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", "x"}], "]"}], "\[Equal]", " ", 
     "0"}], " ", "&&", "  ", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}], "\[Equal]", "0"}], 
    " ", "&&", " ", 
    RowBox[{"a", " ", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"b", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"c", " ", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"d", " ", "=!=", "0"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[25]:=",ExpressionUUID->"e855303e-4c11-4e86-91a9-f15ef7bf5d1d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "c"}]}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", "d"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox["3"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", "a", " ", "c", " ", "d"}], "-", 
           RowBox[{"a", " ", 
            SuperscriptBox["d", "2"]}]}]]}], 
        SqrtBox["b"]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", "d"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      FractionBox[
       RowBox[{
        SqrtBox["3"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"2", " ", "a", " ", "c", " ", "d"}], "-", 
          RowBox[{"a", " ", 
           SuperscriptBox["d", "2"]}]}]]}], 
       SqrtBox["b"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8352424644666243`*^9, 3.8352551905778856`*^9, 
  3.83526391450293*^9, 3.8393358267509303`*^9, 3.8393363709199886`*^9, 
  3.8393923948141775`*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"4912db0c-4328-49ee-b550-2ba862199c54"]
}, Open  ]],

Cell["Finally suppose b|ad and put", "Text",
 CellChangeTimes->{{3.835242473473897*^9, 3.835242498104439*^9}, {
  3.8371588814146256`*^9, 
  3.837158887412555*^9}},ExpressionUUID->"3f70fffd-c420-4b0f-a149-\
fa03accc1cdc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["x", "3"]}], "+", 
   RowBox[{"a", " ", "d", " ", "x", " ", 
    SuperscriptBox["y", "2"]}], " ", "+", " ", 
   RowBox[{"c", " ", "3", " ", "a", " ", 
    SuperscriptBox["x", "2"]}], " ", "+", " ", 
   RowBox[{"d", " ", "a", " ", "d", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.835242554738243*^9, 3.8352425628379307`*^9}, {
  3.835242592977634*^9, 3.835242593948513*^9}, {3.8352549882538853`*^9, 
  3.835255013261032*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"a4496ed6-e69d-475b-ad22-6647968b5cf2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", "x"}], "]"}], "\[Equal]", " ", 
     "0"}], " ", "&&", "  ", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}], "\[Equal]", "0"}], 
    " ", "&&", " ", 
    RowBox[{"a", " ", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"b", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"c", " ", "=!=", "0"}], " ", "&&", " ", 
    RowBox[{"d", " ", "=!=", "0"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.832148199112403*^9, 3.8321483076925716`*^9}, {
   3.8321484001531744`*^9, 3.8321484321034784`*^9}, {3.832148473551338*^9, 
   3.832148476742898*^9}, 3.835242659915744*^9},
 CellLabel->"In[27]:=",ExpressionUUID->"421315a8-e0cc-4661-b6b2-5e1ed100d488"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", "d"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", "c"}], "-", "d"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", "d"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       SqrtBox["3"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", "c"}], "-", "d"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "c"}]}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8321484935732985`*^9, 3.8323091194234343`*^9, 
  3.832316136299695*^9, 3.8323183290517683`*^9, 3.83231951537372*^9, 
  3.8326472170726075`*^9, 3.8329088796335373`*^9, 3.8329240270396767`*^9, 
  3.8335965097585993`*^9, 3.8335966035370936`*^9, 3.835242626446978*^9, 
  3.835242667484406*^9, 3.835255190628663*^9, 3.835263914555894*^9, 
  3.8393358267714677`*^9, 3.8393363709345655`*^9, 3.8393923948422136`*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"96ea9710-7139-47ce-bb44-cd6f164df9a0"]
}, Open  ]],

Cell["\<\
Now, if c, d are integers, then the coordinates of stationary points are \
integers and the square roots of them.\
\>", "Text",
 CellChangeTimes->{{3.8352531444980974`*^9, 
  3.8352532289869194`*^9}},ExpressionUUID->"478e9607-6c3a-4c0a-b4cd-\
9c86fb265c34"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parametricsolution", " ", "=", " ", 
  RowBox[{"Solve", "[", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", "x"}], "]"}], "\[Equal]", " ", 
      "0"}], " ", "&&", "  ", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}], "\[Equal]", "0"}],
      " ", "&&", "  ", 
     RowBox[{"a", " ", "=!=", "0"}], " ", "&&", " ", 
     RowBox[{"b", "=!=", "0"}], " ", "&&", " ", 
     RowBox[{"c", " ", "=!=", "0"}], " ", "&&", " ", 
     RowBox[{"d", " ", "=!=", "0"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.832148199112403*^9, 3.8321483076925716`*^9}, {
   3.8321484001531744`*^9, 3.8321484321034784`*^9}, {3.832148473551338*^9, 
   3.832148476742898*^9}, {3.83230913662134*^9, 3.832309162159271*^9}, {
   3.8323092036576943`*^9, 3.8323092053441563`*^9}, {3.832318925601573*^9, 
   3.832318936293353*^9}, {3.835255062249518*^9, 3.835255071240465*^9}, 
   3.835255247694561*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"2fce0eec-697a-493c-b78c-c3c015912d51"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", "d"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["3"]}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", "c"}], "-", "d"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", "d"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       SqrtBox["3"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", "c"}], "-", "d"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "c"}]}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.83230917453312*^9, 3.8323092149064984`*^9, 
  3.8323168120912733`*^9, 3.8323183290930996`*^9, 3.832319515414098*^9, 
  3.8326472171192923`*^9, 3.832908879656453*^9, 3.832924027047157*^9, 
  3.833596509809003*^9, 3.8335966035586853`*^9, 3.835255190628663*^9, 
  3.8352552566504593`*^9, 3.8352639146009035`*^9, 3.8393358268143806`*^9, 
  3.8393363709784265`*^9, 3.839392394853619*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"5cb787ea-b8ce-47bd-b40e-f042891a63a4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "f", " ", "]"}]], "Input",
 CellChangeTimes->{{3.835255379228957*^9, 3.8352553852180395`*^9}, {
   3.8393348365246673`*^9, 3.83933484825471*^9}, 3.8393363487127085`*^9},
 CellLabel->"In[29]:=",ExpressionUUID->"5aee0914-09b8-4385-8dba-ee28124df196"]
}, Open  ]],

Cell[CellGroupData[{

Cell["For students", "Subsubsection",
 CellChangeTimes->{{3.832316839074002*^9, 3.8323168446346693`*^9}, {
  3.837528798596901*^9, 
  3.837528807319236*^9}},ExpressionUUID->"949c252c-2f0a-4cc6-8b41-\
a7b6e93eef30"],

Cell[TextData[{
 "In what follows, we deal with the function f[c,d][x,y] == ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    RowBox[{"d", " ", "x", " ", 
     SuperscriptBox["y", "2"]}], "+", 
    RowBox[{"3", " ", "c", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["d", "2"], 
     SuperscriptBox["y", "2"], " "}]}], TraditionalForm]],ExpressionUUID->
  "0e408f26-4680-4196-bc68-90eaf36fedb6"],
 ", with non-zero c, d."
}], "Text",
 CellChangeTimes->{{3.8352535142264853`*^9, 3.8352535855337267`*^9}, {
   3.8352536627650223`*^9, 3.83525368425778*^9}, {3.8375285365083747`*^9, 
   3.8375286113168592`*^9}, {3.83752867489102*^9, 3.83752870416381*^9}, 
   3.8375287571653423`*^9},ExpressionUUID->"5f827fc2-d9c4-4840-be2e-\
1f4cfe9a96e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"c_", ",", "d_"}], "]"}], "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", "+", " ", 
   RowBox[{"d", " ", "x", " ", 
    SuperscriptBox["y", "2"]}], " ", "+", " ", 
   RowBox[{"3", " ", "c", " ", 
    SuperscriptBox["x", "2"]}], " ", "+", " ", 
   RowBox[{
    SuperscriptBox["d", "2"], " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.832316924468848*^9, 3.832317019446293*^9}, 
   3.832317277289123*^9},
 CellLabel->"In[30]:=",ExpressionUUID->"e931853d-de62-4b80-8b47-ad7ac0155b7a"],

Cell["\<\
Moreover, we have to define our own list of parameters listofparameters of \
arbitrary length. For example\
\>", "Text",
 CellChangeTimes->{{3.8352538887590203`*^9, 3.8352540073827405`*^9}, {
  3.835255418993602*^9, 3.835255445388098*^9}, {3.835264042288595*^9, 
  3.83526405164909*^9}},ExpressionUUID->"db6d330e-1e44-4b99-91eb-\
151f15203105"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"listofparameters", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], ",", "  ", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "2"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"-", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"-", "3"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"-", "4"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2"}], ",", 
      RowBox[{"-", "4"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"-", "2"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"-", "4"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"5", ",", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"5", ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"5", ",", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"5", ",", "4"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.8352554697910385`*^9, 3.8352554709781456`*^9}, 
   3.8393342288414903`*^9},
 CellLabel->"In[31]:=",ExpressionUUID->"97187457-9be8-48c8-8b55-75549b615377"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "4"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.835255473048356*^9, 3.835262603925962*^9, 
  3.835264459903614*^9, 3.839336381510044*^9, 3.8393923948872347`*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"6040f1e0-9224-4c59-9d2e-af685e173749"]
}, Open  ]],

Cell["The length of listofparameters is", "Text",
 CellChangeTimes->{{3.839391340893814*^9, 
  3.839391365512048*^9}},ExpressionUUID->"c2b10984-4e39-46a2-9317-\
cf5dfd43df4a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "listofparameters", "]"}]], "Input",
 CellChangeTimes->{{3.839336309669774*^9, 3.839336320938218*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"be4c2016-44c8-4300-b394-63dfa093956c"],

Cell[BoxData["30"], "Output",
 CellChangeTimes->{3.839336381510044*^9, 3.839392394902858*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"4d513246-0e76-4770-a75c-dc86be979fd1"]
}, Open  ]],

Cell["\<\
From now on we write f[x,y] rather then f[c,d][x,y].
We define two function that act on listofparameters. The first one returns a \
list of exercises for students together with instruction. The second one \
returns a list of respective answers needed for a teacher. \
\>", "Text",
 CellChangeTimes->{{3.835253699494502*^9, 3.835253728705638*^9}, {
  3.83526399117238*^9, 3.835264021320522*^9}, {3.8352640746051593`*^9, 
  3.835264157108657*^9}, {3.8352642715201483`*^9, 3.8352643426262155`*^9}, {
  3.835264423374675*^9, 3.835264433529355*^9}, {3.8393914460810957`*^9, 
  3.8393915050618753`*^9}},ExpressionUUID->"6fc9cf26-e45f-44ce-8c69-\
c24954305829"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ForStudents", "[", "xxx__", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "  ", 
     RowBox[{
     "listofrighthandside", " ", ",", "  ", "listofheads", " ", ",", " ", 
      "listoflefthandside", " ", ","}], 
     "                                                                        \
                 ", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"listofrighthandside", " ", "=", " ", 
      RowBox[{"Apply", "[", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"#1", ",", "#2"}], "]"}], "[", 
          RowBox[{"x", ",", "y"}], "]"}], "&"}], ",", "xxx", "  ", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}]}], ";", " ", 
     RowBox[{"listofheads", " ", "=", " ", 
      RowBox[{"Apply", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", " ", "xxx", " ", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}]}], ";", 
     RowBox[{"listoflefthandside", " ", "=", " ", 
      RowBox[{"Map", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"HoldForm", "[", 
          RowBox[{"#", " ", "[", 
           RowBox[{"x", ",", "y"}], "]"}], "]"}], "&"}], ",", " ", 
        "listofheads"}], "]"}]}], ";", " ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"r", ",", "Bold"}], "]"}], "]"}], ",", " ", 
         RowBox[{
         "Print", "[", 
          "\"\<Dana jest funkcja f zmiennych x, y, zale\:017cna od \
dw\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \!\(\*SuperscriptBox[\(x\), \
\(3\)]\) + d x \!\(\*SuperscriptBox[\(y\), \(2\)]\) + 3 c \
\!\(\*SuperscriptBox[\(x\), \(2\)]\) + \!\(\*SuperscriptBox[\(d\), \(2\)]\) \
\!\(\*SuperscriptBox[\(y\), \(2\)]\). Zbadaj istnienie ekstrem\[OAcute]w \
lokalnych funkcji f. Oblicz hesjan.\>\"", "]"}], ",", " ", 
         RowBox[{"Print", "[", " ", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x", ",", "y"}], "]"}], " ", "==", " ", 
           RowBox[{"ReleaseHold", "[", " ", 
            RowBox[{"listoflefthandside", "[", 
             RowBox[{"[", "r", "]"}], "]"}], "]"}]}], "]"}]}], "}"}], ",", 
       " ", 
       RowBox[{"{", 
        RowBox[{"r", ",", "1", " ", ",", " ", 
         RowBox[{"Length", "[", "listoflefthandside", "]"}]}], "}"}]}], 
      "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.835255955127578*^9, 3.83525597577102*^9}, {
   3.8352560579973345`*^9, 3.8352561208997*^9}, {3.839336078141315*^9, 
   3.8393360876656623`*^9}, {3.839336232198786*^9, 3.839336239606126*^9}, 
   3.8393915142919593`*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"898b8691-7b88-4d87-8317-9c10a3759e17"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ForStudents", "[", "listofparameters", "]"}]], "Input",
 CellChangeTimes->{{3.8352561526873507`*^9, 3.8352561783602576`*^9}, 
   3.839391520992201*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->"In[34]:=",ExpressionUUID->"05da9260-adfa-4622-893f-8e0d1572532e"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["1",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392394934104*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"19d165e7-eb27-495e-b4d8-1d7c0bcab9f3"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392394934104*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"496742c6-71d1-4683-b599-d44be0b3f997"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392394934104*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"90545b66-5134-4afb-a19c-9c4c2df250eb"],

Cell[BoxData[
 StyleBox["2",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392394934104*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"f714b6f6-0cb1-4931-82b6-c1dd8679a318"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392394934104*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"26b4dd7c-83aa-47e3-9ff6-43ededcbe8d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392394934104*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"e6ca8327-7b9b-42d5-bb3c-4aa216893240"],

Cell[BoxData[
 StyleBox["3",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392394949733*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"b448f4eb-885c-4df2-a3a2-3dde841e7b7e"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392394949733*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"b29598a2-befa-4b2e-9c98-4dc23f1714f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"4725a1ba-100b-4a7b-8e21-1e4aa49f4bb1"],

Cell[BoxData[
 StyleBox["4",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"70876fd3-bf90-4ee1-986f-ff0dc85e977b"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"36720242-9974-4966-b81e-2c11a9de9b10"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"0cb7b3f4-531f-41d1-b753-1adfe7487c21"],

Cell[BoxData[
 StyleBox["5",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"26ede2dd-7724-4ffb-903f-a03cd481862b"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"6b8084f5-bd76-465f-afcd-d15e33720ca8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"d387e872-f0fb-4730-8152-dd1a47cdeda7"],

Cell[BoxData[
 StyleBox["6",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"6d15d902-e04c-40ca-843c-37c723758db0"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949532394`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"d8904b39-606d-45ea-81a8-04dde17d0281"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"7bc33986-8238-4b1f-a5ce-27b1cbfa4be6"],

Cell[BoxData[
 StyleBox["7",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"0e5a42e7-43c8-442f-b196-41aad19fe8e2"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"f3ebe622-d95e-4a44-8ccd-b394499e0192"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"c4855160-68a1-4811-87d4-0c116ada3025"],

Cell[BoxData[
 StyleBox["8",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"28fc7554-fe14-4b66-9144-717b72e3b27b"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"008f32da-d702-4272-97fb-21f509212746"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"d940c1f4-d286-4895-a106-b7604e664519"],

Cell[BoxData[
 StyleBox["9",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"3ec15b65-1c06-4e15-ba29-8072bde48b3a"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923949695187`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"54b81315-6a72-498b-b480-62446cbe0497"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"1c2ba4fe-7300-4432-813a-9dc9f65ba02e"],

Cell[BoxData[
 StyleBox["10",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"329f6364-0b19-4baf-8d86-6c82d3bd49ac"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"52cea06f-6876-4db6-a2d4-82f27df9ce2f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"253e5d15-0f2a-4037-b1bd-99341a83bb36"],

Cell[BoxData[
 StyleBox["11",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"13a9950c-e265-4dc3-8d43-3f31f4f96218"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"604b4718-db87-41ed-b36d-c4e7eddd88bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"72e1614e-d749-4a6c-9ee6-db256b5b02fe"],

Cell[BoxData[
 StyleBox["12",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"3e0034c1-ce3d-4701-b4aa-b89de603ace8"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.83939239498518*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"87383d77-5034-42e7-9614-b1e3b9bc1b44"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"16846b5c-2faf-4e6f-a6f4-5e81f635ebe6"],

Cell[BoxData[
 StyleBox["13",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"142f6d10-45ff-44d9-adc2-b5fcef068066"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"a17acb11-813e-48a4-8992-29f714c048a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"781cebb6-fa1a-419e-a7ae-98e9359dd948"],

Cell[BoxData[
 StyleBox["14",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"69dbec10-d395-4706-88ec-0340f444ba7e"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"870fc76e-f672-43a0-a207-100ad636a0de"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"f588b61f-24f9-472e-a58a-9a619c385d67"],

Cell[BoxData[
 StyleBox["15",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"6dcb0435-d937-4e88-b296-02744a4b0650"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395001974*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"92e8b14b-081e-4903-8cdb-712f5ae0c4c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"d2316235-a01e-4bc3-96ba-1facbd4af057"],

Cell[BoxData[
 StyleBox["16",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"6dc097f8-72b2-4fac-956f-62bdd7781dbd"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"e6c22bda-a399-4ee5-a192-46f52f8b0720"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"c44069a4-4bbf-4fbf-8bed-2e2fd21aaca1"],

Cell[BoxData[
 StyleBox["17",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"312f6b2d-9910-470c-8e14-81842107a233"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"2d9b8f9e-beec-4996-9e16-61eb1d253037"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"0b0ed190-30b3-4368-bc95-b56e3440d326"],

Cell[BoxData[
 StyleBox["18",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"68a646c4-2eda-4a40-bae5-160e1848fae8"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"a193a96a-3f39-4e53-993e-a72ca2d4bc61"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395017606*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"5490857e-7ee1-4ab4-af88-4f49eba5f38e"],

Cell[BoxData[
 StyleBox["19",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"09660aa6-eecb-4ed5-be92-140cd9d61664"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"835589bb-e55c-40a8-ab74-02d32edcc7af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"24975730-6a3d-4735-8609-26835fea6e86"],

Cell[BoxData[
 StyleBox["20",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"5a1e3003-c218-41ef-b191-418cfd467774"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"1a9b8ead-8890-4a9c-9ce5-c0dacb87832c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"1c30e84d-8d81-4f9f-8968-4b619b4ed051"],

Cell[BoxData[
 StyleBox["21",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"2298a32d-e407-4d9d-8d29-7822f1807af1"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"9f04e8c9-f091-413c-8a3a-1bf9f8183c80"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950332685`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"b4c1fad8-3ee1-4de9-b89c-f68f1370a4ea"],

Cell[BoxData[
 StyleBox["22",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395048847*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"7e202ce2-d639-4d93-8c45-7b9cf565831d"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395048847*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"f098b4d2-40df-4a7b-997d-f0d8cbf6e666"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395048847*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"6ce544de-5e29-4731-ad9e-b9e706960722"],

Cell[BoxData[
 StyleBox["23",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"484b76c2-3c4b-4fe4-890a-58d58c30dbce"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"c0114737-fee5-4fae-81aa-eedf6517d8ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"6cc83c85-d62c-4073-8511-85b3129e5e37"],

Cell[BoxData[
 StyleBox["24",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"e97ca0b9-754c-444c-9c24-f702b60e34da"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"1c0a83e0-ff0c-455f-9cf4-7b6b858690a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"21ff4474-a55d-496c-bcd4-86e62f7904d6"],

Cell[BoxData[
 StyleBox["25",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"593d7f8b-078d-4e3e-9082-7fa12fc32240"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"71395f0d-c892-437c-ae9c-526cc6c154ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950533547`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"ebadda24-b0d6-4ef2-a2f9-af20685d55c9"],

Cell[BoxData[
 StyleBox["26",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"3e727dfd-664f-46eb-89bd-59d9cdb09767"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"702d06db-fdd0-4821-8ca8-cbb6e7bb448d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"b88964e3-9567-4df6-a3aa-afc5dcffc9d7"],

Cell[BoxData[
 StyleBox["27",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"20296f92-d1db-4d99-bc3f-9994bdb38622"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"19a61fb5-aeda-49bb-9bd2-0701f7ad2f1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"68a9fbb9-6dd6-4fc8-9e70-00fcf87ea9fa"],

Cell[BoxData[
 StyleBox["28",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"081f659d-60e4-46c6-acb5-87251e1f3ff0"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"8599fc94-fcf3-4008-9db0-ae43b7d045e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.8393923950696735`*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"13b57719-239f-421a-9a42-5e5b3fa65413"],

Cell[BoxData[
 StyleBox["29",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395085973*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"36cf8ef4-5950-40a6-a045-11f95d1e1b92"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395085973*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"34a3f105-b35b-4fb2-9374-33f755ca72eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395085973*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"0b5fb103-95c3-4f3f-8a93-c76eec8f7668"],

Cell[BoxData[
 StyleBox["30",
  StripOnInput->False,
  FontWeight->Bold]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395085973*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"1801378e-b5af-4e75-8984-3556c8cc8efc"],

Cell[BoxData["\<\"Dana jest funkcja f zmiennych x, y, zale\:017cna od dw\
\[OAcute]ch parametr\[OAcute]w c, d: f[x,y] == \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(3\\)]\\) + d x \
\\!\\(\\*SuperscriptBox[\\(y\\), \\(2\\)]\\) + 3 c \
\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\) + \
\\!\\(\\*SuperscriptBox[\\(d\\), \\(2\\)]\\) \\!\\(\\*SuperscriptBox[\\(y\\), \
\\(2\\)]\\). Zbadaj istnienie ekstrem\[OAcute]w lokalnych funkcji f. Oblicz \
hesjan.\"\>"], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395085973*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"54e29a68-3c08-41de-9476-20206e24fb96"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.835256190494114*^9, 3.8352645093145266`*^9, 
  3.8393363817278223`*^9, 3.839392395085973*^9},
 FontColor->RGBColor[0., 0., 0.],
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"100fb36f-ebfd-4084-b983-d76bcc451661"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["For teachers", "Subsubsection",
 CellChangeTimes->{{3.835260627552412*^9, 
  3.835260639448718*^9}},ExpressionUUID->"5809a7f1-5eed-4ba9-b7b8-\
ecfe235a1047"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ForTeachers", "[", "xxx__", "]"}], " ", ":=", 
  RowBox[{"Module", "[", " ", 
   RowBox[{
    RowBox[{"{", "  ", 
     RowBox[{
     "parametricsolution", ",", " ", "lisofstationarypoints", " ", ",", 
      "list", ",", "listofrighthandside", " ", ",", "listofheads", ",", 
      "listoflefthandside", " ", ",", "hesjanandfbisx", " ", ",", 
      "hesjanandfbisxhasz", ",", " ", "values"}], 
     "                              ", "}"}], ",", " ", 
    RowBox[{
     RowBox[{"parametricsolution", " ", "=", " ", 
      RowBox[{"Solve", "[", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"f", "[", 
              RowBox[{"c", ",", "d"}], "]"}], "[", 
             RowBox[{"x", ",", "y"}], "]"}], ",", "x"}], "]"}], "\[Equal]", 
          " ", "0"}], " ", "&&", "  ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"f", "[", 
              RowBox[{"c", ",", "d"}], "]"}], "[", 
             RowBox[{"x", ",", "y"}], "]"}], ",", "y"}], "]"}], "\[Equal]", 
          "0"}], " ", "&&", "  ", 
         RowBox[{"a", " ", "=!=", "0"}], " ", "&&", " ", 
         RowBox[{"b", "=!=", "0"}], " ", "&&", " ", 
         RowBox[{"c", " ", "=!=", "0"}], " ", "&&", " ", 
         RowBox[{"d", " ", "=!=", "0"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"lisofstationarypoints", "  ", "=", " ", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{"parametricsolution", "  ", "/.", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"c", " ", "\[Rule]", 
            RowBox[{
             RowBox[{"xxx", "[", 
              RowBox[{"[", "r", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ",", 
           RowBox[{"d", "->", " ", 
            RowBox[{
             RowBox[{"xxx", "[", 
              RowBox[{"[", "r", "]"}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"r", ",", "1", ",", " ", 
          RowBox[{"Length", "[", "xxx", "]"}]}], "}"}]}], "]"}]}], ";", 
     RowBox[{"list", " ", "=", " ", 
      RowBox[{"Map", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"MapAt", "[", " ", 
          RowBox[{"Last", ",", "#", " ", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", "1", "}"}], ",", 
             RowBox[{"{", "2", "}"}]}], "}"}]}], "]"}], "&"}], ",", " ", 
        "lisofstationarypoints", ",", " ", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     "\"\<listofparameters is crated by the user\>\"", ";", 
     RowBox[{"listofrighthandside", " ", "=", " ", 
      RowBox[{"Apply", "[", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"#1", ",", "#2"}], "]"}], "[", 
          RowBox[{"x", ",", "y"}], "]"}], "&"}], ",", "xxx", "  ", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"listofheads", " ", "=", " ", 
      RowBox[{"Apply", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", " ", "xxx", " ", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"listoflefthandside", " ", "=", " ", 
      RowBox[{"Map", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"HoldForm", "[", 
          RowBox[{"#", " ", "[", 
           RowBox[{"x", ",", "y"}], "]"}], "]"}], "&"}], ",", " ", 
        "listofheads"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{
       RowBox[{"hesjan", "[", "r_", "]"}], "[", 
       RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"listofrighthandside", "[", 
           RowBox[{"[", "r", "]"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"x", ",", "2"}], "}"}]}], "]"}], " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"listofrighthandside", "[", 
           RowBox[{"[", "r", "]"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], "  ", "-", 
       SuperscriptBox[
        RowBox[{"(", " ", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"listofrighthandside", "[", 
            RowBox[{"[", "r", "]"}], "]"}], ",", " ", "x", ",", "y"}], "]"}], 
         " ", ")"}], "2"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"fbisx", "[", "r_", "]"}], "[", 
       RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"listofrighthandside", "[", 
         RowBox[{"[", "r", "]"}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", "2"}], "}"}]}], "]"}]}], " ", ";", " ", 
     RowBox[{"hesjanandfbisx", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"hesjan", "[", "r", "]"}], "[", 
           RowBox[{"x", ",", "y"}], "]"}], ",", " ", 
          RowBox[{
           RowBox[{"fbisx", "[", "r", "]"}], "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"r", ",", "1", ",", " ", 
          RowBox[{"Length", "[", "listofrighthandside", "]"}]}], "}"}]}], 
       "]"}]}], " ", ";", " ", 
     RowBox[{"hesjanandfbisxhasz", " ", "=", " ", 
      RowBox[{"(", 
       RowBox[{"hesjanandfbisx", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "\[Rule]", "#1"}], ",", " ", 
          RowBox[{"y", "\[Rule]", "#2"}]}], "}"}]}], ")"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     "\"\<values returns values of  Hessian det and \
\!\(\*FractionBox[\(\*SuperscriptBox[\(\[PartialD]\), \(2\)]f\), \
\(\[PartialD]\*SuperscriptBox[\(x\), \(2\)]\)]\)  at stationary points\>\"", 
     ";", "\n", 
     RowBox[{"values", " ", "=", " ", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Evaluate", "[", 
            RowBox[{"hesjanandfbisxhasz", "[", 
             RowBox[{"[", "r", "]"}], "]"}], "]"}], "&"}], ",", " ", 
          RowBox[{"list", "[", 
           RowBox[{"[", "r", "]"}], "]"}], ",", 
          RowBox[{"{", "1", "}"}]}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"r", ",", "1", ",", " ", 
          RowBox[{"Length", "[", "listofrighthandside", "]"}]}], "}"}]}], 
       "]"}]}], ";", " ", "\n", 
     RowBox[{"Do", "[", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Print", " ", "[", 
          RowBox[{"Style", "[", 
           RowBox[{"r", ",", " ", "18", ",", " ", "Red"}], "]"}], "]"}], ",", 
         " ", "\n", 
         RowBox[{"Print", "[", "\"\<Function:\>\"", "]"}], ",", "  ", "\n", 
         RowBox[{"Print", "[", " ", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x", ",", "y"}], "]"}], " ", "==", " ", 
           RowBox[{"ReleaseHold", "[", " ", 
            RowBox[{"listoflefthandside", "[", 
             RowBox[{"[", "r", "]"}], "]"}], "  ", "]"}]}], "  ", "]"}], ",", 
         " ", 
         RowBox[{"Print", "[", "\"\<Stationary points:\>\"", "]"}], ",", "  ", 
         RowBox[{"Print", "[", " ", 
          RowBox[{"list", "[", 
           RowBox[{"[", "r", "]"}], "]"}], " ", "]"}], ",", " ", 
         RowBox[{
         "Print", "[", 
          "\"\<Hessian det and \!\(\*FractionBox[\(\*SuperscriptBox[\(\
\[PartialD]\), \(2\)]f\), \(\[PartialD]\*SuperscriptBox[\(x\), \(2\)]\)]\):\>\
\"", "]"}], ",", " ", 
         RowBox[{"Print", "[", 
          RowBox[{"hesjanandfbisx", "[", 
           RowBox[{"[", "r", "]"}], "]"}], " ", "]"}], ",", "  ", 
         RowBox[{
         "Print", "[", " ", 
          "\"\<Values of  Hessian det and \
\!\(\*FractionBox[\(\*SuperscriptBox[\(\[PartialD]\), \(2\)]f\), \
\(\[PartialD]\*SuperscriptBox[\(x\), \(2\)]\)]\)  at stationary points:\>\"", 
          "]"}], ",", "  ", 
         RowBox[{"Print", "[", " ", 
          RowBox[{"values", "[", 
           RowBox[{"[", "r", "]"}], "]"}], " ", "]"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"r", ",", "1", " ", ",", " ", 
         RowBox[{"Length", "[", "listoflefthandside", "]"}]}], "}"}]}], 
      "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.835260644691519*^9, 3.835260680808628*^9}, {
   3.8352607819795537`*^9, 3.83526079572373*^9}, {3.8352608411197867`*^9, 
   3.835260851561469*^9}, {3.83526102514904*^9, 3.8352610782557716`*^9}, {
   3.835261188996398*^9, 3.8352612194061904`*^9}, {3.8352612528247004`*^9, 
   3.8352612787060423`*^9}, {3.8352613841789627`*^9, 3.835261391875575*^9}, {
   3.835261444247512*^9, 3.8352614921023607`*^9}, {3.8352615747183185`*^9, 
   3.8352615913839645`*^9}, {3.835261642512413*^9, 3.8352616614939623`*^9}, {
   3.8352617019711657`*^9, 3.835261717439339*^9}, {3.8352620415263186`*^9, 
   3.835262060289911*^9}, {3.8352620950537686`*^9, 3.835262108792898*^9}, {
   3.835262139067941*^9, 3.8352621550013885`*^9}, {3.835262301261928*^9, 
   3.835262406897146*^9}, {3.8352625397306385`*^9, 3.8352625481242514`*^9}, {
   3.8352627172477565`*^9, 3.835262722317011*^9}, {3.835262759809657*^9, 
   3.835262818274272*^9}, {3.8352632298033123`*^9, 3.8352632365988274`*^9}, {
   3.8352634310514803`*^9, 3.835263432202636*^9}, {3.8371577276928406`*^9, 
   3.837157747895131*^9}, {3.8393361662247243`*^9, 3.839336224557032*^9}, 
   3.8393915645967607`*^9},
 CellLabel->"In[35]:=",ExpressionUUID->"89c7d7ed-dfc0-417a-9e17-461e6f46a038"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ForTeachers", "[", "listofparameters", "]"}]], "Input",
 CellChangeTimes->{{3.835263254703494*^9, 3.835263274618838*^9}, {
   3.8352634961920443`*^9, 3.8352634973812456`*^9}, 3.8393915738558025`*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"55dc3cde-dbe6-47ec-a550-86f0a4c9ba9b"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["1",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395169142*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"8c099913-a113-48c1-bf86-f299ee167e7b"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395169142*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d10fa203-12d1-4c49-8124-88f672f1fb4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395169142*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"0fe1bd93-b2f3-4826-acdb-31c8c48dced0"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395169142*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"b4b3d6af-b888-4ead-b31c-7b7dbd2543d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", 
      SqrtBox["15"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     SqrtBox["15"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395169142*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"a3f9d721-4f9f-4d0e-bd0e-c5a54e9afed2"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923951847477`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9e4ad02f-6c4c-4f99-ac00-969131404dce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"12", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923951847477`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"615d3b00-db5a-41d9-8ccc-da4211a88708"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923951847477`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"32263580-f4ff-4afd-a9d2-25d21066ad15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "60"}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "60"}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"24", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "120"}], ",", 
     RowBox[{"-", "12"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923951847477`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c5c95838-f578-446e-afd6-7261f1f2cc02"],

Cell[BoxData[
 StyleBox["2",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923951847477`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"26edb23a-8036-4f61-9bac-f94a9d2f55af"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923951847477`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"60acb3a5-1cb9-413b-9459-da05bc7ebd74"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923951847477`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"cb99c1d4-23d6-4641-abc5-e8afc25679c2"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923951847477`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"696400b0-cd9d-418f-996d-6d5e5f25129e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395200838*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"eb785d2d-5895-4c92-b9db-a989ee9e3e20"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395200838*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"facdf25e-3049-4e4a-ade1-98d6bf2f5eb4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"6", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"6", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"203921d8-934d-4091-8052-b1ca8b12ec1c"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"1538cad0-d59a-4f40-ae4d-5945352234ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "6"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c66f6b4c-9dee-4b25-b4bd-63553e60f0bc"],

Cell[BoxData[
 StyleBox["3",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"4d62b571-4db5-49f3-838f-8259b099af0f"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"0784d937-dc89-49ae-b4b3-a3b5ce9551f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"50501f08-749e-4b39-aece-5e587fa2c1bc"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"15949756-a558-4a60-95fe-65eb132a9bac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"742591d8-b28c-43db-9789-deede64d19f8"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395203952*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"03248185-5a02-4a0e-b94f-620fa0bd690f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"12", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952196417`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ea726a37-b818-4656-842e-3631cdb5896e"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952196417`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ecc4a845-4ec0-4ad3-9148-6cb108bc5f91"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"24", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"72", ",", 
     RowBox[{"-", "12"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952196417`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"f75d1572-717c-4c46-af26-a369fc9b089c"],

Cell[BoxData[
 StyleBox["4",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952196417`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"3b743213-02ea-4f1d-b19f-caf497f8cceb"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952196417`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e818e560-cca9-47b1-96ed-87c3d4100f8d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952196417`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"cf279e51-169f-4d3e-ad82-43fe1d65ad16"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952196417`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ccb4746b-69fd-4474-8190-8214d7f96714"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"2", " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952196417`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"7f44ee5e-8fe4-4c42-a9c9-9772e3a2415f"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d10883d6-a828-4952-b6bf-427188fdf941"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "-", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"6", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"6", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"5e46001f-e68d-4008-afe1-abcff70136e9"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"a2d447e5-5903-4017-892a-2435ecbbf0c6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "192"}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "192"}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "96"}], ",", 
     RowBox[{"-", "6"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"4a641503-a330-4a05-aa87-a0716bc76f6f"],

Cell[BoxData[
 StyleBox["5",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"3efa1906-c5eb-45fe-98df-7712ccd127d1"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"2439250a-f654-46f6-8d97-988d28b9c3b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e13bacef-a41b-4722-b31e-d4d38f19c79b"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"3b98e58f-cb30-4798-b5b2-f89e2de9a410"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395235314*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e50a185f-6767-48fe-bdc3-cd80ffa0b430"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239525128*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"254abd65-e24d-444f-acb0-89c9bd1565ac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"12", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952537947`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d76b9d2d-aa19-4d61-b3ae-83df6f0e5647"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952537947`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"156a1439-2f8e-4ab1-92de-0a491e4f032f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "36"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"24", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"72", ",", 
     RowBox[{"-", "12"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952537947`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"a66eb434-2478-42c7-9076-40d7bae811a8"],

Cell[BoxData[
 StyleBox["6",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952537947`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"048e69c3-79ca-4267-b2b2-b290a8719245"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952537947`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"dbe61515-4a2f-41a7-bcb9-5bd32366701d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952537947`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"7cdd7625-d24d-49ea-9047-36ba9e4182a7"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952537947`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9fbde73f-e423-4259-858f-80285381a12e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"-", 
      SqrtBox["6"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     SqrtBox["6"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952537947`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"029b0f2f-1ed5-4273-997a-1a3a6aab2a55"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952694225`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"cf914c21-70a0-4dc9-86c1-1fd7e71b2402"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"12", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952694225`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"565d41f3-30ac-4996-858d-5706ef833396"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952694225`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6a5547b0-4161-4e0d-9cc3-8cbb5796a0a6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "96"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "96"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"96", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"96", ",", 
     RowBox[{"-", "12"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952694225`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"eb45b857-5b47-44b0-b58d-0bf6eee71874"],

Cell[BoxData[
 StyleBox["7",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952694225`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"10ab7bc4-8517-426b-aa22-1303bf3802de"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952694225`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6399cdad-944a-4d0c-a23b-ae998ea698df"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952694225`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e5df7c09-5e89-4622-9af3-4327cbffb54f"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952694225`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"2946c6bf-a0db-4571-a838-d76fabc1d969"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"3", " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952850604`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"0d3038a2-f71a-4746-b171-796a608f0ce6"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952850604`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"7ecbbb79-15a2-4fe6-8ef0-995c3113d536"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "-", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"12", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952897243`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"80d49708-4346-430d-8e20-4faebd566fed"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923952897243`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d2c20de0-23a9-4cf2-9129-b811027735b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "288"}], ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "288"}], ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"96", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "288"}], ",", 
     RowBox[{"-", "12"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395293427*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"aabcf676-ffcb-402d-b019-51d0ed03164d"],

Cell[BoxData[
 StyleBox["8",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395293427*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6c2e14d3-3162-4c0d-ac8d-1f399c5ad6fc"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395293427*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"b7b03407-7d01-407a-9af6-f7479a05774c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395293427*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c041cdfd-33b1-4337-a3c6-e08f7a3efedb"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395293427*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"864a3656-0684-49e3-b78f-c78879601725"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", 
      SqrtBox["15"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     SqrtBox["15"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395293427*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"5d538709-1986-49fd-a560-649b3f507f6f"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953046103`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"081fac2d-8770-45a0-905b-4a4f72249b96"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"18", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953067603`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c02a4eb4-229b-488d-8502-eeb41aa10975"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953067603`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d31af488-d983-4988-a5e5-10a565184595"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "60"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "60"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"36", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"180", ",", 
     RowBox[{"-", "18"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953100123`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"a73c365b-cc91-41da-ba81-5aed7555ce9d"],

Cell[BoxData[
 StyleBox["9",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953100123`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"68c0b63c-9518-4469-8db4-87d547f288d2"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953100123`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ef3f4db0-4799-410e-8388-c8f1fbf28ff5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953100123`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"747760d4-bdbf-48bc-ae73-b06bf306c28c"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953100123`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e37371f8-f685-4ac0-a523-4dc581803e70"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", 
      SqrtBox["21"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     SqrtBox["21"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953100123`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"846be20a-9245-4888-bf31-d0842e2da22a"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953203344`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e8778f67-5e24-49e6-9a9b-9b26740a7916"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"18", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953224583`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"725b1edc-057b-4ddd-b3a1-1d773266b5e9"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953224583`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"055e0289-61da-4146-98e8-c425110b1586"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "84"}], ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "84"}], ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"36", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "252"}], ",", 
     RowBox[{"-", "18"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953258295`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"fa445803-0af4-4634-b7b2-d650db5d1f38"],

Cell[BoxData[
 StyleBox["10",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953258295`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"fd8410cd-1419-4b5b-9d08-725706f8697b"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953258295`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"7a5f5b84-188a-4c72-b29b-015e4b1f80ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953258295`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"4abadd8c-2361-4060-a2ce-108cb4a82066"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953258295`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ccd48861-cbc3-460a-8d78-4775452bd570"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     SqrtBox["3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953258295`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"8048ceca-c80c-43a9-8314-5ca85c5dd068"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395336501*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c0944bd0-8e1c-419f-a66c-de6ed165c30f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"36", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"12", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239533895*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6666b01c-6c6a-4499-9721-de0b00e214c4"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239533895*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"19dfb384-dfb0-44ab-ab46-e0dc8b0842e7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "108"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "108"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"216", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"72", ",", 
     RowBox[{"-", "12"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239534256*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"f38ff93c-67bc-476f-aa34-4c3c32751c18"],

Cell[BoxData[
 StyleBox["11",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239534256*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ec29b266-5465-4f3b-ad5e-8fc420f6336c"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239534256*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"83c56c6e-3a62-43c8-a43a-cb92a53fb556"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239534256*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"1f5d13d3-5a3f-49b5-a9f0-57af5167a745"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239534256*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"a44078ea-452c-42f8-8c4c-7a6c853c49c9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"2", " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239534256*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ff568744-2fa6-4c2a-a4ce-390209a26dc8"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953544674`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"0bb87b6e-294b-4148-be01-f83a83d703f3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"18", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395355591*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"481cd006-dc89-429b-985f-1875bd873d8e"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395355591*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"116dd65d-10fa-47e0-82ef-fd5d97ff8173"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "192"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "192"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"144", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"288", ",", 
     RowBox[{"-", "18"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953589697`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"aa80a60b-efc5-48a7-9e98-3624c2a3f8cd"],

Cell[BoxData[
 StyleBox["12",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953589697`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"a43dbead-2460-4cae-a17d-df4c9465f335"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953589697`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"580518cc-3f87-4de1-aec0-cd6fc7401899"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953589697`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ffad8d71-92bb-4eb3-9c29-f722e7ff0212"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953589697`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"8a07b0d2-65bb-41cf-8193-ed86d0f4a548"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953589697`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"96d1e1f9-f632-478c-897e-73e39dae611e"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923953589697`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9001b544-acf5-468e-ab1c-a64e645bafd4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}], "2"], "-", 
    RowBox[{"36", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"18", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395370571*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e88be689-76dd-43f4-9c65-5fa6f4d668c9"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395370571*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"3d3c464c-b31f-4cb3-90f2-03a2b795bb39"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "324"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"324", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"324", ",", 
     RowBox[{"-", "18"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395374149*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"37ddedd1-a77b-43f6-be00-f26b10b3f329"],

Cell[BoxData[
 StyleBox["13",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395374149*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"a610fa06-c070-4c26-9ec9-09d02da9d4d5"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395374149*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"a239dbd9-47cf-4eb9-a5ae-d2d2b772a148"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395374149*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6950e1f7-a074-47f1-b925-a71a714d58c4"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395374149*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"063e3891-090d-49e3-8fda-d0fb0891996f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", 
      SqrtBox["21"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     SqrtBox["21"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395374149*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d81075b0-ee9c-4039-bf51-a78cacbf9118"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395385056*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d786dcbe-4eb4-4430-8a6d-b10e4406274e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395386976*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"396315a4-befb-4b55-a557-20e049fa44a1"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395386976*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"45a6ef47-6670-421a-bb3e-7908c77e713c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "84"}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "84"}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"336", ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395390542*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"f412db95-5c02-46ef-8619-b375b1313b96"],

Cell[BoxData[
 StyleBox["14",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395390542*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"4ea65e3e-759d-44fe-9f37-1dd90e376489"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395390542*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"f69e25d6-f021-46e6-97e0-597abf425ce9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395390542*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"513f047f-9b06-4158-8b1c-0ef574bb5aaf"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395390542*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"89b18138-b986-4fb7-8dc0-a735e264450b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"3", " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395390542*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"51f78ea3-f37f-4475-a6bc-c61458f59e37"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954011135`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ccfa2335-a49c-47cb-8094-104351b1b14d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395403051*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"2ef5ca3e-3589-4cbe-b082-040151913e6d"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395403051*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d91d70c1-1e1a-40a4-b829-dd854bc26a94"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "108"}], ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "108"}], ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "432"}], ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395406558*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"b7995bff-0a4c-4418-8689-cfa2b25d024a"],

Cell[BoxData[
 StyleBox["15",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395406558*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ee99500c-80b6-423d-8aee-b5767160a247"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395406558*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"220b07b8-eea4-4a0d-88cf-852da37d5268"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395406558*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"5db9b948-c42b-4e17-94d8-65638822efd7"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395406558*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"73bf0a6f-e963-487e-9574-615f34b2b054"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      SqrtBox["15"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     SqrtBox["15"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395406558*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"34ccaf07-b00a-4fab-aa99-959add1a290f"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954170666`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e2e9d9af-f7d7-45da-b542-d835e6c2a3ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"36", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395419089*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ff3b40c3-98bd-42dc-aded-2c301569354a"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395419089*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"1be955fe-eebe-4f91-bc9e-82b8623a910b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "540"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "540"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"432", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395419089*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"19825f0d-c175-46c8-bc4a-72751d31d541"],

Cell[BoxData[
 StyleBox["16",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395419089*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"8a062ef9-e6e6-4a6e-a01d-3fd9f3c4f2f3"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395419089*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"71ea0aa1-96b4-4bc4-93b8-be290c2d4549"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395419089*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"5be203f6-9011-44ce-bb98-294c7c733f49"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395419089*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"4297e1bb-f669-4709-8ef5-e9833125078f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", 
      SqrtBox["6"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     SqrtBox["6"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395419089*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"937fea13-a809-4eb0-b578-cbd371c30398"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395433874*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9c79bb95-eab5-4602-af20-40915bc7b13e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"32", "+", 
       RowBox[{"8", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"18", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395435865*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9774282a-dec8-40d9-a358-c58be8e49705"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395435865*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"25133a5b-36d9-41cc-9502-fcd98ca8a20c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "384"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "384"}], ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"576", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"288", ",", 
     RowBox[{"-", "18"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954394445`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9282cd53-d94c-445c-99a4-99f77a98a2af"],

Cell[BoxData[
 StyleBox["17",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954394445`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"62e89357-5336-4fe0-b8c0-67df1a83f4fc"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954394445`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9b6eb59a-80ed-47a0-a371-7738df03ff4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"6", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954394445`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"23f64513-0be0-4a0b-927a-52a0ce6e591c"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954394445`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"38cc50da-bfad-4deb-acee-66fb61d2ddbd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954394445`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6907e48b-529f-4885-9974-680967430305"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954394445`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"370288e3-ed67-4d29-8805-30439db2bb76"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"12", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"32", "+", 
       RowBox[{"8", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"12", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395450656*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"351fe78a-0a99-4498-9441-a69894f87c16"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395450656*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6be34ea9-ebb8-4dbc-970b-d9115a9c8967"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"384", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "12"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395454587*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"2ee17bbf-9fbe-4145-a790-3039d927ab66"],

Cell[BoxData[
 StyleBox["18",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395454587*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"baa3b89b-3cea-43e0-b24b-15b0be974b58"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395454587*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"5d7d3442-03c1-4aa5-aefe-dd6b63207b4d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395454587*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c42890bb-6bb4-463b-940d-763f23986244"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395454587*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"f7c4d704-d941-4de0-888e-57f61dac5cbc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", 
     RowBox[{"-", 
      SqrtBox["33"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     SqrtBox["33"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395454587*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"643e3fd1-0de5-4bfe-bc8f-07d1e05f5594"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954657745`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"1f007a5a-4817-4a7c-b128-1dea3e8263be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"18", "-", 
       RowBox[{"6", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"36", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954676447`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"71dddda4-afad-439c-a9ef-ecf348ae704c"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954676447`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"65bcf3f9-6a03-487a-802e-d571ff863297"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1188"}], ",", "42"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1188"}], ",", "42"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"432", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1584"}], ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954711995`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e3d6a52c-7b40-442d-adc1-c6753231c587"],

Cell[BoxData[
 StyleBox["19",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954711995`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"43fa093f-fef4-4e61-927a-fce1f0170f4a"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954711995`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9bcb2e6b-4faf-4b0d-9a57-dd6e8cc2774b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954711995`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ccdeb35d-12ce-4aaa-977c-c5e4e022907f"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954711995`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e6e18d31-f7db-498c-a556-c9119b2f36b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", 
      SqrtBox["30"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     SqrtBox["30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954711995`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"05fd7676-4cc1-4f2c-b789-0b9541d9d7c6"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954821663`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"bf59150d-6e41-4c94-bab6-be2e8f89f02d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"32", "-", 
       RowBox[{"8", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"18", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954840546`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"587a613e-f9df-4825-ac82-64a1f8073877"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923954840546`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ed08d2af-8304-4e13-9231-7c8bd25f1d5e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1920"}], ",", "42"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1920"}], ",", "42"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"576", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1440"}], ",", 
     RowBox[{"-", "18"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395487627*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"11104265-1785-43a3-85a1-61e2ecd796a9"],

Cell[BoxData[
 StyleBox["20",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395487627*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"14a38a44-22d9-43af-b40d-495ac31a7eab"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395487627*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ed5699df-18db-4023-a1f9-6e447876a5f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395487627*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"dfd96cb8-1cdb-4d79-880f-8665d0188fad"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395487627*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"3fe1d15c-f0a1-4e9a-a65b-2688b3e350d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395487627*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e2cda6ec-3137-469b-bd26-fc04079261aa"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395487627*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"b86d12bb-789e-456e-9511-b9368602eb92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"32", "-", 
       RowBox[{"8", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "12"}], "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{
    RowBox[{"-", "12"}], "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395499338*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"5701b5f1-d33f-4f26-8e08-8facff041f14"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395499338*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"32de5a89-be2b-48aa-a65e-bc0537c26ef7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "384"}], ",", 
     RowBox[{"-", "12"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "12"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955033817`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ace217ed-bb3a-4b99-957b-9a6b7fdbf6da"],

Cell[BoxData[
 StyleBox["21",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955033817`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"cf314b57-79d0-4030-bb08-3e2c0eadbb41"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955033817`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"5568c8ed-c765-4141-bb55-418ddf2bb4d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955033817`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"3ee69028-8469-4ab2-80e7-3a51b5ae3580"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955033817`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"0a4fafff-82d9-4e96-ad29-f428640ad838"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"3", " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955033817`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"37c8462a-ef0f-43ff-bf48-872fe5b4dd5d"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955149603`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"58bdaf2b-54d3-4221-8810-6b5fa904ebc5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395516776*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9ef39c53-23ff-46c6-b78f-138dea26a0d3"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395516776*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"55d18b6b-1a14-4b14-8d91-a552ec361a9d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "288"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "288"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"576", ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955206356`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"79b02d88-0817-4934-907e-16f93fc60f54"],

Cell[BoxData[
 StyleBox["22",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955206356`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"81584ad9-7146-4c36-b1eb-8cb9ddc0c372"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955206356`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"13870eb4-5b19-4d66-9f9e-688e21e79608"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955206356`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e18b4b89-69b2-475d-854b-a25277ef2c99"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955206356`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9a1486c3-3fb7-4db1-9215-55cde27d8919"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"3", " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955206356`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"59c6559b-c583-421d-9334-7d8af478a826"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955321054`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"efd3b696-417f-4b33-a69b-f4771227361d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395534114*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"05a274c4-777e-47d6-b625-3e4d2f7bac3f"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395534114*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"50d61068-92a9-4ffb-b6cd-1a845830bf78"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "288"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "288"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"576", ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395537794*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"38a72e76-8f0c-40c3-9c8a-49a878f9fb12"],

Cell[BoxData[
 StyleBox["23",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395537794*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d86ac549-dc30-4a40-ac4d-6bb754bc539e"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395537794*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"09e1129d-d999-460f-97bc-acacedd11bd8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395537794*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"1e4e7cc9-8328-497a-8663-90ad89bac816"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395537794*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"91d87589-dca0-4778-9630-62f0e00945d7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", 
      SqrtBox["30"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     SqrtBox["30"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395537794*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"914acbe4-3628-4be0-990d-edb56c5c3add"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955487165`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"42b2c1e6-ab7c-429a-b99d-c004bbe2bf5a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "-", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395550605*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c01fec3d-016b-4458-9b0e-0f36ede67448"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395550605*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"452cd0d2-a78b-4aa3-9f5e-63cc3ba09700"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "480"}], ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "480"}], ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"192", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "960"}], ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395554323*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"cfc1995f-ad54-4d8d-bfbc-cc93a32ec0aa"],

Cell[BoxData[
 StyleBox["24",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395554323*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"3e6ef417-2c2c-4186-8b7c-a3e8e002d99f"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395554323*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d913285f-b009-4f32-8cb7-bccc44bf5a01"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395554323*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9905e00a-ab02-4aff-a191-04d4a3d32233"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395554323*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"8f421290-056f-4413-8317-7bf3d533defe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{"2", " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395554323*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"0f75ed1a-7cc4-489a-bb30-b3065c34cbb5"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395565352*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"88f97804-9d3a-4b08-8aa4-fe10beb96a31"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"32", "+", 
       RowBox[{"8", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955672007`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"55c9e933-bd8f-4cb4-81dd-833695411699"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923955672007`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"11956cba-6b56-4308-88a6-a1e00e42ca61"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "768"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "768"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"768", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"768", ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239557098*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e42effb7-490a-4e82-b6c2-55eb9ec3e789"],

Cell[BoxData[
 StyleBox["25",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239557098*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"69ed8914-a8a8-4491-8604-202dc130c7fe"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239557098*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"7a9fa828-4fb9-4898-ada2-cd0b1640855e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"12", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "-", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239557098*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"317cc63a-3371-4e14-9dfc-038ef7198d0f"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239557098*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"3695c2c9-7115-4101-b731-7243815ff51d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239557098*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"e12ba2f8-8a08-4539-b3ff-89c0ac1e1686"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239557098*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"8e4b066b-8e3c-4147-9ae9-84f029c5f747"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"32", "-", 
       RowBox[{"8", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"24", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395582552*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"0ec94f98-70c4-4ff9-88a3-6fdacc69b8d8"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395582552*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"79ec73ab-b07f-4901-94eb-752691e05abd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", "48"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", "48"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"768", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2304"}], ",", 
     RowBox[{"-", "24"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395586093*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9701cac0-b4be-400b-91a6-77a93637a0dd"],

Cell[BoxData[
 StyleBox["26",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395586093*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ecc1ebcb-952c-4371-9cdd-f4abe3f00079"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395586093*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"994319ee-4b25-473f-a3a9-f01f6b95964a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "-", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395586093*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"94958d00-f253-4a1b-8b05-7e59b9c3db4c"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395586093*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"26c15324-f491-4a6a-9146-a92bac0525cf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", 
      SqrtBox["33"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     SqrtBox["33"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395586093*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"45e0be97-f422-4409-95b1-0763a0e68518"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395598839*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"608006bf-d4fd-445a-84d5-da3ef8254604"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"30", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"30", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956007524`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6f7e9fed-5a5a-4fa5-84fe-4bc51075d2a1"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956007524`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"6edcd3f3-7936-48db-8b4e-dd671340d101"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "132"}], ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "132"}], ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"60", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "660"}], ",", 
     RowBox[{"-", "30"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395604573*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"b30bc757-c659-4162-abb9-a7174057e33f"],

Cell[BoxData[
 StyleBox["27",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395604573*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9b2471f7-ba7a-424c-9286-c2a69314affb"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395604573*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"0f45c6bd-4d14-4179-887f-b28d0146d75d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   SuperscriptBox["y", "2"], "+", 
   RowBox[{"x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395604573*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"2d98a3f9-4f64-465c-b38a-a0e46e9ad9ca"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395604573*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d7131e6d-289e-436e-86b4-4ad159f296f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"3", " ", 
      SqrtBox["3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395604573*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c3662e98-a1ba-4211-b5e9-d10ec46eb102"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956159735`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"544776bc-00dc-48be-8d2d-bc7fb4e865c3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"2", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"30", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"30", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956179266`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"9ab50013-867c-4209-870f-f0bffb082826"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956179266`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"1f351587-0a35-415c-b88c-59754e964a1a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "108"}], ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "108"}], ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"60", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", 
     RowBox[{"-", "30"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395622018*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"578100ae-9877-42b3-af7f-9d64b7e1f520"],

Cell[BoxData[
 StyleBox["28",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395622018*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"50826215-4f72-44b6-91f9-79c3a543d142"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395622018*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"636a17f9-7744-484c-95cd-b1c6a7240948"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"2", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395622018*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"8a2dcb65-a6e5-41a8-ad90-c7da910b3f81"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395622018*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"4e980dc4-7ceb-47f1-af7f-ee816219f1ec"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["6"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2"}], ",", 
     RowBox[{"2", " ", 
      SqrtBox["6"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395622018*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"bf308ac9-f0c5-424b-bcb7-803cf848a845"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956334734`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"2a18f3e4-5daa-43fb-9a58-5e4b45828b10"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"4", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"30", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"30", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239563552*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"f282e72d-71fb-48fc-810d-76ce60133132"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.83939239563552*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d28e70e4-d12a-4d7b-9098-b9a8ae7b741d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "384"}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "384"}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"240", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", 
     RowBox[{"-", "30"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956393504`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c5e65239-c65d-42aa-928b-e6b889ff4faa"],

Cell[BoxData[
 StyleBox["29",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956393504`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"42fd6753-33c6-4611-a63b-4b1bd377020b"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956393504`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"32c7fa00-3968-49a9-ae18-5b9eb3812487"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"3", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956393504`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"7f7b7434-e401-4ea1-8726-365b8428c6e9"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956393504`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"b410f7b7-1317-497e-a4aa-24b9d7f3bcf7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     RowBox[{"-", 
      SqrtBox["21"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", 
     SqrtBox["21"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956393504`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"ab95914f-addc-4451-bebd-de4ad1042693"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956503305`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"c19ee91a-9ed0-45a1-9b50-cf8f2e995376"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"18", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"30", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"36", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"30", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395652291*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"b380892a-cad1-4e1e-88fd-8e1fb90e0b49"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956543875`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"f03cbaa8-3f71-4ef3-86a6-bb9b77f845bd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "756"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "756"}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1260", ",", 
     RowBox[{"-", "30"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395656148*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"aeb00535-74d8-4ffa-b66d-b3e02ba6a412"],

Cell[BoxData[
 StyleBox["30",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395656148*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"7ec7e2f5-11cf-4430-9ad0-321123ac0b1f"],

Cell[BoxData["\<\"Function:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395656148*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"7fbc6f96-7800-4c0d-b3bf-27068a8937da"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"15", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   SuperscriptBox["x", "3"], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["y", "2"]}], "+", 
   RowBox[{"4", " ", "x", " ", 
    SuperscriptBox["y", "2"]}]}]}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395656148*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"88bd421f-6944-426f-9a66-67a42ded5e85"],

Cell[BoxData["\<\"Stationary points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395656148*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"461b2e97-c1f6-4af6-9aef-132ae7a3b8e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4"}], ",", 
     RowBox[{"3", " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", "0"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395656148*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"737a0c2a-7cba-42a4-a8f7-7c4ebff78791"],

Cell[BoxData["\<\"Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\):\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.839392395667014*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"fbcc7f06-5a34-4820-aefc-cccc83e3ace1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"30", "+", 
       RowBox[{"6", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"32", "+", 
       RowBox[{"8", " ", "x"}]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SuperscriptBox["y", "2"]}]}], ",", 
   RowBox[{"30", "+", 
    RowBox[{"6", " ", "x"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956690035`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"459c7468-740e-4e9e-bef2-4cb325e55960"],

Cell[BoxData["\<\"Values of  Hessian det and \
\\!\\(\\*FractionBox[\\(\\*SuperscriptBox[\\(\[PartialD]\\), \\(2\\)]f\\), \
\\(\[PartialD]\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)]\\)  at stationary \
points:\"\>"], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956690035`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"46de9f3c-7627-4a1b-bbc2-fc41575dae83"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1152"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1152"}], ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1440", ",", 
     RowBox[{"-", "30"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.8352632855846815`*^9, 3.8352645596803603`*^9, 
  3.839336471257735*^9, 3.8393923956728954`*^9},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"620793c8-7687-4325-ba3f-cee1c4a79c89"]
}, Open  ]]
}, Open  ]],

Cell["Clear all definitions", "Text",
 CellChangeTimes->{{3.839334938706786*^9, 3.8393349483620195`*^9}, 
   3.839335186199309*^9},ExpressionUUID->"cec2d118-8107-4acb-baaf-\
8b918df3763a"],

Cell[BoxData[
 RowBox[{"Clear", "[", " ", 
  RowBox[{
  "f", ",", " ", "listofparameters", ",", " ", "ForStudents", ",", " ", 
   "ForTeachers"}], "]"}]], "Input",
 CellChangeTimes->{{3.839334952118925*^9, 3.8393350217713547`*^9}, {
  3.8393351607238064`*^9, 3.839335178619938*^9}, {3.839391791710656*^9, 
  3.8393917997809753`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"bb82bae4-f233-4946-a297-06a8ec03299b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1141.2, 568.8},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
TaggingRules->{"$testsRun" -> False},
Magnification:>1.5 Inherited,
FrontEndVersion->"12.2 for Microsoft Windows (64-bit) (December 12, 2020)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"],
ExpressionUUID->"c0f5f567-834e-49d8-8f8a-e64855d927ce"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 463, 9, 327, "Title",ExpressionUUID->"f4127fb0-ac83-4259-9c97-79c6d9b0af56"],
Cell[1046, 33, 182, 3, 62, "Author",ExpressionUUID->"0db49f07-b9fc-4864-a9fa-f996f9d84a68"],
Cell[1231, 38, 467, 9, 49, "Department",ExpressionUUID->"2aff5f34-50b2-4074-8929-33b372bae672"],
Cell[1701, 49, 172, 3, 50, "Text",ExpressionUUID->"61c4b771-eeb0-496e-8c1f-617a24f1858e"],
Cell[CellGroupData[{
Cell[1898, 56, 161, 3, 103, "Section",ExpressionUUID->"0680e803-e07a-4bb2-ad68-869854d4e99d"],
Cell[2062, 61, 2574, 42, 787, "Text",ExpressionUUID->"b992263d-f6ce-47b3-8120-5042758196fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4673, 108, 202, 4, 103, "Section",ExpressionUUID->"c2987a83-db69-4ea4-ba5c-075404df2f4c"],
Cell[CellGroupData[{
Cell[4900, 116, 368, 6, 49, "Subsubsection",ExpressionUUID->"987c660c-f517-493b-9035-6cd391f3f3c0"],
Cell[5271, 124, 481, 9, 429, "Text",ExpressionUUID->"8cb91a9c-0369-4943-8b11-1d5bfa9ea0b8"],
Cell[5755, 135, 428, 10, 303, "Input",ExpressionUUID->"de82af97-faee-42c2-91f4-b00663a85aa7"],
Cell[CellGroupData[{
Cell[6208, 149, 1134, 30, 303, "Input",ExpressionUUID->"fabee59f-9882-4040-89b0-d874c20faa23"],
Cell[7345, 181, 1433, 37, 353, "Output",ExpressionUUID->"eab655cb-1643-459d-9961-4cc694ae4ba0"]
}, Open  ]],
Cell[8793, 221, 851, 13, 429, "Text",ExpressionUUID->"4a330fc1-6502-439b-a15b-93ecdf34f923"],
Cell[9647, 236, 447, 8, 256, "Text",ExpressionUUID->"b9e61f88-0b02-4d11-9c05-91a0c089d22a"],
Cell[10097, 246, 499, 13, 303, "Input",ExpressionUUID->"c47b159b-a6bc-40a6-8aa3-1c450d9cb56a"],
Cell[CellGroupData[{
Cell[10621, 263, 1163, 29, 303, "Input",ExpressionUUID->"8717ecca-984d-4cdf-9a0f-570c9cb19696"],
Cell[11787, 294, 1314, 33, 353, "Output",ExpressionUUID->"57b1027c-b52f-4a6f-a926-376b7c1c36b4"]
}, Open  ]],
Cell[13116, 330, 241, 5, 256, "Text",ExpressionUUID->"333e7dfb-3911-46f1-8d22-978cb0dd3475"],
Cell[13360, 337, 280, 4, 303, "Input",ExpressionUUID->"9e86f152-ae81-47a8-85f2-6f34ceca452d"]
}, Closed]],
Cell[CellGroupData[{
Cell[13677, 346, 164, 3, 47, "Subsubsection",ExpressionUUID->"3d175d12-43da-4432-ae00-a201f9b8c64f"],
Cell[13844, 351, 385, 8, 117, "Text",ExpressionUUID->"bc6cf451-a4b7-478c-8955-b641a85db6d4"],
Cell[14232, 361, 305, 7, 50, "Text",ExpressionUUID->"618d4a37-9c5e-4ba3-9177-c279b0653c70"],
Cell[14540, 370, 214, 4, 50, "Text",ExpressionUUID->"001f9eb1-efc8-4010-a95a-92fa348f42d7"],
Cell[14757, 376, 653, 15, 60, "Input",ExpressionUUID->"ee7114a0-8255-484a-a702-f63a8f5827c2"],
Cell[15413, 393, 360, 7, 83, "Text",ExpressionUUID->"edf20948-7d49-425c-b539-a12af9a63f23"],
Cell[CellGroupData[{
Cell[15798, 404, 2883, 83, 145, "Input",ExpressionUUID->"a27d5900-7ea0-414e-8467-1cec849c6434"],
Cell[18684, 489, 2359, 80, 116, "Output",ExpressionUUID->"59357941-783d-4c3b-9fff-00081d1126b3"]
}, Open  ]],
Cell[21058, 572, 240, 4, 50, "Text",ExpressionUUID->"76a20d94-92d3-40ec-8ba7-5df665adb89d"],
Cell[CellGroupData[{
Cell[21323, 580, 1011, 19, 58, "Input",ExpressionUUID->"b43fe6ed-9361-4a5f-add1-df96027b0c3e"],
Cell[22337, 601, 6494, 196, 268, "Output",ExpressionUUID->"07bf9951-dda9-406c-942b-3fce5e1cd1e4"]
}, Open  ]],
Cell[28846, 800, 256, 6, 256, "Text",ExpressionUUID->"4c9e2792-fd1c-40f0-bf0c-f762ec98d52d"],
Cell[CellGroupData[{
Cell[29127, 810, 581, 12, 303, "Input",ExpressionUUID->"adae21dc-2c9e-45f8-97d4-b6abe61b5b01"],
Cell[29711, 824, 2507, 80, 600, "Output",ExpressionUUID->"90925cc7-0dc7-4258-a9bc-282aebc57e39"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32255, 909, 557, 12, 303, "Input",ExpressionUUID->"76556e3e-c569-4862-8d1f-bb400ed69ab6"],
Cell[32815, 923, 5114, 200, 749, "Output",ExpressionUUID->"8aa8b8b4-1adb-4056-b87c-fcdd1a3bf44d"]
}, Open  ]],
Cell[37944, 1126, 260, 4, 256, "Text",ExpressionUUID->"c27872c8-9c72-40d9-b846-cc6b62ec7bf5"],
Cell[CellGroupData[{
Cell[38229, 1134, 1342, 28, 454, "Input",ExpressionUUID->"ad5d462e-72c1-439c-8bf9-821b1d9ee3d3"],
Cell[CellGroupData[{
Cell[39596, 1166, 321, 8, 171, "Print",ExpressionUUID->"96d54837-ce2e-473a-b2e3-9de2d6906ea4"],
Cell[39920, 1176, 648, 20, 182, "Print",ExpressionUUID->"1b71e4f0-29b5-491c-b23a-780943acefab"],
Cell[40571, 1198, 321, 8, 171, "Print",ExpressionUUID->"d071b536-f5a0-42d2-9ded-812f7b3e363e"],
Cell[40895, 1208, 659, 20, 182, "Print",ExpressionUUID->"187ebc6e-93d7-4f57-b4d2-627bb0f59c8e"],
Cell[41557, 1230, 321, 8, 171, "Print",ExpressionUUID->"377e0593-7342-4f6b-b747-455c63f15d28"],
Cell[41881, 1240, 606, 18, 182, "Print",ExpressionUUID->"4d0a95ed-3f6f-4f7f-b9ce-39a31c329c18"],
Cell[42490, 1260, 321, 8, 171, "Print",ExpressionUUID->"96b70ed6-1227-4f87-8dee-5ac24f74a4ac"],
Cell[42814, 1270, 606, 18, 182, "Print",ExpressionUUID->"cd95dec2-522b-4572-b929-fea7e6bbfc94"],
Cell[43423, 1290, 321, 8, 171, "Print",ExpressionUUID->"d1dc2b03-a37e-4bb2-9fc7-a0e6cbfbbb01"],
Cell[43747, 1300, 617, 18, 182, "Print",ExpressionUUID->"9270b975-1d93-4dae-b659-42d59c173596"],
Cell[44367, 1320, 321, 8, 171, "Print",ExpressionUUID->"27c9c505-d5b9-49e2-8c80-1b05c054dd5e"],
Cell[44691, 1330, 606, 18, 182, "Print",ExpressionUUID->"8c1d0d9b-c54c-428c-9377-4f096936e3c7"],
Cell[45300, 1350, 321, 8, 171, "Print",ExpressionUUID->"bac1178c-fae8-4812-8c5f-e6782bee620a"],
Cell[45624, 1360, 648, 20, 182, "Print",ExpressionUUID->"0fca224b-ee4a-412d-b2b9-aa76b9064ee4"],
Cell[46275, 1382, 321, 8, 171, "Print",ExpressionUUID->"7e93ecb7-e958-4a34-8e70-447623e5e96b"],
Cell[46599, 1392, 648, 20, 182, "Print",ExpressionUUID->"6cc712e1-fb15-4925-810c-807ac74f8539"],
Cell[47250, 1414, 321, 8, 171, "Print",ExpressionUUID->"b248e8cb-da2a-4301-a1fb-947f9ddecb7e"],
Cell[47574, 1424, 606, 18, 182, "Print",ExpressionUUID->"b0f5ed76-b700-42f4-8737-c3e858a8232a"],
Cell[48183, 1444, 322, 8, 171, "Print",ExpressionUUID->"ebe0bade-f9c4-4f43-9ff5-705f52c70c4e"],
Cell[48508, 1454, 617, 18, 182, "Print",ExpressionUUID->"3771b725-cc78-4c3e-b4d8-d0c52b0e36bc"],
Cell[49128, 1474, 322, 8, 171, "Print",ExpressionUUID->"aaf91e00-edb6-4f2d-8831-3f51f5c77f34"],
Cell[49453, 1484, 617, 18, 182, "Print",ExpressionUUID->"d97a1704-d564-42e9-a84e-02bb69f10fdf"],
Cell[50073, 1504, 322, 8, 171, "Print",ExpressionUUID->"ffbef9b1-f4ff-464a-85ad-a117ac7dff1b"],
Cell[50398, 1514, 659, 20, 182, "Print",ExpressionUUID->"729934cf-2df7-4551-af39-260a34c7cb82"],
Cell[51060, 1536, 322, 8, 171, "Print",ExpressionUUID->"267d59b1-7ea4-4945-b1cf-780782f6e25c"],
Cell[51385, 1546, 659, 20, 182, "Print",ExpressionUUID->"0d530900-329a-4b3c-8d8a-e26bdc213fb8"],
Cell[52047, 1568, 322, 8, 171, "Print",ExpressionUUID->"49c85e98-32e5-4d4a-86c1-3561510596d2"],
Cell[52372, 1578, 659, 20, 182, "Print",ExpressionUUID->"452a9398-62a3-48bd-9918-c78327d7bc6c"],
Cell[53034, 1600, 324, 8, 171, "Print",ExpressionUUID->"24ed5ffa-26f7-41d2-9da9-beb558ea9451"],
Cell[53361, 1610, 619, 18, 182, "Print",ExpressionUUID->"d6b7365d-ecdb-41e7-ac3a-e28635d3bb4a"],
Cell[53983, 1630, 324, 8, 171, "Print",ExpressionUUID->"41e1a047-75dd-44c6-ae39-047700b0e26b"],
Cell[54310, 1640, 609, 18, 182, "Print",ExpressionUUID->"895e1e4d-34a5-403b-af16-fc9241e555e8"],
Cell[54922, 1660, 324, 8, 171, "Print",ExpressionUUID->"fa547995-1bc4-4ff2-b694-02595b9d1708"],
Cell[55249, 1670, 651, 20, 182, "Print",ExpressionUUID->"cac8df2a-0268-4f7c-8498-6045d11f599d"],
Cell[55903, 1692, 324, 8, 171, "Print",ExpressionUUID->"eb2c210d-8326-45cc-b385-5559a73934bc"],
Cell[56230, 1702, 609, 18, 182, "Print",ExpressionUUID->"e1489a8b-d861-4ac9-99e7-ed8dca3e4c66"],
Cell[56842, 1722, 324, 8, 171, "Print",ExpressionUUID->"e513d3b0-c801-4559-a349-1c147785aaf9"],
Cell[57169, 1732, 619, 18, 182, "Print",ExpressionUUID->"2cc52ffa-a03d-43c9-b75e-1be8f1caac7f"],
Cell[57791, 1752, 324, 8, 171, "Print",ExpressionUUID->"c5ce71d0-18c4-459f-bbf4-9db397dc2573"],
Cell[58118, 1762, 619, 18, 182, "Print",ExpressionUUID->"183cf73d-d64b-49ac-92e7-d0f058c5b385"],
Cell[58740, 1782, 324, 8, 171, "Print",ExpressionUUID->"e3d4c190-de85-4a94-86a2-111ae28d37c9"],
Cell[59067, 1792, 661, 20, 182, "Print",ExpressionUUID->"5b6cd426-000d-48b4-a480-57d376a47d8b"],
Cell[59731, 1814, 324, 8, 171, "Print",ExpressionUUID->"232f0476-82d3-4b33-b650-6b9d9c6fc08a"],
Cell[60058, 1824, 661, 20, 182, "Print",ExpressionUUID->"dc94efb8-1c4b-4f48-872f-8f78a01a89d6"],
Cell[60722, 1846, 324, 8, 171, "Print",ExpressionUUID->"8dcf422e-739b-4289-9445-2f3577448699"],
Cell[61049, 1856, 663, 20, 182, "Print",ExpressionUUID->"ad964e03-4e86-4b53-8d4b-e9ac3b44f6d2"],
Cell[61715, 1878, 324, 8, 171, "Print",ExpressionUUID->"6b21b644-9a7e-46b3-a9aa-3ac8d71d3a16"],
Cell[62042, 1888, 663, 20, 182, "Print",ExpressionUUID->"6d4fb640-209d-4019-8e79-5894fe8c6c7b"],
Cell[62708, 1910, 324, 8, 171, "Print",ExpressionUUID->"9f28907e-7dce-4db5-8f49-603396dcba39"],
Cell[63035, 1920, 619, 18, 182, "Print",ExpressionUUID->"6b3e882c-32c3-4727-a8af-8b7bf502debf"],
Cell[63657, 1940, 324, 8, 171, "Print",ExpressionUUID->"2552925f-ec59-4b92-bfe9-56ee5217034f"],
Cell[63984, 1950, 619, 18, 182, "Print",ExpressionUUID->"87fd44a6-badf-4099-bba3-936c4431e49d"],
Cell[64606, 1970, 324, 8, 171, "Print",ExpressionUUID->"ea4952d2-bbca-4287-b054-0dd439526721"],
Cell[64933, 1980, 619, 18, 182, "Print",ExpressionUUID->"5380c7d1-c396-4333-afee-56833aadef4b"],
Cell[65555, 2000, 324, 8, 171, "Print",ExpressionUUID->"660a02fe-9843-4296-9405-a6e5a8c086b2"],
Cell[65882, 2010, 661, 20, 182, "Print",ExpressionUUID->"bf3bab32-a295-4064-9d68-8cdcdf7b3555"],
Cell[66546, 2032, 324, 8, 171, "Print",ExpressionUUID->"18dcfe6d-0e5d-4cd9-a74f-d974ddf2699d"],
Cell[66873, 2042, 609, 18, 182, "Print",ExpressionUUID->"2cc47eb9-352c-43fc-b5e4-8754fb26f3e2"],
Cell[67485, 2062, 324, 8, 171, "Print",ExpressionUUID->"1852b3af-4bec-4497-963d-5cc2974d5db8"],
Cell[67812, 2072, 609, 18, 182, "Print",ExpressionUUID->"85617552-925b-45c6-a378-cb89fe975ae8"]
}, Open  ]]
}, Open  ]],
Cell[68448, 2094, 473, 9, 429, "Text",ExpressionUUID->"53b329bf-1935-47a2-bb51-be32a7efe310"],
Cell[CellGroupData[{
Cell[68946, 2107, 1303, 29, 600, "Input",ExpressionUUID->"dcb81d5d-7f5c-46ed-8d42-116363299f6a"],
Cell[CellGroupData[{
Cell[70274, 2140, 324, 8, 171, "Print",ExpressionUUID->"0569e59c-54c5-4514-87c5-c7fed5b224b0"],
Cell[70601, 2150, 384, 6, 171, "Print",ExpressionUUID->"9cf3ad6f-f08f-423c-86ec-bb5c20327569"],
Cell[70988, 2158, 545, 15, 182, "Print",ExpressionUUID->"36cc6a16-8add-4278-a32a-c770f56092fd"],
Cell[71536, 2175, 322, 8, 171, "Print",ExpressionUUID->"b84fda4a-052c-41ea-98ae-f00515762be4"],
Cell[71861, 2185, 384, 6, 171, "Print",ExpressionUUID->"cb03dd06-5c4c-4ca3-9eeb-0f785a68a6c8"],
Cell[72248, 2193, 556, 15, 182, "Print",ExpressionUUID->"275ccac5-b265-4876-adcc-a19f2a9593c1"],
Cell[72807, 2210, 322, 8, 171, "Print",ExpressionUUID->"6801fac7-fdbc-4b75-befb-24fdf75166f9"],
Cell[73132, 2220, 384, 6, 171, "Print",ExpressionUUID->"742d7a5e-7ead-461f-a976-d795c3cc290c"],
Cell[73519, 2228, 525, 14, 182, "Print",ExpressionUUID->"96f73c30-30a1-4963-a11b-6932977ef839"],
Cell[74047, 2244, 322, 8, 171, "Print",ExpressionUUID->"8c587b71-9572-4d27-9bf1-072ac6f6bf5f"],
Cell[74372, 2254, 384, 6, 171, "Print",ExpressionUUID->"f0962a51-5590-40f7-98c7-3003dd979422"],
Cell[74759, 2262, 527, 14, 182, "Print",ExpressionUUID->"a505b710-3915-4bc7-97a9-1832bc5011d6"],
Cell[75289, 2278, 324, 8, 171, "Print",ExpressionUUID->"69efa7db-fe1c-402e-a5a5-e7f628cfb1a8"],
Cell[75616, 2288, 386, 6, 171, "Print",ExpressionUUID->"82707eea-46e4-4521-a3aa-5eb7dcb6b88d"],
Cell[76005, 2296, 538, 14, 182, "Print",ExpressionUUID->"8ff9731f-cca4-4b9b-a395-4e689fd687df"],
Cell[76546, 2312, 324, 8, 171, "Print",ExpressionUUID->"160b6312-30f7-4fce-a782-37c01ce7a1c1"],
Cell[76873, 2322, 386, 6, 171, "Print",ExpressionUUID->"adaeed41-499d-47c1-9b98-0029fbf79fe0"],
Cell[77262, 2330, 527, 14, 182, "Print",ExpressionUUID->"9f23c2ac-06ab-4bd9-9eaf-c8550cecd682"],
Cell[77792, 2346, 324, 8, 171, "Print",ExpressionUUID->"0ac61d44-7e35-47b2-b0e5-f021a52fac35"],
Cell[78119, 2356, 386, 6, 171, "Print",ExpressionUUID->"93fc7808-f408-4995-91d3-b6105f58fb67"],
Cell[78508, 2364, 547, 15, 182, "Print",ExpressionUUID->"a8802724-3978-413a-bcbf-c1f47abf39e5"],
Cell[79058, 2381, 324, 8, 171, "Print",ExpressionUUID->"e8fa05a7-c04e-434d-94c6-be5d92e58309"],
Cell[79385, 2391, 386, 6, 171, "Print",ExpressionUUID->"b209fd5c-f3a0-4e8b-b3d0-1debfd8525fd"],
Cell[79774, 2399, 547, 15, 182, "Print",ExpressionUUID->"d5eed40d-0601-4162-ae83-2d462f6faf02"],
Cell[80324, 2416, 324, 8, 171, "Print",ExpressionUUID->"9a85efd6-a30e-4130-80e3-f57ce705a4a9"],
Cell[80651, 2426, 386, 6, 171, "Print",ExpressionUUID->"b1bc88db-ab21-49ec-aa70-e1f054d9679f"],
Cell[81040, 2434, 527, 14, 182, "Print",ExpressionUUID->"0c8cde36-b154-4d10-9b9c-da676e99dfc5"],
Cell[81570, 2450, 325, 8, 171, "Print",ExpressionUUID->"dd6661b2-0dd1-4551-aa1b-bb6b0349a495"],
Cell[81898, 2460, 386, 6, 171, "Print",ExpressionUUID->"4e237b41-38a2-4416-8817-8299192c02bf"],
Cell[82287, 2468, 538, 14, 182, "Print",ExpressionUUID->"ae82c241-ad44-4226-b623-97d71dbabba5"],
Cell[82828, 2484, 325, 8, 171, "Print",ExpressionUUID->"af203b08-692e-45a7-9498-0f538d8c7132"],
Cell[83156, 2494, 386, 6, 171, "Print",ExpressionUUID->"cdaa99c4-79fc-4ee7-bf40-75bb78d67b58"],
Cell[83545, 2502, 538, 14, 182, "Print",ExpressionUUID->"d4757223-1637-4218-845f-f8474a1ed028"],
Cell[84086, 2518, 325, 8, 171, "Print",ExpressionUUID->"cb8981f2-7a34-43ac-8623-463ab5fb7a63"],
Cell[84414, 2528, 386, 6, 171, "Print",ExpressionUUID->"2d0dc357-c0ac-40c2-bf8a-e619a64b1aa7"],
Cell[84803, 2536, 558, 15, 182, "Print",ExpressionUUID->"c6e74c7f-0af9-423c-9905-51dae9b952af"],
Cell[85364, 2553, 325, 8, 171, "Print",ExpressionUUID->"008d041c-6367-463d-9248-53ca7e5371b8"],
Cell[85692, 2563, 386, 6, 171, "Print",ExpressionUUID->"12435e67-ba43-4c07-a2e4-674a2e568fef"],
Cell[86081, 2571, 558, 15, 182, "Print",ExpressionUUID->"8a5fc60d-708c-4cea-b319-fe4ff6f45273"],
Cell[86642, 2588, 325, 8, 171, "Print",ExpressionUUID->"20aa9b1c-30eb-4a56-bd55-e6f0abd8aaed"],
Cell[86970, 2598, 386, 6, 171, "Print",ExpressionUUID->"bab88d0b-2ebd-410f-9b18-b9f40af02da5"],
Cell[87359, 2606, 558, 15, 182, "Print",ExpressionUUID->"e5fed8ab-0bb7-431c-a665-ad97e8a0b05b"],
Cell[87920, 2623, 325, 8, 171, "Print",ExpressionUUID->"cccf2255-6344-4b28-bdc8-e10d92d7270b"],
Cell[88248, 2633, 386, 6, 171, "Print",ExpressionUUID->"975b632e-d5af-4405-b44a-2ebd8cec10d7"],
Cell[88637, 2641, 538, 14, 182, "Print",ExpressionUUID->"a2d35f17-3844-4a27-a9ae-38dc60181856"],
Cell[89178, 2657, 323, 8, 171, "Print",ExpressionUUID->"34d4cae3-fbbf-4d26-91cc-3b3c8f146e8f"],
Cell[89504, 2667, 384, 6, 171, "Print",ExpressionUUID->"bd92d5ac-0064-493e-aa26-8ea900be5dd8"],
Cell[89891, 2675, 526, 14, 182, "Print",ExpressionUUID->"6711332f-54eb-40f8-9042-cb8564cdc803"],
Cell[90420, 2691, 323, 8, 171, "Print",ExpressionUUID->"02618358-2079-4433-baa4-f3040bc5d84e"],
Cell[90746, 2701, 384, 6, 171, "Print",ExpressionUUID->"432e0a19-5b2c-4c6f-9bda-12296aa0a1ad"],
Cell[91133, 2709, 546, 15, 182, "Print",ExpressionUUID->"30cb550c-901b-4268-8cd1-197073a183b6"],
Cell[91682, 2726, 323, 8, 171, "Print",ExpressionUUID->"a628486e-35d6-453b-ac90-ccef72b4ccf0"],
Cell[92008, 2736, 384, 6, 171, "Print",ExpressionUUID->"b27478e6-0618-4f63-a66c-daf3572a6bc5"],
Cell[92395, 2744, 526, 14, 182, "Print",ExpressionUUID->"d9d5e7c1-0c3a-4d95-bc8a-98bd5f21245a"],
Cell[92924, 2760, 323, 8, 171, "Print",ExpressionUUID->"ccec920e-dd34-40c9-88d4-87edfa48f4c2"],
Cell[93250, 2770, 384, 6, 171, "Print",ExpressionUUID->"7d2ea7e3-663e-4808-9c88-5240ec0988e8"],
Cell[93637, 2778, 538, 14, 182, "Print",ExpressionUUID->"61ad9975-bb51-41c2-b69f-c8d24eae9ad8"],
Cell[94178, 2794, 325, 8, 171, "Print",ExpressionUUID->"c540f962-1508-4e8f-afce-89f26e216b0a"],
Cell[94506, 2804, 386, 6, 171, "Print",ExpressionUUID->"015006e3-6238-44f4-9a9f-da64ece20f2d"],
Cell[94895, 2812, 538, 14, 182, "Print",ExpressionUUID->"08470814-89ea-42fe-8dcc-066f6e0ccb47"],
Cell[95436, 2828, 325, 8, 171, "Print",ExpressionUUID->"4d8ccdd2-d8b9-40c4-b916-d22805659cb3"],
Cell[95764, 2838, 386, 6, 171, "Print",ExpressionUUID->"62c9c3b8-e24d-45c3-87b8-111e1cea2d49"],
Cell[96153, 2846, 558, 15, 182, "Print",ExpressionUUID->"6261b21d-bc3c-49e2-b19e-849d12b876e1"],
Cell[96714, 2863, 325, 8, 171, "Print",ExpressionUUID->"38d61bf6-fefd-4f8b-b156-e9c51fd4162e"],
Cell[97042, 2873, 386, 6, 171, "Print",ExpressionUUID->"bd8210ef-c8d4-42e3-a4d0-db63f9cb8acd"],
Cell[97431, 2881, 558, 15, 182, "Print",ExpressionUUID->"413994a0-39d6-4a5f-9612-ba037fc1099a"],
Cell[97992, 2898, 323, 8, 171, "Print",ExpressionUUID->"8eae8de3-d042-4c72-8df3-cd4f57844ad4"],
Cell[98318, 2908, 384, 6, 171, "Print",ExpressionUUID->"420a82a6-5c53-489a-b4a2-8722670a9880"],
Cell[98705, 2916, 536, 14, 182, "Print",ExpressionUUID->"b63de9f1-3a26-4973-aa05-0f74737674f4"],
Cell[99244, 2932, 323, 8, 171, "Print",ExpressionUUID->"9a7869b8-7b08-47cc-b7ae-a1925ccd69d3"],
Cell[99570, 2942, 384, 6, 171, "Print",ExpressionUUID->"b2071a16-bf78-4bce-ac5b-c9fd222e3586"],
Cell[99957, 2950, 536, 14, 182, "Print",ExpressionUUID->"0f5ed594-4f8b-4696-a02f-45e5f09c11ac"],
Cell[100496, 2966, 323, 8, 171, "Print",ExpressionUUID->"6fa2bb6f-ae44-4b14-80a0-a3c23d7f0c75"],
Cell[100822, 2976, 384, 6, 171, "Print",ExpressionUUID->"989cceb2-6b13-4e2e-b170-6b0d9381d19d"],
Cell[101209, 2984, 536, 14, 182, "Print",ExpressionUUID->"cbcb7226-5ec7-4ae1-a89f-d7b68f356279"],
Cell[101748, 3000, 323, 8, 171, "Print",ExpressionUUID->"f73af40d-535a-4e42-b998-c875c8c370aa"],
Cell[102074, 3010, 384, 6, 171, "Print",ExpressionUUID->"f7fc19ef-ab1c-4f60-b5b7-3272c28ecec8"],
Cell[102461, 3018, 538, 14, 182, "Print",ExpressionUUID->"397787d0-3637-432b-84c9-efd5a2669497"],
Cell[103002, 3034, 325, 8, 171, "Print",ExpressionUUID->"dbfb2ebe-caa7-4bca-8f1b-046608d5ad73"],
Cell[103330, 3044, 386, 6, 171, "Print",ExpressionUUID->"d0a7930c-d559-4c12-ba1c-8160818a3efe"],
Cell[103719, 3052, 538, 14, 182, "Print",ExpressionUUID->"467ffa7d-07f3-4f34-8c4a-2661498efea0"],
Cell[104260, 3068, 325, 8, 171, "Print",ExpressionUUID->"8a959d61-5602-49e3-870b-19fe6ed73c07"],
Cell[104588, 3078, 386, 6, 171, "Print",ExpressionUUID->"e7145f6f-7965-45d5-847a-febb68ed4ba0"],
Cell[104977, 3086, 558, 15, 182, "Print",ExpressionUUID->"dae6309f-5276-40b0-91c2-2b817edf5aff"],
Cell[105538, 3103, 325, 8, 171, "Print",ExpressionUUID->"ce5ff748-ada3-499e-8270-de6b396844a3"],
Cell[105866, 3113, 386, 6, 171, "Print",ExpressionUUID->"93d4293f-cef5-4ca4-9a3f-86de0812a1fd"],
Cell[106255, 3121, 528, 14, 182, "Print",ExpressionUUID->"7695c34b-67bb-4bdc-ba6d-199868e509ef"],
Cell[106786, 3137, 325, 8, 171, "Print",ExpressionUUID->"5f3a795c-4d4f-4a3c-b997-2a015bce7701"],
Cell[107114, 3147, 383, 6, 171, "Print",ExpressionUUID->"0a4ce374-79be-4e50-83e1-d79e8acea062"],
Cell[107500, 3155, 525, 14, 182, "Print",ExpressionUUID->"5d1720b6-a7bb-4f91-808c-bf66236f3a0e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[108086, 3176, 165, 3, 247, "Subsubsection",ExpressionUUID->"3133c71c-6fc6-4639-9df9-771995106026"],
Cell[108254, 3181, 314, 6, 256, "Text",ExpressionUUID->"ed468c81-00ea-4f26-9152-8243ec63fc7c"],
Cell[108571, 3189, 334, 7, 256, "Text",ExpressionUUID->"ce2802e6-fd9c-4a83-9f87-b0033b0d89b9"],
Cell[CellGroupData[{
Cell[108930, 3200, 1096, 25, 600, "Input",ExpressionUUID->"e5f30780-1f03-4000-ad22-7bc51abce6e1"],
Cell[110029, 3227, 19316, 635, 4419, "Output",ExpressionUUID->"236464bf-9517-4a0d-b1f4-e1c262928054"]
}, Open  ]],
Cell[129360, 3865, 385, 8, 256, "Text",ExpressionUUID->"760432ac-ecb9-451d-bab7-164549d3ba2b"],
Cell[CellGroupData[{
Cell[129770, 3877, 1236, 23, 303, "Input",ExpressionUUID->"54367331-7965-4f19-b037-ef051ec65307"],
Cell[131009, 3902, 11064, 395, 1629, "Output",ExpressionUUID->"f0630ad8-0ae1-4ed3-bd62-dc14b9e606f7"]
}, Open  ]],
Cell[142088, 4300, 517, 15, 348, "Text",ExpressionUUID->"fdd5a3c1-d5e6-4e24-b3e2-e31bb4180a89"],
Cell[142608, 4317, 1060, 29, 454, "Input",ExpressionUUID->"bc605c97-8131-469b-8263-29f908fc436a"],
Cell[143671, 4348, 566, 13, 303, "Input",ExpressionUUID->"779f1093-bad4-4d95-a8ba-68ccc7be0533"],
Cell[144240, 4363, 725, 20, 348, "Text",ExpressionUUID->"5d413c94-85c9-4040-9ac4-536d01251a39"],
Cell[CellGroupData[{
Cell[144990, 4387, 805, 19, 303, "Input",ExpressionUUID->"4fdf202d-559e-4544-90e7-400ef7c034ed"],
Cell[145798, 4408, 10243, 341, 1532, "Output",ExpressionUUID->"bd09eb6a-8a0b-475a-b8f0-3feccc3aa4be"]
}, Open  ]],
Cell[156056, 4752, 925, 22, 519, "Text",ExpressionUUID->"b54702e7-8bc1-4eb6-a406-52c579057bc8"],
Cell[CellGroupData[{
Cell[157006, 4778, 627, 12, 303, "Input",ExpressionUUID->"932df2bc-3629-47d0-b671-b58d5ffc4fc8"],
Cell[157636, 4792, 10391, 341, 1876, "Output",ExpressionUUID->"28df3850-8904-4f9c-a80f-e9a14767a1da"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168064, 5138, 1235, 25, 303, "Input",ExpressionUUID->"d64a38ce-31bb-4d06-9d78-b8537f45e1c9"],
Cell[169302, 5165, 12696, 455, 2362, "Output",ExpressionUUID->"3c713df1-bdab-41e6-8c40-c56d89b546d0"]
}, Open  ]],
Cell[182013, 5623, 230, 4, 256, "Text",ExpressionUUID->"2ddbfd44-5fe5-4e83-bbbc-74f6e6adea5f"],
Cell[CellGroupData[{
Cell[182268, 5631, 2391, 49, 1134, "Input",ExpressionUUID->"57562402-5fc0-4056-bdf8-f67fc243e0c4"],
Cell[CellGroupData[{
Cell[184684, 5684, 473, 13, 222, "Print",ExpressionUUID->"7f466922-694a-45ca-9d5a-58da79e5f849"],
Cell[185160, 5699, 265, 5, 171, "Print",ExpressionUUID->"5e3faba9-78ef-40c2-80c2-807d924025cb"],
Cell[185428, 5706, 631, 20, 182, "Print",ExpressionUUID->"1ba1bea8-920c-44ed-9d99-ee50ac2ea525"],
Cell[186062, 5728, 274, 5, 171, "Print",ExpressionUUID->"2d170b8d-b1f9-45fe-a94f-13152418460f"],
Cell[186339, 5735, 552, 17, 171, "Print",ExpressionUUID->"77d0fafe-c1e6-4fa3-aa91-2470e46c8c0a"],
Cell[186894, 5754, 426, 8, 348, "Print",ExpressionUUID->"bd5340ed-2aa1-4538-b146-cd043134d738"],
Cell[187323, 5764, 586, 18, 202, "Print",ExpressionUUID->"66b76ebf-4adb-4f6a-bb14-ddc6ba3262b6"],
Cell[187912, 5784, 284, 5, 171, "Print",ExpressionUUID->"4e8b3a90-ad35-40a9-9547-d7f236482689"],
Cell[188199, 5791, 620, 20, 171, "Print",ExpressionUUID->"eb3f8376-2b9a-4288-90d9-f303a29f8488"],
Cell[188822, 5813, 473, 13, 222, "Print",ExpressionUUID->"11d18684-111e-4c32-aab3-091b5e0ab163"],
Cell[189298, 5828, 265, 5, 171, "Print",ExpressionUUID->"75f7a4d2-17d2-4252-8c5f-e3d3a4544fe7"],
Cell[189566, 5835, 642, 20, 182, "Print",ExpressionUUID->"26587108-eb7d-4c81-9428-8a02c12ed619"],
Cell[190211, 5857, 274, 5, 171, "Print",ExpressionUUID->"d7ae16ef-3c39-48c7-b906-2acf85c5c5e8"],
Cell[190488, 5864, 552, 17, 171, "Print",ExpressionUUID->"7f516ca4-0cbb-4b13-b685-41e993d4be9a"],
Cell[191043, 5883, 426, 8, 348, "Print",ExpressionUUID->"486ae76f-5824-4905-8c8b-32abe829bccc"],
Cell[191472, 5893, 586, 18, 202, "Print",ExpressionUUID->"b207d285-a4f7-4fae-b91b-884573487f77"],
Cell[192061, 5913, 282, 5, 171, "Print",ExpressionUUID->"f4ed30b7-43d4-497f-a968-e7d7665fd01c"],
Cell[192346, 5920, 621, 20, 171, "Print",ExpressionUUID->"8edd4580-a77e-4a4f-a1e4-4db522c36449"],
Cell[192970, 5942, 471, 13, 222, "Print",ExpressionUUID->"1d1ca40a-e9d1-41d8-80bd-f74a4bd12935"],
Cell[193444, 5957, 263, 5, 171, "Print",ExpressionUUID->"e19d6409-4ca4-4086-bc83-2e80b4ac29f7"],
Cell[193710, 5964, 587, 18, 182, "Print",ExpressionUUID->"a53082e4-5172-401d-9513-e8d37cdf6bf1"],
Cell[194300, 5984, 272, 5, 171, "Print",ExpressionUUID->"5355cc3d-4cc1-4a11-8ce9-268cbbe0ccf2"],
Cell[194575, 5991, 592, 19, 171, "Print",ExpressionUUID->"15bf6743-7367-43fd-8c29-13578fe01037"],
Cell[195170, 6012, 424, 8, 348, "Print",ExpressionUUID->"ef3f70e7-7d6a-4cda-b078-f59477799e1e"],
Cell[195597, 6022, 520, 15, 202, "Print",ExpressionUUID->"10beae44-ae6a-40d6-b11a-e7b3d4af0921"],
Cell[196120, 6039, 282, 5, 171, "Print",ExpressionUUID->"5d5f109a-b512-4343-861b-ea6bdaa96030"],
Cell[196405, 6046, 617, 20, 171, "Print",ExpressionUUID->"4f2c4868-072f-4aa1-ae05-90086b8544d7"],
Cell[197025, 6068, 471, 13, 222, "Print",ExpressionUUID->"5af8640d-eeec-44cc-a552-76c5b6e85514"],
Cell[197499, 6083, 263, 5, 171, "Print",ExpressionUUID->"17f1fabe-9c77-46de-ad8a-bc7b510f12fd"],
Cell[197765, 6090, 587, 18, 182, "Print",ExpressionUUID->"1559d472-f47d-49f1-9148-da9961ca641f"],
Cell[198355, 6110, 272, 5, 171, "Print",ExpressionUUID->"b8aeb87e-240e-4f4f-9bee-6c12e85f3077"],
Cell[198630, 6117, 592, 19, 171, "Print",ExpressionUUID->"c232e676-a2e1-4d5c-bc8c-40f475933bec"],
Cell[199225, 6138, 424, 8, 348, "Print",ExpressionUUID->"d1e666bf-b45b-40c9-a65b-f4bb52406ba7"],
Cell[199652, 6148, 520, 15, 202, "Print",ExpressionUUID->"ef2e2d2c-846d-4cc8-88dd-e740cfc17fb4"],
Cell[200175, 6165, 282, 5, 171, "Print",ExpressionUUID->"e8c5e064-0b64-4219-81d2-9526d68cf469"],
Cell[200460, 6172, 618, 20, 171, "Print",ExpressionUUID->"2bdd3fe0-5061-40b6-a9fa-4359f12a13bd"],
Cell[201081, 6194, 471, 13, 222, "Print",ExpressionUUID->"fa5612e5-a14e-48ef-ae74-02df4866d99b"],
Cell[201555, 6209, 263, 5, 171, "Print",ExpressionUUID->"833da214-8e72-4d4a-88f3-53dca150ebb3"],
Cell[201821, 6216, 598, 18, 182, "Print",ExpressionUUID->"4873892a-236f-4d23-a94e-8e4153562b22"],
Cell[202422, 6236, 272, 5, 171, "Print",ExpressionUUID->"16a946e8-fc88-40ec-8ced-8f248d8ca409"],
Cell[202697, 6243, 592, 19, 171, "Print",ExpressionUUID->"0f428a8a-24d0-4419-ad38-59ebb3fc0088"],
Cell[203292, 6264, 424, 8, 348, "Print",ExpressionUUID->"1dc86154-d26e-458e-8122-7a58eb4c8f5c"],
Cell[203719, 6274, 524, 15, 202, "Print",ExpressionUUID->"2450e42f-88df-44c2-a17d-966ec7b5af24"],
Cell[204246, 6291, 284, 5, 171, "Print",ExpressionUUID->"840ed12d-8413-4c0a-963a-167a2cd3f3fa"],
Cell[204533, 6298, 623, 20, 171, "Print",ExpressionUUID->"92cc7c1a-5c67-48b9-8b78-9f2a3269de51"],
Cell[205159, 6320, 473, 13, 222, "Print",ExpressionUUID->"5045476b-9396-431b-8a93-7a34dd8d5561"],
Cell[205635, 6335, 265, 5, 171, "Print",ExpressionUUID->"bce34401-6a6d-42b4-b4d8-e74796a0d5aa"],
Cell[205903, 6342, 589, 18, 182, "Print",ExpressionUUID->"05709213-a3e4-4fca-8cbe-64bde91e25c1"],
Cell[206495, 6362, 274, 5, 171, "Print",ExpressionUUID->"c39be98e-ca51-4d35-93e0-8c00e1aa8328"],
Cell[206772, 6369, 594, 19, 171, "Print",ExpressionUUID->"0eee461b-be7a-491d-a7c7-d9fbd273f5d7"],
Cell[207369, 6390, 426, 8, 348, "Print",ExpressionUUID->"7d51b46b-6686-4595-a25c-d0f00f2443d3"],
Cell[207798, 6400, 523, 15, 202, "Print",ExpressionUUID->"ae1eae79-ccf9-4e57-84f4-448e77414cbe"],
Cell[208324, 6417, 284, 5, 171, "Print",ExpressionUUID->"0694dcae-b017-4079-901c-7dc89623204e"],
Cell[208611, 6424, 619, 20, 171, "Print",ExpressionUUID->"d4e83bff-492a-44aa-806c-0673948224f6"],
Cell[209233, 6446, 473, 13, 222, "Print",ExpressionUUID->"b4697841-6ca6-4170-9a78-56358b9ae6ce"],
Cell[209709, 6461, 265, 5, 171, "Print",ExpressionUUID->"542ab23b-6cf9-44fc-8204-3f47730a4025"],
Cell[209977, 6468, 631, 20, 182, "Print",ExpressionUUID->"4825815d-4fb9-4351-8096-b28d0afd5660"],
Cell[210611, 6490, 274, 5, 171, "Print",ExpressionUUID->"37149703-a72c-493c-b3e7-31e431b3d5ba"],
Cell[210888, 6497, 552, 17, 171, "Print",ExpressionUUID->"7ead711a-0b43-4ee3-aed4-671c70a2e59c"],
Cell[211443, 6516, 426, 8, 348, "Print",ExpressionUUID->"d3f255c7-703e-4ba8-be31-eda0029a2bef"],
Cell[211872, 6526, 585, 18, 202, "Print",ExpressionUUID->"1b05eb19-4ec8-48db-a38b-7e4a57d144c1"],
Cell[212460, 6546, 282, 5, 171, "Print",ExpressionUUID->"1360d72d-898b-441d-92c4-a93037f39eac"],
Cell[212745, 6553, 617, 20, 171, "Print",ExpressionUUID->"c343bf09-1f4c-4f01-9ec6-5049822c31e8"],
Cell[213365, 6575, 471, 13, 222, "Print",ExpressionUUID->"f100e8c4-ddff-4f02-8f7c-c00d9b5149e4"],
Cell[213839, 6590, 263, 5, 171, "Print",ExpressionUUID->"cbca8f7f-b8e7-42ce-96d4-f084177e45f4"],
Cell[214105, 6597, 629, 20, 182, "Print",ExpressionUUID->"5bd37406-4a03-4b90-b450-73db1487aa78"],
Cell[214737, 6619, 272, 5, 171, "Print",ExpressionUUID->"fc60b278-5f6c-4442-a9f3-89c522dd5d3f"],
Cell[215012, 6626, 550, 17, 171, "Print",ExpressionUUID->"f30b3d2e-b621-4c99-a1dc-c716d0290020"],
Cell[215565, 6645, 424, 8, 348, "Print",ExpressionUUID->"1f41fddf-ddf9-4759-8c3f-18399f780dd1"],
Cell[215992, 6655, 587, 18, 202, "Print",ExpressionUUID->"c301c71f-41d6-48b9-9cb5-57ffdd179e6d"],
Cell[216582, 6675, 284, 5, 171, "Print",ExpressionUUID->"cd55dd47-7601-409c-899b-374f1efe7388"],
Cell[216869, 6682, 621, 20, 171, "Print",ExpressionUUID->"a2aafd1a-7c5a-4063-b48d-b50a93e8983b"],
Cell[217493, 6704, 473, 13, 222, "Print",ExpressionUUID->"cb2152db-183d-4a67-aa3a-e16df43e30f3"],
Cell[217969, 6719, 265, 5, 171, "Print",ExpressionUUID->"3594b6fd-6ac6-4ba8-8d5a-10f5c75eadaf"],
Cell[218237, 6726, 589, 18, 182, "Print",ExpressionUUID->"3eab02a8-18e7-4bf1-af55-e00dd6c98897"],
Cell[218829, 6746, 274, 5, 171, "Print",ExpressionUUID->"c31727e8-9f02-4b5d-84ee-c2232bacc732"],
Cell[219106, 6753, 594, 19, 171, "Print",ExpressionUUID->"c8cb0751-aae6-4b6f-8e82-4be22a9970e8"],
Cell[219703, 6774, 426, 8, 348, "Print",ExpressionUUID->"6f892fa9-2e61-4317-a35d-4fd01e94a8a3"],
Cell[220132, 6784, 523, 15, 202, "Print",ExpressionUUID->"277a6496-2d9a-4145-ac03-6280d034ddfb"],
Cell[220658, 6801, 284, 5, 171, "Print",ExpressionUUID->"627398a6-74a7-430f-91fb-fa53cf817a59"],
Cell[220945, 6808, 621, 20, 171, "Print",ExpressionUUID->"958a487a-2115-4d45-922b-c13e7eae962b"],
Cell[221569, 6830, 474, 13, 222, "Print",ExpressionUUID->"08e20b44-c6ef-46a4-9469-d3069a7fb32b"],
Cell[222046, 6845, 265, 5, 171, "Print",ExpressionUUID->"a2e13f42-7cca-4ee2-b221-e9245bb35d5a"],
Cell[222314, 6852, 600, 18, 182, "Print",ExpressionUUID->"4a6a7535-20b1-4fd2-a203-0f48ab53a862"],
Cell[222917, 6872, 274, 5, 171, "Print",ExpressionUUID->"6129223e-52e0-4f51-983e-e7cc449ea543"],
Cell[223194, 6879, 594, 19, 171, "Print",ExpressionUUID->"e20c1ba3-2807-4a4c-bb1c-97a52ee415f6"],
Cell[223791, 6900, 426, 8, 348, "Print",ExpressionUUID->"ba3ce28f-f9d1-4c59-ab79-85f1311455e9"],
Cell[224220, 6910, 522, 15, 202, "Print",ExpressionUUID->"12bc6e11-d969-4d0e-8609-7e3c486df503"],
Cell[224745, 6927, 282, 5, 171, "Print",ExpressionUUID->"82e15858-f313-4c4d-bae9-7c5d8dc3adce"],
Cell[225030, 6934, 622, 20, 171, "Print",ExpressionUUID->"015039a5-d399-421c-9e5b-32e43f6dcb1e"],
Cell[225655, 6956, 472, 13, 222, "Print",ExpressionUUID->"928a7750-07e5-4992-9b0e-cf2c8cf70d2a"],
Cell[226130, 6971, 263, 5, 171, "Print",ExpressionUUID->"7debdb26-9bba-474a-b1f2-25dbd7cc49a1"],
Cell[226396, 6978, 598, 18, 182, "Print",ExpressionUUID->"65c3312f-5e3d-46bf-8628-0fc9423adc4b"],
Cell[226997, 6998, 272, 5, 171, "Print",ExpressionUUID->"edf76857-b43f-4383-a686-93db0700dcfc"],
Cell[227272, 7005, 592, 19, 171, "Print",ExpressionUUID->"3600ac97-e9e8-44ce-9752-63499d5e776f"],
Cell[227867, 7026, 424, 8, 348, "Print",ExpressionUUID->"5ba02b73-8c80-441f-8fe5-9a30a2393c21"],
Cell[228294, 7036, 522, 15, 202, "Print",ExpressionUUID->"5f0b1bc6-9970-44d5-8062-68b9ad1fd105"],
Cell[228819, 7053, 282, 5, 171, "Print",ExpressionUUID->"5b2c3d00-66f1-4954-bd78-cbc6806236bc"],
Cell[229104, 7060, 623, 20, 171, "Print",ExpressionUUID->"24d5d5b6-1668-495c-a065-5d2fdb6b0891"],
Cell[229730, 7082, 472, 13, 222, "Print",ExpressionUUID->"01d5a5f5-f52a-4047-8d1c-a1bc811dcb9e"],
Cell[230205, 7097, 263, 5, 171, "Print",ExpressionUUID->"5a4e9d80-fd36-412e-bc84-32f90fd8f196"],
Cell[230471, 7104, 640, 20, 182, "Print",ExpressionUUID->"515c4054-fb50-4533-afe5-43f608277c57"],
Cell[231114, 7126, 272, 5, 171, "Print",ExpressionUUID->"d45b6950-04b4-4244-a93a-91f76bbe973f"],
Cell[231389, 7133, 550, 17, 171, "Print",ExpressionUUID->"c35b8672-76af-4df5-9c42-cf25a0d503c6"],
Cell[231942, 7152, 424, 8, 348, "Print",ExpressionUUID->"6e0875eb-78a0-4625-9288-d59def1653d8"],
Cell[232369, 7162, 588, 18, 202, "Print",ExpressionUUID->"c34ec656-b3cf-4741-92a5-bcd829968140"],
Cell[232960, 7182, 284, 5, 171, "Print",ExpressionUUID->"830a1c99-66c5-4786-8f6c-ecc1a69ab401"],
Cell[233247, 7189, 625, 20, 171, "Print",ExpressionUUID->"57d69829-189d-4883-a531-0a0023e20180"],
Cell[233875, 7211, 474, 13, 222, "Print",ExpressionUUID->"92d0ff77-22dc-46fd-bd8c-8930bc6af7ee"],
Cell[234352, 7226, 265, 5, 171, "Print",ExpressionUUID->"bce78e82-5f89-4744-9a57-b476ad1a77c3"],
Cell[234620, 7233, 642, 20, 182, "Print",ExpressionUUID->"7c9043d0-666f-4fff-82db-6e30a1075dbb"],
Cell[235265, 7255, 274, 5, 171, "Print",ExpressionUUID->"3552846d-37cb-4562-82da-bd9c833012f4"],
Cell[235542, 7262, 552, 17, 171, "Print",ExpressionUUID->"53b38449-217d-4afc-9e15-bec092f6a381"],
Cell[236097, 7281, 424, 8, 348, "Print",ExpressionUUID->"46a00834-6fce-434e-bc0b-f0fd22dcd516"],
Cell[236524, 7291, 586, 18, 202, "Print",ExpressionUUID->"a71e7c6b-5adf-4fee-9e18-d650ce650490"],
Cell[237113, 7311, 282, 5, 171, "Print",ExpressionUUID->"9a7691c6-a07d-4bf5-b1c9-c6ca0e54f273"],
Cell[237398, 7318, 622, 20, 171, "Print",ExpressionUUID->"2f2fafed-7f41-4082-b35e-d2dfce5475cd"],
Cell[238023, 7340, 472, 13, 222, "Print",ExpressionUUID->"e73bb5ab-f0ef-473b-863f-7c4e2e605ea4"],
Cell[238498, 7355, 263, 5, 171, "Print",ExpressionUUID->"0bb71c9d-6923-4869-90be-625a8e070313"],
Cell[238764, 7362, 640, 20, 182, "Print",ExpressionUUID->"5be74fd1-c6c4-4eb6-9729-83e970dc193f"],
Cell[239407, 7384, 272, 5, 171, "Print",ExpressionUUID->"ffecac65-b705-445b-8362-b7067b4327e4"],
Cell[239682, 7391, 550, 17, 171, "Print",ExpressionUUID->"356a4eca-f4a3-4e4f-9b9e-de33bcc495f6"],
Cell[240235, 7410, 424, 8, 348, "Print",ExpressionUUID->"efca83d8-f2dc-44b3-a38f-8ac1fca7802c"],
Cell[240662, 7420, 585, 18, 202, "Print",ExpressionUUID->"d38ebb88-3629-4028-bfb9-6fa24c522438"],
Cell[241250, 7440, 281, 5, 171, "Print",ExpressionUUID->"a35b01d3-239c-4fbe-8b2e-4f9736bb7fbf"],
Cell[241534, 7447, 622, 20, 171, "Print",ExpressionUUID->"20cc2f04-4fd0-4646-a60a-445169ab931e"],
Cell[242159, 7469, 471, 13, 222, "Print",ExpressionUUID->"c0e440cc-2530-421b-a914-741527b8d884"],
Cell[242633, 7484, 262, 5, 171, "Print",ExpressionUUID->"7325c4e5-1d13-4b01-91de-0bbd8bcf3bc1"],
Cell[242898, 7491, 597, 18, 182, "Print",ExpressionUUID->"2e1aa563-be03-4214-a7dc-b7f755674600"],
Cell[243498, 7511, 271, 5, 171, "Print",ExpressionUUID->"af84c029-7624-4b97-868b-34e4be937ade"],
Cell[243772, 7518, 591, 19, 171, "Print",ExpressionUUID->"9c65e6bb-68d0-4208-b45a-d9f0c29753b5"],
Cell[244366, 7539, 423, 8, 348, "Print",ExpressionUUID->"4409220e-2a71-430b-85dd-7e24b371f1ea"],
Cell[244792, 7549, 524, 15, 202, "Print",ExpressionUUID->"50786a8a-0bd4-441d-aa4d-ab9bcd18b3fa"],
Cell[245319, 7566, 284, 5, 171, "Print",ExpressionUUID->"dc0eec2d-0aa3-497b-8e73-d867ace34fba"],
Cell[245606, 7573, 625, 20, 171, "Print",ExpressionUUID->"58b29c61-918e-43b0-be8c-37bc2de6ab9e"],
Cell[246234, 7595, 474, 13, 222, "Print",ExpressionUUID->"98842ef1-f26c-42ba-90f0-5e133f8670ed"],
Cell[246711, 7610, 265, 5, 171, "Print",ExpressionUUID->"e92e2232-9149-47bd-bde3-edb4aa8b5f82"],
Cell[246979, 7617, 590, 18, 182, "Print",ExpressionUUID->"e5f2152a-36d0-466a-a6f0-3ab0e46f6b66"],
Cell[247572, 7637, 274, 5, 171, "Print",ExpressionUUID->"7511954d-6900-48f0-8725-0b362639f4d2"],
Cell[247849, 7644, 595, 19, 171, "Print",ExpressionUUID->"308a3eb5-d8fc-487a-91df-51f260f4e2b9"],
Cell[248447, 7665, 426, 8, 348, "Print",ExpressionUUID->"409224f3-ff35-4801-ac07-f9890c8027d4"],
Cell[248876, 7675, 524, 15, 202, "Print",ExpressionUUID->"08b43553-3a46-4992-832d-f4c8e592d14b"],
Cell[249403, 7692, 284, 5, 171, "Print",ExpressionUUID->"1c39af48-4ee8-4faf-b0b7-2a588b6f8396"],
Cell[249690, 7699, 622, 20, 171, "Print",ExpressionUUID->"c2556daf-31c1-4c76-a1cd-c2b02aa4e0db"],
Cell[250315, 7721, 474, 13, 222, "Print",ExpressionUUID->"22fba25c-83f7-49d8-90d5-9e93353007e3"],
Cell[250792, 7736, 265, 5, 171, "Print",ExpressionUUID->"fa6aae4c-8caf-481a-b25d-10da4510d113"],
Cell[251060, 7743, 632, 20, 182, "Print",ExpressionUUID->"a4ddeddb-3ac0-4e6d-809d-2ec5e36d7c9e"],
Cell[251695, 7765, 274, 5, 171, "Print",ExpressionUUID->"9ce81771-3db0-4321-94a4-54ab57f22bff"],
Cell[251972, 7772, 553, 17, 171, "Print",ExpressionUUID->"4c6eae83-0b16-40c8-93b3-f01a1059035a"],
Cell[252528, 7791, 426, 8, 348, "Print",ExpressionUUID->"a122750c-dff5-4d33-b7bd-87486ffab090"],
Cell[252957, 7801, 588, 18, 202, "Print",ExpressionUUID->"0055854a-ad76-4929-9c90-ed02d0d967ac"],
Cell[253548, 7821, 284, 5, 171, "Print",ExpressionUUID->"d7ee8815-65c0-4665-91a9-b49e1dd43374"],
Cell[253835, 7828, 624, 20, 171, "Print",ExpressionUUID->"3e520a8c-dabe-48e8-80a0-74cc9c3e2200"],
Cell[254462, 7850, 474, 13, 222, "Print",ExpressionUUID->"e68a1c4a-203c-46cc-9d72-1b900ec4e7a1"],
Cell[254939, 7865, 265, 5, 171, "Print",ExpressionUUID->"4be747a2-73cc-4f5e-b1ce-e873da9f7849"],
Cell[255207, 7872, 590, 18, 182, "Print",ExpressionUUID->"633b463d-2048-44d1-8211-80151b4b3ba9"],
Cell[255800, 7892, 274, 5, 171, "Print",ExpressionUUID->"de8473ac-fb19-4882-b38c-223ddb85628b"],
Cell[256077, 7899, 595, 19, 171, "Print",ExpressionUUID->"9beb7c79-a91e-4c09-bd44-f55ea5141c85"],
Cell[256675, 7920, 426, 8, 348, "Print",ExpressionUUID->"ca75b7b8-1e56-4115-983b-81f23eda6153"],
Cell[257104, 7930, 524, 15, 202, "Print",ExpressionUUID->"ef8ccc60-aacd-471a-912d-474a18249b70"],
Cell[257631, 7947, 284, 5, 171, "Print",ExpressionUUID->"8389de44-aa63-4025-95de-dc7091bb41ed"],
Cell[257918, 7954, 624, 20, 171, "Print",ExpressionUUID->"5d6025ec-11b5-42bb-9bf8-cb8e3afc3abd"],
Cell[258545, 7976, 474, 13, 222, "Print",ExpressionUUID->"92b7c51d-590e-4c69-a919-fde86ba36ae4"],
Cell[259022, 7991, 265, 5, 171, "Print",ExpressionUUID->"dd23fad3-7398-4dcb-8256-8151f7a20075"],
Cell[259290, 7998, 600, 18, 182, "Print",ExpressionUUID->"cc68b615-5ec3-4713-acdd-7586a78abe49"],
Cell[259893, 8018, 274, 5, 171, "Print",ExpressionUUID->"68d1aeda-5517-4112-9ece-4da157e9ed8c"],
Cell[260170, 8025, 595, 19, 171, "Print",ExpressionUUID->"f4f0479a-af07-4107-86c4-8bb5a030f153"],
Cell[260768, 8046, 426, 8, 348, "Print",ExpressionUUID->"55c18e98-11e6-4386-80c4-3b8a143466f5"],
Cell[261197, 8056, 522, 15, 202, "Print",ExpressionUUID->"f9f531b6-da2e-4124-8ffc-b58e5199904e"],
Cell[261722, 8073, 282, 5, 171, "Print",ExpressionUUID->"f5af8791-47b9-40db-9b50-16a53e10c0b3"],
Cell[262007, 8080, 626, 20, 171, "Print",ExpressionUUID->"4883775b-d7f8-4e01-a39d-d08621b79e5b"],
Cell[262636, 8102, 472, 13, 222, "Print",ExpressionUUID->"156ea0be-28e7-4c0b-90c2-5cfecded9363"],
Cell[263111, 8117, 263, 5, 171, "Print",ExpressionUUID->"b0ead1aa-3cb2-4ed3-a809-a5edae580d91"],
Cell[263377, 8124, 598, 18, 182, "Print",ExpressionUUID->"09862362-1da1-4fc6-bfd2-6eb0cc721864"],
Cell[263978, 8144, 274, 5, 171, "Print",ExpressionUUID->"7e093450-4175-44b1-9076-4f2923a8d0ad"],
Cell[264255, 8151, 595, 19, 171, "Print",ExpressionUUID->"df183a7f-2355-44c2-a840-75a40ece35b7"],
Cell[264853, 8172, 426, 8, 348, "Print",ExpressionUUID->"bb9ee92c-3b1a-4551-b094-dc8e3fdde6c7"],
Cell[265282, 8182, 524, 15, 202, "Print",ExpressionUUID->"b2f8f225-e9b3-4bca-a774-2dd199900864"],
Cell[265809, 8199, 284, 5, 171, "Print",ExpressionUUID->"2ed5ff94-46b8-4a0d-b010-390d7c929bce"],
Cell[266096, 8206, 628, 20, 171, "Print",ExpressionUUID->"c57a36b8-2232-41c6-82c5-2d758741c584"],
Cell[266727, 8228, 474, 13, 222, "Print",ExpressionUUID->"9ca2b2c6-625f-4d95-8609-5180d4631e59"],
Cell[267204, 8243, 265, 5, 171, "Print",ExpressionUUID->"c14fe1c3-5c91-4f5f-ba73-9727ba087be1"],
Cell[267472, 8250, 642, 20, 182, "Print",ExpressionUUID->"f62bf90b-021b-4c9c-89f6-5ab6bd32271c"],
Cell[268117, 8272, 274, 5, 171, "Print",ExpressionUUID->"977872bb-0419-4297-af17-46761d707ac2"],
Cell[268394, 8279, 553, 17, 171, "Print",ExpressionUUID->"3801e71c-1630-4724-938a-ded6f5720aaf"],
Cell[268950, 8298, 426, 8, 348, "Print",ExpressionUUID->"067178dd-59f2-4602-bcb0-415df5ace681"],
Cell[269379, 8308, 588, 18, 202, "Print",ExpressionUUID->"8b830054-f9ed-4fb0-8801-1c332fa15c11"],
Cell[269970, 8328, 284, 5, 171, "Print",ExpressionUUID->"a6d90110-2e59-4427-8d26-e8428216816f"],
Cell[270257, 8335, 628, 20, 171, "Print",ExpressionUUID->"ce84e981-d85c-40b4-b940-c62f03e280bd"],
Cell[270888, 8357, 474, 13, 222, "Print",ExpressionUUID->"97540c7f-febc-4979-911c-36431fd79715"],
Cell[271365, 8372, 265, 5, 171, "Print",ExpressionUUID->"7cb856fa-078b-457f-9151-338e366de964"],
Cell[271633, 8379, 642, 20, 182, "Print",ExpressionUUID->"92e0b060-2388-44ef-a07c-408b17cd158a"],
Cell[272278, 8401, 274, 5, 171, "Print",ExpressionUUID->"d7f8899b-6546-47d0-ae95-666073defb4d"],
Cell[272555, 8408, 553, 17, 171, "Print",ExpressionUUID->"4774e95a-d1b3-46c0-a170-de6d5db8be87"],
Cell[273111, 8427, 426, 8, 348, "Print",ExpressionUUID->"ac867c8d-354d-48f3-826f-e6d937e88f7d"],
Cell[273540, 8437, 571, 17, 202, "Print",ExpressionUUID->"acff7c59-98ed-4c56-a8aa-2b56005fb74e"],
Cell[274114, 8456, 282, 5, 171, "Print",ExpressionUUID->"a4d716db-5781-48d3-99e5-b4afaa5d58b1"],
Cell[274399, 8463, 626, 20, 171, "Print",ExpressionUUID->"e2b54c8f-f7e7-42ff-accf-d804beedbc85"],
Cell[275028, 8485, 472, 13, 222, "Print",ExpressionUUID->"9235c2e0-aab9-4f21-8874-8a6b1dc97317"],
Cell[275503, 8500, 263, 5, 171, "Print",ExpressionUUID->"2c58b34a-3173-4174-852e-274e66a3eb44"],
Cell[275769, 8507, 642, 20, 182, "Print",ExpressionUUID->"c9a39edd-0913-49d0-a2e5-843cdb48bd37"],
Cell[276414, 8529, 272, 5, 171, "Print",ExpressionUUID->"902a6264-17de-457a-a2bd-bc320a8bd213"],
Cell[276689, 8536, 509, 15, 171, "Print",ExpressionUUID->"cbc4ff0d-91f2-4b0d-a5d9-1af1977d57f6"],
Cell[277201, 8553, 424, 8, 348, "Print",ExpressionUUID->"a79d1944-edb4-44aa-9ef8-ad8c377ecf42"],
Cell[277628, 8563, 569, 17, 202, "Print",ExpressionUUID->"3c00c56c-9d44-4690-ab3e-fba230dcd562"],
Cell[278200, 8582, 284, 5, 171, "Print",ExpressionUUID->"2cfe42cf-d2f2-4e85-ac52-9cdac079af61"],
Cell[278487, 8589, 628, 20, 171, "Print",ExpressionUUID->"bf09ad26-c7b9-4b5c-a0f7-6e6e6a36ea23"],
Cell[279118, 8611, 474, 13, 222, "Print",ExpressionUUID->"760db434-63fb-4d0c-b721-e886045c947b"],
Cell[279595, 8626, 265, 5, 171, "Print",ExpressionUUID->"9f0b89c0-8e71-451e-a7a0-eaa4888080ef"],
Cell[279863, 8633, 644, 20, 182, "Print",ExpressionUUID->"295691e6-3672-41a5-a50d-da8c3f56337a"],
Cell[280510, 8655, 274, 5, 171, "Print",ExpressionUUID->"230c4aa0-0a5e-43d5-ac2b-d033afb0c9b6"],
Cell[280787, 8662, 511, 15, 171, "Print",ExpressionUUID->"3ee2d887-f868-45f0-a7d9-4c0bc4e26f12"],
Cell[281301, 8679, 426, 8, 348, "Print",ExpressionUUID->"16d075d4-b06b-4999-9f37-87c7ab1f0e58"],
Cell[281730, 8689, 569, 17, 202, "Print",ExpressionUUID->"ce242588-76bb-499e-979a-f26991c64573"],
Cell[282302, 8708, 284, 5, 171, "Print",ExpressionUUID->"efc000e3-b7a4-4b53-b3f9-2853ccc2b10f"],
Cell[282589, 8715, 624, 20, 171, "Print",ExpressionUUID->"3850bb04-1bec-43e2-8e25-bcd67ba37a2d"],
Cell[283216, 8737, 474, 13, 222, "Print",ExpressionUUID->"617919b0-06f1-40ea-b3ed-81ad61e6fcfd"],
Cell[283693, 8752, 265, 5, 171, "Print",ExpressionUUID->"c5e89b2b-7f59-4922-9274-4f051ba9b48a"],
Cell[283961, 8759, 600, 18, 182, "Print",ExpressionUUID->"7e32afea-ecd0-47d4-beb9-573f44a21532"],
Cell[284564, 8779, 274, 5, 171, "Print",ExpressionUUID->"c4903f0f-243f-42ee-acd3-42ff49714e06"],
Cell[284841, 8786, 595, 19, 171, "Print",ExpressionUUID->"e8186802-9877-4683-8102-4a59d940569c"],
Cell[285439, 8807, 426, 8, 348, "Print",ExpressionUUID->"53a4d506-d734-4556-a44e-96c48cb19482"],
Cell[285868, 8817, 522, 15, 202, "Print",ExpressionUUID->"f932953a-5052-4940-bedb-fdf95287c389"],
Cell[286393, 8834, 282, 5, 171, "Print",ExpressionUUID->"43acf8f4-e74d-49a8-a9a2-1ac319951544"],
Cell[286678, 8841, 622, 20, 171, "Print",ExpressionUUID->"96a6b4a5-aedf-4843-a6f7-587e6044ce4e"],
Cell[287303, 8863, 472, 13, 222, "Print",ExpressionUUID->"a8d4905e-ae7e-4094-84bb-374ee23d6eaf"],
Cell[287778, 8878, 263, 5, 171, "Print",ExpressionUUID->"09b77633-cbc8-4d73-a39f-7b174019b8b0"],
Cell[288044, 8885, 598, 18, 182, "Print",ExpressionUUID->"e30e8e30-edae-4de4-811b-a8485b1c057a"],
Cell[288645, 8905, 272, 5, 171, "Print",ExpressionUUID->"41bdf649-bfbc-4ecb-a896-cfae50c16b73"],
Cell[288920, 8912, 593, 19, 171, "Print",ExpressionUUID->"b91ae83e-61a7-4645-b7f0-a5ae523746b2"],
Cell[289516, 8933, 424, 8, 348, "Print",ExpressionUUID->"3a99f7ed-7883-4cdc-85c2-40ccc6fad1db"],
Cell[289943, 8943, 522, 15, 202, "Print",ExpressionUUID->"8ca2c656-fd7b-41bc-94e1-916b20ec19fa"],
Cell[290468, 8960, 282, 5, 171, "Print",ExpressionUUID->"5de03faa-bbe2-4ede-94ee-760ca76a8c9f"],
Cell[290753, 8967, 623, 20, 171, "Print",ExpressionUUID->"a7bae9d4-df9a-4bf8-b169-180f13dcd165"],
Cell[291379, 8989, 470, 13, 222, "Print",ExpressionUUID->"7fde8eb6-437b-46d1-b53e-96d26cefc720"],
Cell[291852, 9004, 261, 5, 171, "Print",ExpressionUUID->"93a4fa8c-4139-47f9-a478-c1fc2fe26d6c"],
Cell[292116, 9011, 596, 18, 182, "Print",ExpressionUUID->"84a71d21-46a5-4cb2-8d8e-079e20326ef2"],
Cell[292715, 9031, 270, 5, 171, "Print",ExpressionUUID->"6dba8a6b-19bc-474e-9615-fd653c6296be"],
Cell[292988, 9038, 592, 19, 171, "Print",ExpressionUUID->"e131f22a-2c75-41b2-84c5-bcba25b66794"],
Cell[293583, 9059, 422, 8, 348, "Print",ExpressionUUID->"3207705e-1f7c-4e64-b08e-28a2388a0b70"],
Cell[294008, 9069, 520, 15, 202, "Print",ExpressionUUID->"1ea86163-a253-4dc9-b223-60c7aac40b4c"],
Cell[294531, 9086, 280, 5, 171, "Print",ExpressionUUID->"19cfabec-62eb-4be9-9969-57d814dca1b3"],
Cell[294814, 9093, 624, 20, 171, "Print",ExpressionUUID->"36de8dd2-1670-4197-9497-cdd115ab6bc1"],
Cell[295441, 9115, 470, 13, 222, "Print",ExpressionUUID->"d8c361b9-5d59-4e15-9d06-1f56c725e584"],
Cell[295914, 9130, 263, 5, 171, "Print",ExpressionUUID->"98d2ccc5-9cc1-4793-886b-c3a2dbe21452"],
Cell[296180, 9137, 640, 20, 182, "Print",ExpressionUUID->"58f4e46d-ef22-42b1-98a8-06ed35c1bc24"],
Cell[296823, 9159, 272, 5, 171, "Print",ExpressionUUID->"faf64e4f-e382-402c-9408-34f8184b5a39"],
Cell[297098, 9166, 552, 17, 171, "Print",ExpressionUUID->"5071ab02-fe3a-4a5e-b99c-4d7e8f3f0008"],
Cell[297653, 9185, 424, 8, 348, "Print",ExpressionUUID->"f829924f-5850-4045-b4e2-9e67b652329e"],
Cell[298080, 9195, 586, 18, 202, "Print",ExpressionUUID->"21a0ba91-d075-4a47-bba7-db1a5082f510"],
Cell[298669, 9215, 282, 5, 171, "Print",ExpressionUUID->"bebb5b5d-790a-4598-b257-9373549bcc15"],
Cell[298954, 9222, 626, 20, 171, "Print",ExpressionUUID->"4f0ffc59-1108-4c5b-9dae-8b1e301f233f"],
Cell[299583, 9244, 472, 13, 222, "Print",ExpressionUUID->"67fcf738-f31b-4acf-a9cb-9452f65d406d"],
Cell[300058, 9259, 263, 5, 171, "Print",ExpressionUUID->"a5dfff63-6ab6-4a35-85a4-ab587469d544"],
Cell[300324, 9266, 588, 18, 182, "Print",ExpressionUUID->"7dc610f2-f254-40b9-aa2a-bac42e145891"],
Cell[300915, 9286, 272, 5, 171, "Print",ExpressionUUID->"b823992b-dfd5-421a-9ff4-2c30403e1915"],
Cell[301190, 9293, 593, 19, 171, "Print",ExpressionUUID->"e9ca615c-3a8b-49e3-8915-9fdd3afe4b00"],
Cell[301786, 9314, 424, 8, 348, "Print",ExpressionUUID->"93e85755-8b0b-40ea-ab26-4ff9a589adbe"],
Cell[302213, 9324, 523, 15, 202, "Print",ExpressionUUID->"dd09b23e-bd85-46eb-bcf4-d1ede7abb683"],
Cell[302739, 9341, 282, 5, 171, "Print",ExpressionUUID->"e0f590f4-c541-42aa-864f-0c54d936453b"],
Cell[303024, 9348, 620, 20, 171, "Print",ExpressionUUID->"4460752e-9d74-4d96-b03e-2a150d179ed6"],
Cell[303647, 9370, 472, 13, 222, "Print",ExpressionUUID->"8bf9be6a-bfc3-41c7-a297-5566f0419672"],
Cell[304122, 9385, 263, 5, 171, "Print",ExpressionUUID->"7a616f1e-7572-4b43-a10d-e937a683472a"],
Cell[304388, 9392, 588, 18, 182, "Print",ExpressionUUID->"bf263582-34de-41bf-8716-40007a566c9f"],
Cell[304979, 9412, 272, 5, 171, "Print",ExpressionUUID->"073c441b-5ed8-4ab1-9e3e-6687188ee3b0"],
Cell[305254, 9419, 593, 19, 171, "Print",ExpressionUUID->"7e08d897-0739-4e88-a500-3051dee9349c"],
Cell[305850, 9440, 424, 8, 348, "Print",ExpressionUUID->"7aa729cc-a416-4a58-9a76-376b1747749f"],
Cell[306277, 9450, 524, 15, 202, "Print",ExpressionUUID->"bee4f5a4-09a4-4322-8037-a8a487e78679"],
Cell[306804, 9467, 282, 5, 171, "Print",ExpressionUUID->"6909481a-dede-41ac-9b74-318eb47d53c1"],
Cell[307089, 9474, 623, 20, 171, "Print",ExpressionUUID->"4b99112d-e22e-44be-82b4-9a6cdc1e9e78"]
}, Open  ]]
}, Open  ]],
Cell[307739, 9498, 167, 3, 256, "Text",ExpressionUUID->"aaa64169-d3b4-4604-b117-bb6607ba1ff3"],
Cell[307909, 9503, 803, 13, 454, "Input",ExpressionUUID->"c51b4fe5-8a40-4ff0-b6ab-20e6389f0b09"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[308761, 9522, 230, 4, 515, "Section",ExpressionUUID->"885f9177-28f9-4ff7-b1fc-8d088038493e"],
Cell[CellGroupData[{
Cell[309016, 9530, 217, 4, 247, "Subsubsection",ExpressionUUID->"622af1b7-37ab-4ec4-941e-fdb70e1a22b7"],
Cell[309236, 9536, 927, 24, 256, "Text",ExpressionUUID->"e3b38c36-e286-4897-a186-3e70f05123b6"],
Cell[310166, 9562, 583, 15, 303, "Input",ExpressionUUID->"d3787089-89d8-458e-89cb-4dee8443e5eb"],
Cell[310752, 9579, 403, 8, 256, "Text",ExpressionUUID->"0db2660a-5de3-4663-86fe-9525b4068d2a"],
Cell[CellGroupData[{
Cell[311180, 9591, 953, 25, 303, "Input",ExpressionUUID->"946e0e6e-e622-4d40-ac00-8a1a0020e4f1"],
Cell[312136, 9618, 1793, 51, 495, "Output",ExpressionUUID->"bef50dba-c7d4-4d91-b50e-5f219c40abde"]
}, Open  ]],
Cell[313944, 9672, 303, 5, 256, "Text",ExpressionUUID->"18708309-7b01-4115-ae68-b5052f5b6ec6"],
Cell[314250, 9679, 617, 15, 303, "Input",ExpressionUUID->"01172021-977f-4b70-877e-118a2d9d6fb0"],
Cell[CellGroupData[{
Cell[314892, 9698, 783, 22, 303, "Input",ExpressionUUID->"e855303e-4c11-4e86-91a9-f15ef7bf5d1d"],
Cell[315678, 9722, 1418, 45, 519, "Output",ExpressionUUID->"4912db0c-4328-49ee-b550-2ba862199c54"]
}, Open  ]],
Cell[317111, 9770, 221, 4, 256, "Text",ExpressionUUID->"3f70fffd-c420-4b0f-a149-fa03accc1cdc"],
Cell[317335, 9776, 684, 16, 303, "Input",ExpressionUUID->"a4496ed6-e69d-475b-ad22-6647968b5cf2"],
Cell[CellGroupData[{
Cell[318044, 9796, 977, 25, 303, "Input",ExpressionUUID->"421315a8-e0cc-4661-b6b2-5e1ed100d488"],
Cell[319024, 9823, 1412, 40, 353, "Output",ExpressionUUID->"96ea9710-7139-47ce-bb44-cd6f164df9a0"]
}, Open  ]],
Cell[320451, 9866, 267, 6, 256, "Text",ExpressionUUID->"478e9607-6c3a-4c0a-b4cd-9c86fb265c34"],
Cell[CellGroupData[{
Cell[320743, 9876, 1247, 29, 303, "Input",ExpressionUUID->"2fce0eec-697a-493c-b78c-c3c015912d51"],
Cell[321993, 9907, 1386, 40, 353, "Output",ExpressionUUID->"5cb787ea-b8ce-47bd-b40e-f042891a63a4"]
}, Open  ]],
Cell[323394, 9950, 285, 4, 303, "Input",ExpressionUUID->"5aee0914-09b8-4385-8dba-ee28124df196"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323716, 9959, 214, 4, 247, "Subsubsection",ExpressionUUID->"949c252c-2f0a-4cc6-8b41-a7b6e93eef30"],
Cell[323933, 9965, 800, 20, 256, "Text",ExpressionUUID->"5f827fc2-d9c4-4840-be2e-1f4cfe9a96e3"],
Cell[324736, 9987, 635, 17, 303, "Input",ExpressionUUID->"e931853d-de62-4b80-8b47-ad7ac0155b7a"],
Cell[325374, 10006, 354, 7, 256, "Text",ExpressionUUID->"db6d330e-1e44-4b99-91eb-151f15203105"],
Cell[CellGroupData[{
Cell[325753, 10017, 2468, 78, 600, "Input",ExpressionUUID->"97187457-9be8-48c8-8b55-75549b615377"],
Cell[328224, 10097, 2289, 77, 454, "Output",ExpressionUUID->"6040f1e0-9224-4c59-9d2e-af685e173749"]
}, Open  ]],
Cell[330528, 10177, 175, 3, 256, "Text",ExpressionUUID->"c2b10984-4e39-46a2-9317-cf5dfd43df4a"],
Cell[CellGroupData[{
Cell[330728, 10184, 219, 3, 303, "Input",ExpressionUUID->"be4c2016-44c8-4300-b394-63dfa093956c"],
Cell[330950, 10189, 172, 2, 303, "Output",ExpressionUUID->"4d513246-0e76-4770-a75c-dc86be979fd1"]
}, Open  ]],
Cell[331137, 10194, 664, 11, 596, "Text",ExpressionUUID->"6fc9cf26-e45f-44ce-8c69-c24954305829"],
Cell[331804, 10207, 2835, 67, 1620, "Input",ExpressionUUID->"898b8691-7b88-4d87-8317-9c10a3759e17"],
Cell[CellGroupData[{
Cell[334664, 10278, 288, 5, 303, "Input",ExpressionUUID->"05da9260-adfa-4622-893f-8e0d1572532e"],
Cell[CellGroupData[{
Cell[334977, 10287, 336, 9, 171, "Print",ExpressionUUID->"19d165e7-eb27-495e-b4d8-1d7c0bcab9f3"],
Cell[335316, 10298, 713, 13, 324, "Print",ExpressionUUID->"496742c6-71d1-4683-b599-d44be0b3f997"],
Cell[336032, 10313, 555, 16, 182, "Print",ExpressionUUID->"90545b66-5134-4afb-a19c-9c4c2df250eb"],
Cell[336590, 10331, 336, 9, 171, "Print",ExpressionUUID->"f714b6f6-0cb1-4931-82b6-c1dd8679a318"],
Cell[336929, 10342, 713, 13, 324, "Print",ExpressionUUID->"26b4dd7c-83aa-47e3-9ff6-43ededcbe8d7"],
Cell[337645, 10357, 590, 17, 182, "Print",ExpressionUUID->"e6ca8327-7b9b-42d5-bb3c-4aa216893240"],
Cell[338238, 10376, 336, 9, 171, "Print",ExpressionUUID->"b448f4eb-885c-4df2-a3a2-3dde841e7b7e"],
Cell[338577, 10387, 713, 13, 324, "Print",ExpressionUUID->"b29598a2-befa-4b2e-9c98-4dc23f1714f7"],
Cell[339293, 10402, 557, 16, 182, "Print",ExpressionUUID->"4725a1ba-100b-4a7b-8e21-1e4aa49f4bb1"],
Cell[339853, 10420, 338, 9, 171, "Print",ExpressionUUID->"70876fd3-bf90-4ee1-986f-ff0dc85e977b"],
Cell[340194, 10431, 715, 13, 324, "Print",ExpressionUUID->"36720242-9974-4966-b81e-2c11a9de9b10"],
Cell[340912, 10446, 592, 17, 182, "Print",ExpressionUUID->"0cb7b3f4-531f-41d1-b753-1adfe7487c21"],
Cell[341507, 10465, 338, 9, 171, "Print",ExpressionUUID->"26ede2dd-7724-4ffb-903f-a03cd481862b"],
Cell[341848, 10476, 715, 13, 324, "Print",ExpressionUUID->"6b8084f5-bd76-465f-afcd-d15e33720ca8"],
Cell[342566, 10491, 557, 16, 182, "Print",ExpressionUUID->"d387e872-f0fb-4730-8152-dd1a47cdeda7"],
Cell[343126, 10509, 338, 9, 171, "Print",ExpressionUUID->"6d15d902-e04c-40ca-843c-37c723758db0"],
Cell[343467, 10520, 715, 13, 324, "Print",ExpressionUUID->"d8904b39-606d-45ea-81a8-04dde17d0281"],
Cell[344185, 10535, 592, 17, 182, "Print",ExpressionUUID->"7bc33986-8238-4b1f-a5ce-27b1cbfa4be6"],
Cell[344780, 10554, 338, 9, 171, "Print",ExpressionUUID->"0e5a42e7-43c8-442f-b196-41aad19fe8e2"],
Cell[345121, 10565, 715, 13, 324, "Print",ExpressionUUID->"f3ebe622-d95e-4a44-8ccd-b394499e0192"],
Cell[345839, 10580, 592, 17, 182, "Print",ExpressionUUID->"c4855160-68a1-4811-87d4-0c116ada3025"],
Cell[346434, 10599, 338, 9, 171, "Print",ExpressionUUID->"28fc7554-fe14-4b66-9144-717b72e3b27b"],
Cell[346775, 10610, 715, 13, 324, "Print",ExpressionUUID->"008f32da-d702-4272-97fb-21f509212746"],
Cell[347493, 10625, 557, 16, 182, "Print",ExpressionUUID->"d940c1f4-d286-4895-a106-b7604e664519"],
Cell[348053, 10643, 338, 9, 171, "Print",ExpressionUUID->"3ec15b65-1c06-4e15-ba29-8072bde48b3a"],
Cell[348394, 10654, 715, 13, 324, "Print",ExpressionUUID->"54b81315-6a72-498b-b480-62446cbe0497"],
Cell[349112, 10669, 554, 16, 182, "Print",ExpressionUUID->"1c2ba4fe-7300-4432-813a-9dc9f65ba02e"],
Cell[349669, 10687, 336, 9, 171, "Print",ExpressionUUID->"329f6364-0b19-4baf-8d86-6c82d3bd49ac"],
Cell[350008, 10698, 712, 13, 324, "Print",ExpressionUUID->"52cea06f-6876-4db6-a2d4-82f27df9ce2f"],
Cell[350723, 10713, 589, 17, 182, "Print",ExpressionUUID->"253e5d15-0f2a-4037-b1bd-99341a83bb36"],
Cell[351315, 10732, 336, 9, 171, "Print",ExpressionUUID->"13a9950c-e265-4dc3-8d43-3f31f4f96218"],
Cell[351654, 10743, 712, 13, 324, "Print",ExpressionUUID->"604b4718-db87-41ed-b36d-c4e7eddd88bf"],
Cell[352369, 10758, 589, 17, 182, "Print",ExpressionUUID->"72e1614e-d749-4a6c-9ee6-db256b5b02fe"],
Cell[352961, 10777, 336, 9, 171, "Print",ExpressionUUID->"3e0034c1-ce3d-4701-b4aa-b89de603ace8"],
Cell[353300, 10788, 712, 13, 324, "Print",ExpressionUUID->"87383d77-5034-42e7-9614-b1e3b9bc1b44"],
Cell[354015, 10803, 590, 17, 182, "Print",ExpressionUUID->"16846b5c-2faf-4e6f-a6f4-5e81f635ebe6"],
Cell[354608, 10822, 337, 9, 171, "Print",ExpressionUUID->"142f6d10-45ff-44d9-adc2-b5fcef068066"],
Cell[354948, 10833, 713, 13, 324, "Print",ExpressionUUID->"a17acb11-813e-48a4-8992-29f714c048a2"],
Cell[355664, 10848, 556, 16, 182, "Print",ExpressionUUID->"781cebb6-fa1a-419e-a7ae-98e9359dd948"],
Cell[356223, 10866, 337, 9, 171, "Print",ExpressionUUID->"69dbec10-d395-4706-88ec-0340f444ba7e"],
Cell[356563, 10877, 713, 13, 324, "Print",ExpressionUUID->"870fc76e-f672-43a0-a207-100ad636a0de"],
Cell[357279, 10892, 556, 16, 182, "Print",ExpressionUUID->"f588b61f-24f9-472e-a58a-9a619c385d67"],
Cell[357838, 10910, 337, 9, 171, "Print",ExpressionUUID->"6dcb0435-d937-4e88-b296-02744a4b0650"],
Cell[358178, 10921, 713, 13, 324, "Print",ExpressionUUID->"92e8b14b-081e-4903-8cdb-712f5ae0c4c9"],
Cell[358894, 10936, 591, 17, 182, "Print",ExpressionUUID->"d2316235-a01e-4bc3-96ba-1facbd4af057"],
Cell[359488, 10955, 337, 9, 171, "Print",ExpressionUUID->"6dc097f8-72b2-4fac-956f-62bdd7781dbd"],
Cell[359828, 10966, 713, 13, 324, "Print",ExpressionUUID->"e6c22bda-a399-4ee5-a192-46f52f8b0720"],
Cell[360544, 10981, 591, 17, 182, "Print",ExpressionUUID->"c44069a4-4bbf-4fbf-8bed-2e2fd21aaca1"],
Cell[361138, 11000, 337, 9, 171, "Print",ExpressionUUID->"312f6b2d-9910-470c-8e14-81842107a233"],
Cell[361478, 11011, 713, 13, 324, "Print",ExpressionUUID->"2d9b8f9e-beec-4996-9e16-61eb1d253037"],
Cell[362194, 11026, 591, 17, 182, "Print",ExpressionUUID->"0b0ed190-30b3-4368-bc95-b56e3440d326"],
Cell[362788, 11045, 337, 9, 171, "Print",ExpressionUUID->"68a646c4-2eda-4a40-bae5-160e1848fae8"],
Cell[363128, 11056, 713, 13, 324, "Print",ExpressionUUID->"a193a96a-3f39-4e53-993e-a72ca2d4bc61"],
Cell[363844, 11071, 591, 17, 182, "Print",ExpressionUUID->"5490857e-7ee1-4ab4-af88-4f49eba5f38e"],
Cell[364438, 11090, 339, 9, 171, "Print",ExpressionUUID->"09660aa6-eecb-4ed5-be92-140cd9d61664"],
Cell[364780, 11101, 715, 13, 324, "Print",ExpressionUUID->"835589bb-e55c-40a8-ab74-02d32edcc7af"],
Cell[365498, 11116, 593, 17, 182, "Print",ExpressionUUID->"24975730-6a3d-4735-8609-26835fea6e86"],
Cell[366094, 11135, 339, 9, 171, "Print",ExpressionUUID->"5a1e3003-c218-41ef-b191-418cfd467774"],
Cell[366436, 11146, 715, 13, 324, "Print",ExpressionUUID->"1a9b8ead-8890-4a9c-9ce5-c0dacb87832c"],
Cell[367154, 11161, 613, 18, 182, "Print",ExpressionUUID->"1c30e84d-8d81-4f9f-8968-4b619b4ed051"],
Cell[367770, 11181, 339, 9, 171, "Print",ExpressionUUID->"2298a32d-e407-4d9d-8d29-7822f1807af1"],
Cell[368112, 11192, 715, 13, 324, "Print",ExpressionUUID->"9f04e8c9-f091-413c-8a3a-1bf9f8183c80"],
Cell[368830, 11207, 593, 17, 182, "Print",ExpressionUUID->"b4c1fad8-3ee1-4de9-b89c-f68f1370a4ea"],
Cell[369426, 11226, 337, 9, 171, "Print",ExpressionUUID->"7e202ce2-d639-4d93-8c45-7b9cf565831d"],
Cell[369766, 11237, 713, 13, 324, "Print",ExpressionUUID->"f098b4d2-40df-4a7b-997d-f0d8cbf6e666"],
Cell[370482, 11252, 591, 17, 182, "Print",ExpressionUUID->"6ce544de-5e29-4731-ad9e-b9e706960722"],
Cell[371076, 11271, 339, 9, 171, "Print",ExpressionUUID->"484b76c2-3c4b-4fe4-890a-58d58c30dbce"],
Cell[371418, 11282, 715, 13, 324, "Print",ExpressionUUID->"c0114737-fee5-4fae-81aa-eedf6517d8ec"],
Cell[372136, 11297, 593, 17, 182, "Print",ExpressionUUID->"6cc83c85-d62c-4073-8511-85b3129e5e37"],
Cell[372732, 11316, 339, 9, 171, "Print",ExpressionUUID->"e97ca0b9-754c-444c-9c24-f702b60e34da"],
Cell[373074, 11327, 715, 13, 324, "Print",ExpressionUUID->"1c0a83e0-ff0c-455f-9cf4-7b6b858690a9"],
Cell[373792, 11342, 594, 17, 182, "Print",ExpressionUUID->"21ff4474-a55d-496c-bcd4-86e62f7904d6"],
Cell[374389, 11361, 339, 9, 171, "Print",ExpressionUUID->"593d7f8b-078d-4e3e-9082-7fa12fc32240"],
Cell[374731, 11372, 715, 13, 324, "Print",ExpressionUUID->"71395f0d-c892-437c-ae9c-526cc6c154ce"],
Cell[375449, 11387, 594, 17, 182, "Print",ExpressionUUID->"ebadda24-b0d6-4ef2-a2f9-af20685d55c9"],
Cell[376046, 11406, 339, 9, 171, "Print",ExpressionUUID->"3e727dfd-664f-46eb-89bd-59d9cdb09767"],
Cell[376388, 11417, 715, 13, 324, "Print",ExpressionUUID->"702d06db-fdd0-4821-8ca8-cbb6e7bb448d"],
Cell[377106, 11432, 558, 16, 182, "Print",ExpressionUUID->"b88964e3-9567-4df6-a3aa-afc5dcffc9d7"],
Cell[377667, 11450, 339, 9, 171, "Print",ExpressionUUID->"20296f92-d1db-4d99-bc3f-9994bdb38622"],
Cell[378009, 11461, 715, 13, 324, "Print",ExpressionUUID->"19a61fb5-aeda-49bb-9bd2-0701f7ad2f1f"],
Cell[378727, 11476, 558, 16, 182, "Print",ExpressionUUID->"68a9fbb9-6dd6-4fc8-9e70-00fcf87ea9fa"],
Cell[379288, 11494, 339, 9, 171, "Print",ExpressionUUID->"081f659d-60e4-46c6-acb5-87251e1f3ff0"],
Cell[379630, 11505, 715, 13, 324, "Print",ExpressionUUID->"8599fc94-fcf3-4008-9db0-ae43b7d045e8"],
Cell[380348, 11520, 593, 17, 182, "Print",ExpressionUUID->"13b57719-239f-421a-9a42-5e5b3fa65413"],
Cell[380944, 11539, 337, 9, 171, "Print",ExpressionUUID->"36cf8ef4-5950-40a6-a045-11f95d1e1b92"],
Cell[381284, 11550, 713, 13, 324, "Print",ExpressionUUID->"34a3f105-b35b-4fb2-9374-33f755ca72eb"],
Cell[382000, 11565, 591, 17, 182, "Print",ExpressionUUID->"0b5fb103-95c3-4f3f-8a93-c76eec8f7668"],
Cell[382594, 11584, 337, 9, 171, "Print",ExpressionUUID->"1801378e-b5af-4e75-8984-3556c8cc8efc"],
Cell[382934, 11595, 713, 13, 324, "Print",ExpressionUUID->"54e29a68-3c08-41de-9476-20206e24fb96"],
Cell[383650, 11610, 592, 17, 182, "Print",ExpressionUUID->"100fb36f-ebfd-4084-b983-d76bcc451661"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[384303, 11634, 163, 3, 247, "Subsubsection",ExpressionUUID->"5809a7f1-5eed-4ba9-b7b8-ecfe235a1047"],
Cell[384469, 11639, 9783, 231, 4641, "Input",ExpressionUUID->"89c7d7ed-dfc0-417a-9e17-461e6f46a038"],
Cell[CellGroupData[{
Cell[394277, 11874, 302, 4, 303, "Input",ExpressionUUID->"55dc3cde-dbe6-47ec-a550-86f0a4c9ba9b"],
Cell[CellGroupData[{
Cell[394604, 11882, 471, 13, 222, "Print",ExpressionUUID->"8c099913-a113-48c1-bf86-f299ee167e7b"],
Cell[395078, 11897, 263, 5, 171, "Print",ExpressionUUID->"d10fa203-12d1-4c49-8124-88f672f1fb4c"],
Cell[395344, 11904, 521, 15, 182, "Print",ExpressionUUID->"0fe1bd93-b2f3-4826-acdb-31c8c48dced0"],
Cell[395868, 11921, 272, 5, 171, "Print",ExpressionUUID->"b4b3d6af-b888-4ead-b31c-7b7dbd2543d5"],
Cell[396143, 11928, 583, 19, 231, "Print",ExpressionUUID->"a3f9d721-4f9f-4d0e-bd0e-c5a54e9afed2"],
Cell[396729, 11949, 408, 7, 348, "Print",ExpressionUUID->"9e4ad02f-6c4c-4f99-ac00-969131404dce"],
Cell[397140, 11958, 608, 19, 202, "Print",ExpressionUUID->"615d3b00-db5a-41d9-8ccc-da4211a88708"],
Cell[397751, 11979, 443, 8, 348, "Print",ExpressionUUID->"32263580-f4ff-4afd-a9d2-25d21066ad15"],
Cell[398197, 11989, 603, 19, 171, "Print",ExpressionUUID->"c5c95838-f578-446e-afd6-7261f1f2cc02"],
Cell[398803, 12010, 473, 13, 222, "Print",ExpressionUUID->"26edb23a-8036-4f61-9bac-f94a9d2f55af"],
Cell[399279, 12025, 265, 5, 171, "Print",ExpressionUUID->"60acb3a5-1cb9-413b-9459-da05bc7ebd74"],
Cell[399547, 12032, 558, 16, 182, "Print",ExpressionUUID->"cb99c1d4-23d6-4641-abc5-e8afc25679c2"],
Cell[400108, 12050, 274, 5, 171, "Print",ExpressionUUID->"696400b0-cd9d-418f-996d-6d5e5f25129e"],
Cell[400385, 12057, 571, 18, 171, "Print",ExpressionUUID->"eb785d2d-5895-4c92-b9db-a989ee9e3e20"],
Cell[400959, 12077, 406, 7, 348, "Print",ExpressionUUID->"facdf25e-3049-4e4a-ade1-98d6bf2f5eb4"],
Cell[401368, 12086, 605, 19, 202, "Print",ExpressionUUID->"203921d8-934d-4091-8052-b1ca8b12ec1c"],
Cell[401976, 12107, 441, 8, 348, "Print",ExpressionUUID->"1538cad0-d59a-4f40-ae4d-5945352234ee"],
Cell[402420, 12117, 572, 18, 171, "Print",ExpressionUUID->"c66f6b4c-9dee-4b25-b4bd-63553e60f0bc"],
Cell[402995, 12137, 471, 13, 222, "Print",ExpressionUUID->"4d62b571-4db5-49f3-838f-8259b099af0f"],
Cell[403469, 12152, 263, 5, 171, "Print",ExpressionUUID->"0784d937-dc89-49ae-b4b3-a3b5ce9551f9"],
Cell[403735, 12159, 521, 15, 182, "Print",ExpressionUUID->"50501f08-749e-4b39-aece-5e587fa2c1bc"],
Cell[404259, 12176, 272, 5, 171, "Print",ExpressionUUID->"15949756-a558-4a60-95fe-65eb132a9bac"],
Cell[404534, 12183, 592, 19, 171, "Print",ExpressionUUID->"742591d8-b28c-43db-9789-deede64d19f8"],
Cell[405129, 12204, 406, 7, 348, "Print",ExpressionUUID->"03248185-5a02-4a0e-b94f-620fa0bd690f"],
Cell[405538, 12213, 608, 19, 202, "Print",ExpressionUUID->"ea726a37-b818-4656-842e-3631cdb5896e"],
Cell[406149, 12234, 443, 8, 348, "Print",ExpressionUUID->"ecc4a845-4ec0-4ad3-9148-6cb108bc5f91"],
Cell[406595, 12244, 579, 18, 171, "Print",ExpressionUUID->"f75d1572-717c-4c46-af26-a369fc9b089c"],
Cell[407177, 12264, 473, 13, 222, "Print",ExpressionUUID->"3b743213-02ea-4f1d-b19f-caf497f8cceb"],
Cell[407653, 12279, 265, 5, 171, "Print",ExpressionUUID->"e818e560-cca9-47b1-96ed-87c3d4100f8d"],
Cell[407921, 12286, 558, 16, 182, "Print",ExpressionUUID->"cf279e51-169f-4d3e-ad82-43fe1d65ad16"],
Cell[408482, 12304, 274, 5, 171, "Print",ExpressionUUID->"ccb4746b-69fd-4474-8190-8214d7f96714"],
Cell[408759, 12311, 637, 21, 231, "Print",ExpressionUUID->"7f44ee5e-8fe4-4c42-a9c9-9772e3a2415f"],
Cell[409399, 12334, 406, 7, 348, "Print",ExpressionUUID->"d10883d6-a828-4952-b6bf-427188fdf941"],
Cell[409808, 12343, 605, 19, 202, "Print",ExpressionUUID->"5e46001f-e68d-4008-afe1-abcff70136e9"],
Cell[410416, 12364, 441, 8, 348, "Print",ExpressionUUID->"a2d447e5-5903-4017-892a-2435ecbbf0c6"],
Cell[410860, 12374, 600, 19, 171, "Print",ExpressionUUID->"4a641503-a330-4a05-aa87-a0716bc76f6f"],
Cell[411463, 12395, 471, 13, 222, "Print",ExpressionUUID->"3efa1906-c5eb-45fe-98df-7712ccd127d1"],
Cell[411937, 12410, 263, 5, 171, "Print",ExpressionUUID->"2439250a-f654-46f6-8d97-988d28b9c3b7"],
Cell[412203, 12417, 521, 15, 182, "Print",ExpressionUUID->"e13bacef-a41b-4722-b31e-d4d38f19c79b"],
Cell[412727, 12434, 272, 5, 171, "Print",ExpressionUUID->"3b98e58f-cb30-4798-b5b2-f89e2de9a410"],
Cell[413002, 12441, 592, 19, 171, "Print",ExpressionUUID->"e50a185f-6767-48fe-bdc3-cd80ffa0b430"],
Cell[413597, 12462, 405, 7, 348, "Print",ExpressionUUID->"254abd65-e24d-444f-acb0-89c9bd1565ac"],
Cell[414005, 12471, 608, 19, 202, "Print",ExpressionUUID->"d76b9d2d-aa19-4d61-b3ae-83df6f0e5647"],
Cell[414616, 12492, 443, 8, 348, "Print",ExpressionUUID->"156a1439-2f8e-4ab1-92de-0a491e4f032f"],
Cell[415062, 12502, 579, 18, 171, "Print",ExpressionUUID->"a66eb434-2478-42c7-9076-40d7bae811a8"],
Cell[415644, 12522, 473, 13, 222, "Print",ExpressionUUID->"048e69c3-79ca-4267-b2b2-b290a8719245"],
Cell[416120, 12537, 265, 5, 171, "Print",ExpressionUUID->"dbe61515-4a2f-41a7-bcb9-5bd32366701d"],
Cell[416388, 12544, 558, 16, 182, "Print",ExpressionUUID->"7cdd7625-d24d-49ea-9047-36ba9e4182a7"],
Cell[416949, 12562, 274, 5, 171, "Print",ExpressionUUID->"9fbde73f-e423-4259-858f-80285381a12e"],
Cell[417226, 12569, 625, 21, 231, "Print",ExpressionUUID->"029b0f2f-1ed5-4273-997a-1a3a6aab2a55"],
Cell[417854, 12592, 408, 7, 348, "Print",ExpressionUUID->"cf914c21-70a0-4dc9-86c1-1fd7e71b2402"],
Cell[418265, 12601, 609, 19, 202, "Print",ExpressionUUID->"565d41f3-30ac-4996-858d-5706ef833396"],
Cell[418877, 12622, 443, 8, 348, "Print",ExpressionUUID->"6a5547b0-4161-4e0d-9cc3-8cbb5796a0a6"],
Cell[419323, 12632, 579, 18, 171, "Print",ExpressionUUID->"eb45b857-5b47-44b0-b58d-0bf6eee71874"],
Cell[419905, 12652, 473, 13, 222, "Print",ExpressionUUID->"10ab7bc4-8517-426b-aa22-1303bf3802de"],
Cell[420381, 12667, 265, 5, 171, "Print",ExpressionUUID->"6399cdad-944a-4d0c-a23b-ae998ea698df"],
Cell[420649, 12674, 558, 16, 182, "Print",ExpressionUUID->"e5df7c09-5e89-4622-9af3-4327cbffb54f"],
Cell[421210, 12692, 274, 5, 171, "Print",ExpressionUUID->"2946c6bf-a0db-4571-a838-d76fabc1d969"],
Cell[421487, 12699, 637, 21, 231, "Print",ExpressionUUID->"0d3038a2-f71a-4746-b171-796a608f0ce6"],
Cell[422127, 12722, 408, 7, 348, "Print",ExpressionUUID->"7ecbbb79-15a2-4fe6-8ef0-995c3113d536"],
Cell[422538, 12731, 609, 19, 202, "Print",ExpressionUUID->"80d49708-4346-430d-8e20-4faebd566fed"],
Cell[423150, 12752, 443, 8, 348, "Print",ExpressionUUID->"d2c20de0-23a9-4cf2-9129-b811027735b2"],
Cell[423596, 12762, 603, 19, 171, "Print",ExpressionUUID->"aabcf676-ffcb-402d-b019-51d0ed03164d"],
Cell[424202, 12783, 471, 13, 222, "Print",ExpressionUUID->"6c2e14d3-3162-4c0d-ac8d-1f399c5ad6fc"],
Cell[424676, 12798, 263, 5, 171, "Print",ExpressionUUID->"b7b03407-7d01-407a-9af6-f7479a05774c"],
Cell[424942, 12805, 521, 15, 182, "Print",ExpressionUUID->"c041cdfd-33b1-4337-a3c6-e08f7a3efedb"],
Cell[425466, 12822, 272, 5, 171, "Print",ExpressionUUID->"864a3656-0684-49e3-b78f-c78879601725"],
Cell[425741, 12829, 625, 21, 231, "Print",ExpressionUUID->"5d538709-1986-49fd-a560-649b3f507f6f"],
Cell[426369, 12852, 408, 7, 348, "Print",ExpressionUUID->"081fac2d-8770-45a0-905b-4a4f72249b96"],
Cell[426780, 12861, 608, 19, 202, "Print",ExpressionUUID->"c02a4eb4-229b-488d-8502-eeb41aa10975"],
Cell[427391, 12882, 443, 8, 348, "Print",ExpressionUUID->"d31af488-d983-4988-a5e5-10a565184595"],
Cell[427837, 12892, 582, 18, 171, "Print",ExpressionUUID->"a73c365b-cc91-41da-ba81-5aed7555ce9d"],
Cell[428422, 12912, 473, 13, 222, "Print",ExpressionUUID->"68c0b63c-9518-4469-8db4-87d547f288d2"],
Cell[428898, 12927, 265, 5, 171, "Print",ExpressionUUID->"ef3f4db0-4799-410e-8388-c8f1fbf28ff5"],
Cell[429166, 12934, 523, 15, 182, "Print",ExpressionUUID->"747760d4-bdbf-48bc-ae73-b06bf306c28c"],
Cell[429692, 12951, 274, 5, 171, "Print",ExpressionUUID->"e37371f8-f685-4ac0-a523-4dc581803e70"],
Cell[429969, 12958, 585, 19, 231, "Print",ExpressionUUID->"846be20a-9245-4888-bf31-d0842e2da22a"],
Cell[430557, 12979, 408, 7, 348, "Print",ExpressionUUID->"e8778f67-5e24-49e6-9a9b-9b26740a7916"],
Cell[430968, 12988, 608, 19, 202, "Print",ExpressionUUID->"725b1edc-057b-4ddd-b3a1-1d773266b5e9"],
Cell[431579, 13009, 443, 8, 348, "Print",ExpressionUUID->"055e0289-61da-4146-98e8-c425110b1586"],
Cell[432025, 13019, 603, 19, 171, "Print",ExpressionUUID->"fa445803-0af4-4634-b7b2-d650db5d1f38"],
Cell[432631, 13040, 474, 13, 222, "Print",ExpressionUUID->"fd8410cd-1419-4b5b-9d08-725706f8697b"],
Cell[433108, 13055, 265, 5, 171, "Print",ExpressionUUID->"7a5f5b84-188a-4c72-b29b-015e4b1f80ba"],
Cell[433376, 13062, 558, 16, 182, "Print",ExpressionUUID->"4abadd8c-2361-4060-a2ce-108cb4a82066"],
Cell[433937, 13080, 274, 5, 171, "Print",ExpressionUUID->"ccd48861-cbc3-460a-8d78-4775452bd570"],
Cell[434214, 13087, 625, 21, 231, "Print",ExpressionUUID->"8048ceca-c80c-43a9-8314-5ca85c5dd068"],
Cell[434842, 13110, 406, 7, 348, "Print",ExpressionUUID->"c0944bd0-8e1c-419f-a66c-de6ed165c30f"],
Cell[435251, 13119, 607, 19, 202, "Print",ExpressionUUID->"6666b01c-6c6a-4499-9721-de0b00e214c4"],
Cell[435861, 13140, 440, 8, 348, "Print",ExpressionUUID->"19dfb384-dfb0-44ab-ab46-e0dc8b0842e7"],
Cell[436304, 13150, 621, 20, 171, "Print",ExpressionUUID->"f38ff93c-67bc-476f-aa34-4c3c32751c18"],
Cell[436928, 13172, 471, 13, 222, "Print",ExpressionUUID->"ec29b266-5465-4f3b-ad5e-8fc420f6336c"],
Cell[437402, 13187, 262, 5, 171, "Print",ExpressionUUID->"83c56c6e-3a62-43c8-a43a-cb92a53fb556"],
Cell[437667, 13194, 555, 16, 182, "Print",ExpressionUUID->"1f5d13d3-5a3f-49b5-a9f0-57af5167a745"],
Cell[438225, 13212, 271, 5, 171, "Print",ExpressionUUID->"a44078ea-452c-42f8-8c4c-7a6c853c49c9"],
Cell[438499, 13219, 676, 23, 231, "Print",ExpressionUUID->"ff568744-2fa6-4c2a-a4ce-390209a26dc8"],
Cell[439178, 13244, 408, 7, 348, "Print",ExpressionUUID->"0bb87b6e-294b-4148-be01-f83a83d703f3"],
Cell[439589, 13253, 607, 19, 202, "Print",ExpressionUUID->"481cd006-dc89-429b-985f-1875bd873d8e"],
Cell[440199, 13274, 441, 8, 348, "Print",ExpressionUUID->"116dd65d-10fa-47e0-82ef-fd5d97ff8173"],
Cell[440643, 13284, 583, 18, 171, "Print",ExpressionUUID->"aa80a60b-efc5-48a7-9e98-3624c2a3f8cd"],
Cell[441229, 13304, 474, 13, 222, "Print",ExpressionUUID->"a43dbead-2460-4cae-a17d-df4c9465f335"],
Cell[441706, 13319, 265, 5, 171, "Print",ExpressionUUID->"580518cc-3f87-4de1-aec0-cd6fc7401899"],
Cell[441974, 13326, 558, 16, 182, "Print",ExpressionUUID->"ffad8d71-92bb-4eb3-9c29-f722e7ff0212"],
Cell[442535, 13344, 274, 5, 171, "Print",ExpressionUUID->"8a07b0d2-65bb-41cf-8193-ed86d0f4a548"],
Cell[442812, 13351, 594, 19, 171, "Print",ExpressionUUID->"96d1e1f9-f632-478c-897e-73e39dae611e"],
Cell[443409, 13372, 408, 7, 348, "Print",ExpressionUUID->"9001b544-acf5-468e-ab1c-a64e645bafd4"],
Cell[443820, 13381, 527, 16, 202, "Print",ExpressionUUID->"e88be689-76dd-43f4-9c65-5fa6f4d668c9"],
Cell[444350, 13399, 441, 8, 348, "Print",ExpressionUUID->"3d3c464c-b31f-4cb3-90f2-03a2b795bb39"],
Cell[444794, 13409, 581, 18, 171, "Print",ExpressionUUID->"37ddedd1-a77b-43f6-be00-f26b10b3f329"],
Cell[445378, 13429, 472, 13, 222, "Print",ExpressionUUID->"a610fa06-c070-4c26-9ec9-09d02da9d4d5"],
Cell[445853, 13444, 263, 5, 171, "Print",ExpressionUUID->"a239dbd9-47cf-4eb9-a5ae-d2d2b772a148"],
Cell[446119, 13451, 522, 15, 182, "Print",ExpressionUUID->"6950e1f7-a074-47f1-b925-a71a714d58c4"],
Cell[446644, 13468, 272, 5, 171, "Print",ExpressionUUID->"063e3891-090d-49e3-8fda-d0fb0891996f"],
Cell[446919, 13475, 625, 21, 231, "Print",ExpressionUUID->"d81075b0-ee9c-4039-bf51-a78cacbf9118"],
Cell[447547, 13498, 406, 7, 348, "Print",ExpressionUUID->"d786dcbe-4eb4-4430-8a6d-b10e4406274e"],
Cell[447956, 13507, 606, 19, 202, "Print",ExpressionUUID->"396315a4-befb-4b55-a557-20e049fa44a1"],
Cell[448565, 13528, 441, 8, 348, "Print",ExpressionUUID->"45a6ef47-6670-421a-bb3e-7908c77e713c"],
Cell[449009, 13538, 580, 18, 171, "Print",ExpressionUUID->"f412db95-5c02-46ef-8619-b375b1313b96"],
Cell[449592, 13558, 472, 13, 222, "Print",ExpressionUUID->"4ea65e3e-759d-44fe-9f37-1dd90e376489"],
Cell[450067, 13573, 263, 5, 171, "Print",ExpressionUUID->"f69e25d6-f021-46e6-97e0-597abf425ce9"],
Cell[450333, 13580, 522, 15, 182, "Print",ExpressionUUID->"513f047f-9b06-4158-8b1c-0ef574bb5aaf"],
Cell[450858, 13597, 272, 5, 171, "Print",ExpressionUUID->"89b18138-b986-4fb7-8dc0-a735e264450b"],
Cell[451133, 13604, 635, 21, 231, "Print",ExpressionUUID->"51f78ea3-f37f-4475-a6bc-c61458f59e37"],
Cell[451771, 13627, 408, 7, 348, "Print",ExpressionUUID->"ccfa2335-a49c-47cb-8094-104351b1b14d"],
Cell[452182, 13636, 606, 19, 202, "Print",ExpressionUUID->"2ef5ca3e-3589-4cbe-b082-040151913e6d"],
Cell[452791, 13657, 441, 8, 348, "Print",ExpressionUUID->"d91d70c1-1e1a-40a4-b829-dd854bc26a94"],
Cell[453235, 13667, 603, 19, 171, "Print",ExpressionUUID->"b7995bff-0a4c-4418-8689-cfa2b25d024a"],
Cell[453841, 13688, 472, 13, 222, "Print",ExpressionUUID->"ee99500c-80b6-423d-8aee-b5767160a247"],
Cell[454316, 13703, 263, 5, 171, "Print",ExpressionUUID->"220b07b8-eea4-4a0d-88cf-852da37d5268"],
Cell[454582, 13710, 557, 16, 182, "Print",ExpressionUUID->"5db9b948-c42b-4e17-94d8-65638822efd7"],
Cell[455142, 13728, 272, 5, 171, "Print",ExpressionUUID->"73bf0a6f-e963-487e-9574-615f34b2b054"],
Cell[455417, 13735, 625, 21, 231, "Print",ExpressionUUID->"34ccaf07-b00a-4fab-aa99-959add1a290f"],
Cell[456045, 13758, 408, 7, 348, "Print",ExpressionUUID->"e2e9d9af-f7d7-45da-b542-d835e6c2a3ee"],
Cell[456456, 13767, 608, 19, 202, "Print",ExpressionUUID->"ff3b40c3-98bd-42dc-aded-2c301569354a"],
Cell[457067, 13788, 441, 8, 348, "Print",ExpressionUUID->"1be955fe-eebe-4f91-bc9e-82b8623a910b"],
Cell[457511, 13798, 581, 18, 171, "Print",ExpressionUUID->"19825f0d-c175-46c8-bc4a-72751d31d541"],
Cell[458095, 13818, 472, 13, 222, "Print",ExpressionUUID->"8a062ef9-e6e6-4a6e-a01d-3fd9f3c4f2f3"],
Cell[458570, 13833, 263, 5, 171, "Print",ExpressionUUID->"71ea0aa1-96b4-4bc4-93b8-be290c2d4549"],
Cell[458836, 13840, 557, 16, 182, "Print",ExpressionUUID->"5be203f6-9011-44ce-bb98-294c7c733f49"],
Cell[459396, 13858, 272, 5, 171, "Print",ExpressionUUID->"4297e1bb-f669-4709-8ef5-e9833125078f"],
Cell[459671, 13865, 623, 21, 231, "Print",ExpressionUUID->"937fea13-a809-4eb0-b578-cbd371c30398"],
Cell[460297, 13888, 406, 7, 348, "Print",ExpressionUUID->"9c79bb95-eab5-4602-af20-40915bc7b13e"],
Cell[460706, 13897, 608, 19, 202, "Print",ExpressionUUID->"9774282a-dec8-40d9-a358-c58be8e49705"],
Cell[461317, 13918, 441, 8, 348, "Print",ExpressionUUID->"25133a5b-36d9-41cc-9502-fcd98ca8a20c"],
Cell[461761, 13928, 625, 20, 171, "Print",ExpressionUUID->"9282cd53-d94c-445c-99a4-99f77a98a2af"],
Cell[462389, 13950, 474, 13, 222, "Print",ExpressionUUID->"62e89357-5336-4fe0-b8c0-67df1a83f4fc"],
Cell[462866, 13965, 265, 5, 171, "Print",ExpressionUUID->"9b6eb59a-80ed-47a0-a371-7738df03ff4f"],
Cell[463134, 13972, 559, 16, 182, "Print",ExpressionUUID->"23f64513-0be0-4a0b-927a-52a0ce6e591c"],
Cell[463696, 13990, 274, 5, 171, "Print",ExpressionUUID->"38cc50da-bfad-4deb-acee-66fb61d2ddbd"],
Cell[463973, 13997, 573, 18, 171, "Print",ExpressionUUID->"6907e48b-529f-4885-9974-680967430305"],
Cell[464549, 14017, 408, 7, 348, "Print",ExpressionUUID->"370288e3-ed67-4d29-8805-30439db2bb76"],
Cell[464960, 14026, 608, 19, 202, "Print",ExpressionUUID->"351fe78a-0a99-4498-9441-a69894f87c16"],
Cell[465571, 14047, 441, 8, 348, "Print",ExpressionUUID->"6be34ea9-ebb8-4dbc-970b-d9115a9c8967"],
Cell[466015, 14057, 577, 18, 171, "Print",ExpressionUUID->"2ee17bbf-9fbe-4145-a790-3039d927ab66"],
Cell[466595, 14077, 472, 13, 222, "Print",ExpressionUUID->"baa3b89b-3cea-43e0-b24b-15b0be974b58"],
Cell[467070, 14092, 263, 5, 171, "Print",ExpressionUUID->"5d7d3442-03c1-4aa5-aefe-dd6b63207b4d"],
Cell[467336, 14099, 557, 16, 182, "Print",ExpressionUUID->"c42890bb-6bb4-463b-940d-763f23986244"],
Cell[467896, 14117, 272, 5, 171, "Print",ExpressionUUID->"f7c4d704-d941-4de0-888e-57f61dac5cbc"],
Cell[468171, 14124, 583, 19, 231, "Print",ExpressionUUID->"643e3fd1-0de5-4bfe-bc8f-07d1e05f5594"],
Cell[468757, 14145, 408, 7, 348, "Print",ExpressionUUID->"1f007a5a-4817-4a7c-b128-1dea3e8263be"],
Cell[469168, 14154, 610, 19, 202, "Print",ExpressionUUID->"71dddda4-afad-439c-a9ef-ecf348ae704c"],
Cell[469781, 14175, 443, 8, 348, "Print",ExpressionUUID->"65bcf3f9-6a03-487a-802e-d571ff863297"],
Cell[470227, 14185, 609, 19, 171, "Print",ExpressionUUID->"e3d6a52c-7b40-442d-adc1-c6753231c587"],
Cell[470839, 14206, 474, 13, 222, "Print",ExpressionUUID->"43fa093f-fef4-4e61-927a-fce1f0170f4a"],
Cell[471316, 14221, 265, 5, 171, "Print",ExpressionUUID->"9bcb2e6b-4faf-4b0d-9a57-dd6e8cc2774b"],
Cell[471584, 14228, 559, 16, 182, "Print",ExpressionUUID->"ccdeb35d-12ce-4aaa-977c-c5e4e022907f"],
Cell[472146, 14246, 274, 5, 171, "Print",ExpressionUUID->"e6e18d31-f7db-498c-a556-c9119b2f36b4"],
Cell[472423, 14253, 585, 19, 231, "Print",ExpressionUUID->"05fd7676-4cc1-4f2c-b789-0b9541d9d7c6"],
Cell[473011, 14274, 408, 7, 348, "Print",ExpressionUUID->"bf59150d-6e41-4c94-bab6-be2e8f89f02d"],
Cell[473422, 14283, 610, 19, 202, "Print",ExpressionUUID->"587a613e-f9df-4825-ac82-64a1f8073877"],
Cell[474035, 14304, 443, 8, 348, "Print",ExpressionUUID->"ed08d2af-8304-4e13-9231-7c8bd25f1d5e"],
Cell[474481, 14314, 607, 19, 171, "Print",ExpressionUUID->"11104265-1785-43a3-85a1-61e2ecd796a9"],
Cell[475091, 14335, 472, 13, 222, "Print",ExpressionUUID->"14a38a44-22d9-43af-b40d-495ac31a7eab"],
Cell[475566, 14350, 263, 5, 171, "Print",ExpressionUUID->"ed5699df-18db-4023-a1f9-6e447876a5f3"],
Cell[475832, 14357, 577, 17, 182, "Print",ExpressionUUID->"dfd96cb8-1cdb-4d79-880f-8665d0188fad"],
Cell[476412, 14376, 272, 5, 171, "Print",ExpressionUUID->"3fe1d15c-f0a1-4e9a-a65b-2688b3e350d3"],
Cell[476687, 14383, 508, 15, 171, "Print",ExpressionUUID->"e2cda6ec-3137-469b-bd26-fc04079261aa"],
Cell[477198, 14400, 406, 7, 348, "Print",ExpressionUUID->"b86d12bb-789e-456e-9511-b9368602eb92"],
Cell[477607, 14409, 651, 21, 202, "Print",ExpressionUUID->"5701b5f1-d33f-4f26-8e08-8facff041f14"],
Cell[478261, 14432, 441, 8, 348, "Print",ExpressionUUID->"32de5a89-be2b-48aa-a65e-bc0537c26ef7"],
Cell[478705, 14442, 558, 17, 171, "Print",ExpressionUUID->"ace217ed-bb3a-4b99-957b-9a6b7fdbf6da"],
Cell[479266, 14461, 474, 13, 222, "Print",ExpressionUUID->"cf314b57-79d0-4030-bb08-3e2c0eadbb41"],
Cell[479743, 14476, 265, 5, 171, "Print",ExpressionUUID->"5568c8ed-c765-4141-bb55-418ddf2bb4d1"],
Cell[480011, 14483, 559, 16, 182, "Print",ExpressionUUID->"3ee69028-8469-4ab2-80e7-3a51b5ae3580"],
Cell[480573, 14501, 274, 5, 171, "Print",ExpressionUUID->"0a4fafff-82d9-4e96-ad29-f428640ad838"],
Cell[480850, 14508, 679, 23, 231, "Print",ExpressionUUID->"37c8462a-ef0f-43ff-bf48-872fe5b4dd5d"],
Cell[481532, 14533, 408, 7, 348, "Print",ExpressionUUID->"58bdaf2b-54d3-4221-8810-6b5fa904ebc5"],
Cell[481943, 14542, 607, 19, 202, "Print",ExpressionUUID->"9ef39c53-23ff-46c6-b78f-138dea26a0d3"],
Cell[482553, 14563, 441, 8, 348, "Print",ExpressionUUID->"55d18b6b-1a14-4b14-8d91-a552ec361a9d"],
Cell[482997, 14573, 585, 18, 171, "Print",ExpressionUUID->"79b02d88-0817-4934-907e-16f93fc60f54"],
Cell[483585, 14593, 474, 13, 222, "Print",ExpressionUUID->"81584ad9-7146-4c36-b1eb-8cb9ddc0c372"],
Cell[484062, 14608, 265, 5, 171, "Print",ExpressionUUID->"13870eb4-5b19-4d66-9f9e-688e21e79608"],
Cell[484330, 14615, 559, 16, 182, "Print",ExpressionUUID->"e18b4b89-69b2-475d-854b-a25277ef2c99"],
Cell[484892, 14633, 274, 5, 171, "Print",ExpressionUUID->"9a1486c3-3fb7-4db1-9215-55cde27d8919"],
Cell[485169, 14640, 679, 23, 231, "Print",ExpressionUUID->"59c6559b-c583-421d-9334-7d8af478a826"],
Cell[485851, 14665, 408, 7, 348, "Print",ExpressionUUID->"efd3b696-417f-4b33-a69b-f4771227361d"],
Cell[486262, 14674, 607, 19, 202, "Print",ExpressionUUID->"05a274c4-777e-47d6-b625-3e4d2f7bac3f"],
Cell[486872, 14695, 441, 8, 348, "Print",ExpressionUUID->"50d61068-92a9-4ffb-b6cd-1a845830bf78"],
Cell[487316, 14705, 583, 18, 171, "Print",ExpressionUUID->"38a72e76-8f0c-40c3-9c8a-49a878f9fb12"],
Cell[487902, 14725, 472, 13, 222, "Print",ExpressionUUID->"d86ac549-dc30-4a40-ac4d-6bb754bc539e"],
Cell[488377, 14740, 263, 5, 171, "Print",ExpressionUUID->"09e1129d-d999-460f-97bc-acacedd11bd8"],
Cell[488643, 14747, 557, 16, 182, "Print",ExpressionUUID->"1e4e7cc9-8328-497a-8663-90ad89bac816"],
Cell[489203, 14765, 272, 5, 171, "Print",ExpressionUUID->"91d87589-dca0-4778-9630-62f0e00945d7"],
Cell[489478, 14772, 583, 19, 231, "Print",ExpressionUUID->"914acbe4-3628-4be0-990d-edb56c5c3add"],
Cell[490064, 14793, 408, 7, 348, "Print",ExpressionUUID->"42b2c1e6-ab7c-429a-b99d-c004bbe2bf5a"],
Cell[490475, 14802, 607, 19, 202, "Print",ExpressionUUID->"c01fec3d-016b-4458-9b0e-0f36ede67448"],
Cell[491085, 14823, 441, 8, 348, "Print",ExpressionUUID->"452cd0d2-a78b-4aa3-9f5e-63cc3ba09700"],
Cell[491529, 14833, 604, 19, 171, "Print",ExpressionUUID->"cfc1995f-ad54-4d8d-bfbc-cc93a32ec0aa"],
Cell[492136, 14854, 472, 13, 222, "Print",ExpressionUUID->"3e6ef417-2c2c-4186-8b7c-a3e8e002d99f"],
Cell[492611, 14869, 263, 5, 171, "Print",ExpressionUUID->"d913285f-b009-4f32-8cb7-bccc44bf5a01"],
Cell[492877, 14876, 558, 16, 182, "Print",ExpressionUUID->"9905e00a-ab02-4aff-a191-04d4a3d32233"],
Cell[493438, 14894, 272, 5, 171, "Print",ExpressionUUID->"8f421290-056f-4413-8317-7bf3d533defe"],
Cell[493713, 14901, 677, 23, 231, "Print",ExpressionUUID->"0f75ed1a-7cc4-489a-bb30-b3065c34cbb5"],
Cell[494393, 14926, 406, 7, 348, "Print",ExpressionUUID->"88f97804-9d3a-4b08-8aa4-fe10beb96a31"],
Cell[494802, 14935, 610, 19, 202, "Print",ExpressionUUID->"55c9e933-bd8f-4cb4-81dd-833695411699"],
Cell[495415, 14956, 443, 8, 348, "Print",ExpressionUUID->"11956cba-6b56-4308-88a6-a1e00e42ca61"],
Cell[495861, 14966, 580, 18, 171, "Print",ExpressionUUID->"e42effb7-490a-4e82-b6c2-55eb9ec3e789"],
Cell[496444, 14986, 471, 13, 222, "Print",ExpressionUUID->"69ed8914-a8a8-4491-8604-202dc130c7fe"],
Cell[496918, 15001, 262, 5, 171, "Print",ExpressionUUID->"7a9fa828-4fb9-4898-ada2-cd0b1640855e"],
Cell[497183, 15008, 557, 16, 182, "Print",ExpressionUUID->"317cc63a-3371-4e14-9dfc-038ef7198d0f"],
Cell[497743, 15026, 271, 5, 171, "Print",ExpressionUUID->"3695c2c9-7115-4101-b731-7243815ff51d"],
Cell[498017, 15033, 549, 17, 171, "Print",ExpressionUUID->"e12ba2f8-8a08-4539-b3ff-89c0ac1e1686"],
Cell[498569, 15052, 405, 7, 348, "Print",ExpressionUUID->"8e4b066b-8e3c-4147-9ae9-84f029c5f747"],
Cell[498977, 15061, 608, 19, 202, "Print",ExpressionUUID->"0ec94f98-70c4-4ff9-88a3-6fdacc69b8d8"],
Cell[499588, 15082, 441, 8, 348, "Print",ExpressionUUID->"79ec73ab-b07f-4901-94eb-752691e05abd"],
Cell[500032, 15092, 607, 19, 171, "Print",ExpressionUUID->"9701cac0-b4be-400b-91a6-77a93637a0dd"],
Cell[500642, 15113, 472, 13, 222, "Print",ExpressionUUID->"ecc1ebcb-952c-4371-9cdd-f4abe3f00079"],
Cell[501117, 15128, 263, 5, 171, "Print",ExpressionUUID->"994319ee-4b25-473f-a3a9-f01f6b95964a"],
Cell[501383, 15135, 522, 15, 182, "Print",ExpressionUUID->"94958d00-f253-4a1b-8b05-7e59b9c3db4c"],
Cell[501908, 15152, 272, 5, 171, "Print",ExpressionUUID->"26c15324-f491-4a6a-9146-a92bac0525cf"],
Cell[502183, 15159, 584, 19, 231, "Print",ExpressionUUID->"45e0be97-f422-4409-95b1-0763a0e68518"],
Cell[502770, 15180, 406, 7, 348, "Print",ExpressionUUID->"608006bf-d4fd-445a-84d5-da3ef8254604"],
Cell[503179, 15189, 608, 19, 202, "Print",ExpressionUUID->"6f7e9fed-5a5a-4fa5-84fe-4bc51075d2a1"],
Cell[503790, 15210, 443, 8, 348, "Print",ExpressionUUID->"6edcd3f3-7936-48db-8b4e-dd671340d101"],
Cell[504236, 15220, 603, 19, 171, "Print",ExpressionUUID->"b30bc757-c659-4162-abb9-a7174057e33f"],
Cell[504842, 15241, 472, 13, 222, "Print",ExpressionUUID->"9b2471f7-ba7a-424c-9286-c2a69314affb"],
Cell[505317, 15256, 263, 5, 171, "Print",ExpressionUUID->"0f45c6bd-4d14-4179-887f-b28d0146d75d"],
Cell[505583, 15263, 522, 15, 182, "Print",ExpressionUUID->"2d98a3f9-4f64-465c-b38a-a0e46e9ad9ca"],
Cell[506108, 15280, 272, 5, 171, "Print",ExpressionUUID->"d7131e6d-289e-436e-86b4-4ad159f296f2"],
Cell[506383, 15287, 678, 23, 231, "Print",ExpressionUUID->"c3662e98-a1ba-4211-b5e9-d10ec46eb102"],
Cell[507064, 15312, 408, 7, 348, "Print",ExpressionUUID->"544776bc-00dc-48be-8d2d-bc7fb4e865c3"],
Cell[507475, 15321, 608, 19, 202, "Print",ExpressionUUID->"9ab50013-867c-4209-870f-f0bffb082826"],
Cell[508086, 15342, 443, 8, 348, "Print",ExpressionUUID->"1f351587-0a35-415c-b88c-59754e964a1a"],
Cell[508532, 15352, 582, 18, 171, "Print",ExpressionUUID->"578100ae-9877-42b3-af7f-9d64b7e1f520"],
Cell[509117, 15372, 472, 13, 222, "Print",ExpressionUUID->"50826215-4f72-44b6-91f9-79c3a543d142"],
Cell[509592, 15387, 263, 5, 171, "Print",ExpressionUUID->"636a17f9-7744-484c-95cd-b1c6a7240948"],
Cell[509858, 15394, 557, 16, 182, "Print",ExpressionUUID->"8a2dcb65-a6e5-41a8-ad90-c7da910b3f81"],
Cell[510418, 15412, 272, 5, 171, "Print",ExpressionUUID->"4e980dc4-7ceb-47f1-af7f-ee816219f1ec"],
Cell[510693, 15419, 678, 23, 231, "Print",ExpressionUUID->"bf308ac9-f0c5-424b-bcb7-803cf848a845"],
Cell[511374, 15444, 408, 7, 348, "Print",ExpressionUUID->"2a18f3e4-5daa-43fb-9a58-5e4b45828b10"],
Cell[511785, 15453, 606, 19, 202, "Print",ExpressionUUID->"f282e72d-71fb-48fc-810d-76ce60133132"],
Cell[512394, 15474, 440, 8, 348, "Print",ExpressionUUID->"d28e70e4-d12a-4d7b-9098-b9a8ae7b741d"],
Cell[512837, 15484, 585, 18, 171, "Print",ExpressionUUID->"c5e65239-c65d-42aa-928b-e6b889ff4faa"],
Cell[513425, 15504, 474, 13, 222, "Print",ExpressionUUID->"42fd6753-33c6-4611-a63b-4b1bd377020b"],
Cell[513902, 15519, 265, 5, 171, "Print",ExpressionUUID->"32c7fa00-3968-49a9-ae18-5b9eb3812487"],
Cell[514170, 15526, 559, 16, 182, "Print",ExpressionUUID->"7f7b7434-e401-4ea1-8726-365b8428c6e9"],
Cell[514732, 15544, 274, 5, 171, "Print",ExpressionUUID->"b410f7b7-1317-497e-a4aa-24b9d7f3bcf7"],
Cell[515009, 15551, 628, 21, 231, "Print",ExpressionUUID->"ab95914f-addc-4451-bebd-de4ad1042693"],
Cell[515640, 15574, 408, 7, 348, "Print",ExpressionUUID->"c19ee91a-9ed0-45a1-9b50-cf8f2e995376"],
Cell[516051, 15583, 608, 19, 202, "Print",ExpressionUUID->"b380892a-cad1-4e1e-88fd-8e1fb90e0b49"],
Cell[516662, 15604, 443, 8, 348, "Print",ExpressionUUID->"f03cbaa8-3f71-4ef3-86a6-bb9b77f845bd"],
Cell[517108, 15614, 584, 18, 171, "Print",ExpressionUUID->"aeb00535-74d8-4ffa-b66d-b3e02ba6a412"],
Cell[517695, 15634, 472, 13, 222, "Print",ExpressionUUID->"7ec7e2f5-11cf-4430-9ad0-321123ac0b1f"],
Cell[518170, 15649, 263, 5, 171, "Print",ExpressionUUID->"7fbc6f96-7800-4c0d-b3bf-27068a8937da"],
Cell[518436, 15656, 558, 16, 182, "Print",ExpressionUUID->"88bd421f-6944-426f-9a66-67a42ded5e85"],
Cell[518997, 15674, 272, 5, 171, "Print",ExpressionUUID->"461b2e97-c1f6-4af6-9aef-132ae7a3b8e1"],
Cell[519272, 15681, 678, 23, 231, "Print",ExpressionUUID->"737a0c2a-7cba-42a4-a8f7-7c4ebff78791"],
Cell[519953, 15706, 406, 7, 348, "Print",ExpressionUUID->"fbcc7f06-5a34-4820-aefc-cccc83e3ace1"],
Cell[520362, 15715, 610, 19, 202, "Print",ExpressionUUID->"459c7468-740e-4e9e-bef2-4cb325e55960"],
Cell[520975, 15736, 443, 8, 348, "Print",ExpressionUUID->"46de9f3c-7627-4a1b-bbc2-fc41575dae83"],
Cell[521421, 15746, 586, 18, 171, "Print",ExpressionUUID->"620793c8-7687-4325-ba3f-cee1c4a79c89"]
}, Open  ]]
}, Open  ]],
Cell[522034, 15768, 188, 3, 256, "Text",ExpressionUUID->"cec2d118-8107-4acb-baaf-8b918df3763a"],
Cell[522225, 15773, 412, 8, 470, "Input",ExpressionUUID->"bb82bae4-f233-4946-a297-06a8ec03299b"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

